//-------------------------------------------------------------------------
/*
Copyright (C) 2010 EDuke32 developers and contributors

This file is part of EDuke32.

EDuke32 is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License version 2
as published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/
//-------------------------------------------------------------------------
#include "ns.h"	// Must come before everything else!

#include "compat.h"
#include "build.h"

#include "namesdyn.h"
#include "global.h"
#include "gamecontrol.h"

BEGIN_DUKE_NS

#define DVPTR(x) &x

int16_t DynamicTileMap[MAXTILES];
int16_t DynamicWeaponMap[MAX_WEAPONS];

struct dynitem
{
    const char *str;
    int32_t *dynvalptr;
    const int16_t staticval;
    const int16_t staticval_rr;
};

static struct dynitem g_dynTileList[] =
{
    { "TILE_SECTOREFFECTOR", DVPTR(TILE_SECTOREFFECTOR), SECTOREFFECTOR__STATIC, SECTOREFFECTOR__STATICRR },
    { "TILE_ACTIVATOR", DVPTR(TILE_ACTIVATOR), ACTIVATOR__STATIC, ACTIVATOR__STATICRR },
    { "TILE_TOUCHPLATE", DVPTR(TILE_TOUCHPLATE), TOUCHPLATE__STATIC, TOUCHPLATE__STATICRR },
    { "TILE_ACTIVATORLOCKED", DVPTR(TILE_ACTIVATORLOCKED), ACTIVATORLOCKED__STATIC, ACTIVATORLOCKED__STATICRR },
    { "TILE_MUSICANDSFX", DVPTR(TILE_MUSICANDSFX), MUSICANDSFX__STATIC, MUSICANDSFX__STATICRR },
    { "TILE_LOCATORS", DVPTR(TILE_LOCATORS), LOCATORS__STATIC, LOCATORS__STATICRR },
    { "TILE_CYCLER", DVPTR(TILE_CYCLER), CYCLER__STATIC, CYCLER__STATICRR },
    { "TILE_MASTERSWITCH", DVPTR(TILE_MASTERSWITCH), MASTERSWITCH__STATIC, MASTERSWITCH__STATICRR },
    { "TILE_RESPAWN", DVPTR(TILE_RESPAWN), RESPAWN__STATIC, RESPAWN__STATICRR },
    { "TILE_GPSPEED", DVPTR(TILE_GPSPEED), GPSPEED__STATIC, GPSPEED__STATICRR },
    { "TILE_FOF", DVPTR(TILE_FOF), FOF__STATIC, FOF__STATICRR },
    { "TILE_ARROW", DVPTR(TILE_ARROW), ARROW__STATIC, ARROW__STATICRR },
    { "TILE_FIRSTGUNSPRITE", DVPTR(TILE_FIRSTGUNSPRITE), FIRSTGUNSPRITE__STATIC, FIRSTGUNSPRITE__STATICRR },
    { "TILE_CHAINGUNSPRITE", DVPTR(TILE_CHAINGUNSPRITE), CHAINGUNSPRITE__STATIC, CHAINGUNSPRITE__STATICRR },
    { "TILE_RPGSPRITE", DVPTR(TILE_RPGSPRITE), RPGSPRITE__STATIC, RPGSPRITE__STATICRR },
    { "TILE_FREEZESPRITE", DVPTR(TILE_FREEZESPRITE), FREEZESPRITE__STATIC, FREEZESPRITE__STATICRR },
    { "TILE_SHRINKERSPRITE", DVPTR(TILE_SHRINKERSPRITE), SHRINKERSPRITE__STATIC, SHRINKERSPRITE__STATICRR },
    { "TILE_HEAVYHBOMB", DVPTR(TILE_HEAVYHBOMB), HEAVYHBOMB__STATIC, HEAVYHBOMB__STATICRR },
    { "TILE_TRIPBOMBSPRITE", DVPTR(TILE_TRIPBOMBSPRITE), TRIPBOMBSPRITE__STATIC, TRIPBOMBSPRITE__STATICRR },
    { "TILE_SHOTGUNSPRITE", DVPTR(TILE_SHOTGUNSPRITE), SHOTGUNSPRITE__STATIC, SHOTGUNSPRITE__STATICRR },
    { "TILE_DEVISTATORSPRITE", DVPTR(TILE_DEVISTATORSPRITE), DEVISTATORSPRITE__STATIC, DEVISTATORSPRITE__STATICRR },
    { "TILE_HEALTHBOX", DVPTR(TILE_HEALTHBOX), HEALTHBOX__STATIC, HEALTHBOX__STATICRR },
    { "TILE_AMMOBOX", DVPTR(TILE_AMMOBOX), AMMOBOX__STATIC, AMMOBOX__STATICRR },
    { "TILE_GROWSPRITEICON", DVPTR(TILE_GROWSPRITEICON), GROWSPRITEICON__STATIC, GROWSPRITEICON__STATICRR },
    { "TILE_INVENTORYBOX", DVPTR(TILE_INVENTORYBOX), INVENTORYBOX__STATIC, INVENTORYBOX__STATICRR },
    { "TILE_FREEZEAMMO", DVPTR(TILE_FREEZEAMMO), FREEZEAMMO__STATIC, FREEZEAMMO__STATICRR },
    { "TILE_AMMO", DVPTR(TILE_AMMO), AMMO__STATIC, AMMO__STATICRR },
    { "TILE_BATTERYAMMO", DVPTR(TILE_BATTERYAMMO), BATTERYAMMO__STATIC, BATTERYAMMO__STATICRR },
    { "TILE_DEVISTATORAMMO", DVPTR(TILE_DEVISTATORAMMO), DEVISTATORAMMO__STATIC, DEVISTATORAMMO__STATICRR },
    { "TILE_RPGAMMO", DVPTR(TILE_RPGAMMO), RPGAMMO__STATIC, RPGAMMO__STATICRR },
    { "TILE_GROWAMMO", DVPTR(TILE_GROWAMMO), GROWAMMO__STATIC, GROWAMMO__STATICRR },
    { "TILE_CRYSTALAMMO", DVPTR(TILE_CRYSTALAMMO), CRYSTALAMMO__STATIC, CRYSTALAMMO__STATICRR },
    { "TILE_HBOMBAMMO", DVPTR(TILE_HBOMBAMMO), HBOMBAMMO__STATIC, HBOMBAMMO__STATICRR },
    { "TILE_AMMOLOTS", DVPTR(TILE_AMMOLOTS), AMMOLOTS__STATIC, AMMOLOTS__STATICRR },
    { "TILE_SHOTGUNAMMO", DVPTR(TILE_SHOTGUNAMMO), SHOTGUNAMMO__STATIC, SHOTGUNAMMO__STATICRR },
    { "TILE_COLA", DVPTR(TILE_COLA), COLA__STATIC, COLA__STATICRR },
    { "TILE_SIXPAK", DVPTR(TILE_SIXPAK), SIXPAK__STATIC, SIXPAK__STATICRR },
    { "TILE_FIRSTAID", DVPTR(TILE_FIRSTAID), FIRSTAID__STATIC, FIRSTAID__STATICRR },
    { "TILE_SHIELD", DVPTR(TILE_SHIELD), SHIELD__STATIC, SHIELD__STATICRR },
    { "TILE_STEROIDS", DVPTR(TILE_STEROIDS), STEROIDS__STATIC, STEROIDS__STATICRR },
    { "TILE_AIRTANK", DVPTR(TILE_AIRTANK), AIRTANK__STATIC, AIRTANK__STATICRR },
    { "TILE_JETPACK", DVPTR(TILE_JETPACK), JETPACK__STATIC, JETPACK__STATICRR },
    { "TILE_HEATSENSOR", DVPTR(TILE_HEATSENSOR), HEATSENSOR__STATIC, HEATSENSOR__STATICRR },
    { "TILE_ACCESSCARD", DVPTR(TILE_ACCESSCARD), ACCESSCARD__STATIC, ACCESSCARD__STATICRR },
    { "TILE_BOOTS", DVPTR(TILE_BOOTS), BOOTS__STATIC, BOOTS__STATICRR },
    { "TILE_MIRRORBROKE", DVPTR(TILE_MIRRORBROKE), MIRRORBROKE__STATIC, MIRRORBROKE__STATICRR },
    { "TILE_CLOUDYOCEAN", DVPTR(TILE_CLOUDYOCEAN), CLOUDYOCEAN__STATIC, 0 },
    { "TILE_CLOUDYSKIES", DVPTR(TILE_CLOUDYSKIES), CLOUDYSKIES__STATIC, CLOUDYSKIES__STATICRR },
    { "TILE_MOONSKY1", DVPTR(TILE_MOONSKY1), MOONSKY1__STATIC, MOONSKY1__STATICRR },
    { "TILE_MOONSKY2", DVPTR(TILE_MOONSKY2), MOONSKY2__STATIC, MOONSKY2__STATICRR },
    { "TILE_MOONSKY3", DVPTR(TILE_MOONSKY3), MOONSKY3__STATIC, MOONSKY3__STATICRR },
    { "TILE_MOONSKY4", DVPTR(TILE_MOONSKY4), MOONSKY4__STATIC, MOONSKY4__STATICRR },
    { "TILE_BIGORBIT1", DVPTR(TILE_BIGORBIT1), BIGORBIT1__STATIC, BIGORBIT1__STATICRR },
    { "TILE_BIGORBIT2", DVPTR(TILE_BIGORBIT2), BIGORBIT2__STATIC, BIGORBIT2__STATICRR },
    { "TILE_BIGORBIT3", DVPTR(TILE_BIGORBIT3), BIGORBIT3__STATIC, BIGORBIT3__STATICRR },
    { "TILE_BIGORBIT4", DVPTR(TILE_BIGORBIT4), BIGORBIT4__STATIC, BIGORBIT4__STATICRR },
    { "TILE_BIGORBIT5", DVPTR(TILE_BIGORBIT5), BIGORBIT5__STATIC, BIGORBIT5__STATICRR },
    { "TILE_LA", DVPTR(TILE_LA), LA__STATIC, LA__STATICRR },
    { "TILE_REDSKY1", DVPTR(TILE_REDSKY1), REDSKY1__STATIC, REDSKY1__STATICRR },
    { "TILE_REDSKY2", DVPTR(TILE_REDSKY2), REDSKY2__STATIC, REDSKY2__STATICRR },
    { "TILE_ATOMICHEALTH", DVPTR(TILE_ATOMICHEALTH), ATOMICHEALTH__STATIC, ATOMICHEALTH__STATICRR },
    { "TILE_TECHLIGHT2", DVPTR(TILE_TECHLIGHT2), TECHLIGHT2__STATIC, TECHLIGHT2__STATICRR },
    { "TILE_TECHLIGHTBUST2", DVPTR(TILE_TECHLIGHTBUST2), TECHLIGHTBUST2__STATIC, TECHLIGHTBUST2__STATICRR },
    { "TILE_TECHLIGHT4", DVPTR(TILE_TECHLIGHT4), TECHLIGHT4__STATIC, TECHLIGHT4__STATICRR },
    { "TILE_TECHLIGHTBUST4", DVPTR(TILE_TECHLIGHTBUST4), TECHLIGHTBUST4__STATIC, TECHLIGHTBUST4__STATICRR },
    { "TILE_WALLLIGHT4", DVPTR(TILE_WALLLIGHT4), WALLLIGHT4__STATIC, WALLLIGHT4__STATICRR },
    { "TILE_WALLLIGHTBUST4", DVPTR(TILE_WALLLIGHTBUST4), WALLLIGHTBUST4__STATIC, WALLLIGHTBUST4__STATICRR },
    { "TILE_ACCESSSWITCH", DVPTR(TILE_ACCESSSWITCH), ACCESSSWITCH__STATIC, ACCESSSWITCH__STATICRR },
    { "TILE_SLOTDOOR", DVPTR(TILE_SLOTDOOR), SLOTDOOR__STATIC, SLOTDOOR__STATICRR },
    { "TILE_LIGHTSWITCH", DVPTR(TILE_LIGHTSWITCH), LIGHTSWITCH__STATIC, LIGHTSWITCH__STATICRR },
    { "TILE_SPACEDOORSWITCH", DVPTR(TILE_SPACEDOORSWITCH), SPACEDOORSWITCH__STATIC, SPACEDOORSWITCH__STATICRR },
    { "TILE_SPACELIGHTSWITCH", DVPTR(TILE_SPACELIGHTSWITCH), SPACELIGHTSWITCH__STATIC, SPACELIGHTSWITCH__STATICRR },
    { "TILE_FRANKENSTINESWITCH", DVPTR(TILE_FRANKENSTINESWITCH), FRANKENSTINESWITCH__STATIC, FRANKENSTINESWITCH__STATICRR },
    { "TILE_NUKEBUTTON", DVPTR(TILE_NUKEBUTTON), NUKEBUTTON__STATIC, NUKEBUTTON__STATICRR },
    { "TILE_MULTISWITCH", DVPTR(TILE_MULTISWITCH), MULTISWITCH__STATIC, MULTISWITCH__STATICRR },
    { "TILE_DOORTILE5", DVPTR(TILE_DOORTILE5), DOORTILE5__STATIC, DOORTILE5__STATICRR },
    { "TILE_DOORTILE6", DVPTR(TILE_DOORTILE6), DOORTILE6__STATIC, DOORTILE6__STATICRR },
    { "TILE_DOORTILE1", DVPTR(TILE_DOORTILE1), DOORTILE1__STATIC, DOORTILE1__STATICRR },
    { "TILE_DOORTILE2", DVPTR(TILE_DOORTILE2), DOORTILE2__STATIC, DOORTILE2__STATICRR },
    { "TILE_DOORTILE3", DVPTR(TILE_DOORTILE3), DOORTILE3__STATIC, DOORTILE3__STATICRR },
    { "TILE_DOORTILE4", DVPTR(TILE_DOORTILE4), DOORTILE4__STATIC, DOORTILE4__STATICRR },
    { "TILE_DOORTILE7", DVPTR(TILE_DOORTILE7), DOORTILE7__STATIC, DOORTILE7__STATICRR },
    { "TILE_DOORTILE8", DVPTR(TILE_DOORTILE8), DOORTILE8__STATIC, DOORTILE8__STATICRR },
    { "TILE_DOORTILE9", DVPTR(TILE_DOORTILE9), DOORTILE9__STATIC, DOORTILE9__STATICRR },
    { "TILE_DOORTILE10", DVPTR(TILE_DOORTILE10), DOORTILE10__STATIC, DOORTILE10__STATICRR },
    { "TILE_DOORSHOCK", DVPTR(TILE_DOORSHOCK), DOORSHOCK__STATIC, DOORSHOCK__STATICRR },
    { "TILE_DIPSWITCH", DVPTR(TILE_DIPSWITCH), DIPSWITCH__STATIC, DIPSWITCH__STATICRR },
    { "TILE_DIPSWITCH2", DVPTR(TILE_DIPSWITCH2), DIPSWITCH2__STATIC, DIPSWITCH2__STATICRR },
    { "TILE_TECHSWITCH", DVPTR(TILE_TECHSWITCH), TECHSWITCH__STATIC, TECHSWITCH__STATICRR },
    { "TILE_DIPSWITCH3", DVPTR(TILE_DIPSWITCH3), DIPSWITCH3__STATIC, DIPSWITCH3__STATICRR },
    { "TILE_ACCESSSWITCH2", DVPTR(TILE_ACCESSSWITCH2), ACCESSSWITCH2__STATIC, ACCESSSWITCH2__STATICRR },
    { "TILE_REFLECTWATERTILE", DVPTR(TILE_REFLECTWATERTILE), REFLECTWATERTILE__STATIC, REFLECTWATERTILE__STATICRR },
    { "TILE_FLOORSLIME", DVPTR(TILE_FLOORSLIME), FLOORSLIME__STATIC, FLOORSLIME__STATICRR },
    { "TILE_BIGFORCE", DVPTR(TILE_BIGFORCE), BIGFORCE__STATIC, BIGFORCE__STATICRR },
    { "TILE_EPISODE", DVPTR(TILE_EPISODE), EPISODE__STATIC, EPISODE__STATICRR },
    { "TILE_MASKWALL9", DVPTR(TILE_MASKWALL9), MASKWALL9__STATIC, MASKWALL9__STATICRR },
    { "TILE_W_LIGHT", DVPTR(TILE_W_LIGHT), W_LIGHT__STATIC, W_LIGHT__STATICRR },
    { "TILE_SCREENBREAK1", DVPTR(TILE_SCREENBREAK1), SCREENBREAK1__STATIC, SCREENBREAK1__STATICRR },
    { "TILE_SCREENBREAK2", DVPTR(TILE_SCREENBREAK2), SCREENBREAK2__STATIC, SCREENBREAK2__STATICRR },
    { "TILE_SCREENBREAK3", DVPTR(TILE_SCREENBREAK3), SCREENBREAK3__STATIC, SCREENBREAK3__STATICRR },
    { "TILE_SCREENBREAK4", DVPTR(TILE_SCREENBREAK4), SCREENBREAK4__STATIC, SCREENBREAK4__STATICRR },
    { "TILE_SCREENBREAK5", DVPTR(TILE_SCREENBREAK5), SCREENBREAK5__STATIC, SCREENBREAK5__STATICRR },
    { "TILE_SCREENBREAK6", DVPTR(TILE_SCREENBREAK6), SCREENBREAK6__STATIC, SCREENBREAK6__STATICRR },
    { "TILE_SCREENBREAK7", DVPTR(TILE_SCREENBREAK7), SCREENBREAK7__STATIC, SCREENBREAK7__STATICRR },
    { "TILE_SCREENBREAK8", DVPTR(TILE_SCREENBREAK8), SCREENBREAK8__STATIC, SCREENBREAK8__STATICRR },
    { "TILE_SCREENBREAK9", DVPTR(TILE_SCREENBREAK9), SCREENBREAK9__STATIC, SCREENBREAK9__STATICRR },
    { "TILE_SCREENBREAK10", DVPTR(TILE_SCREENBREAK10), SCREENBREAK10__STATIC, SCREENBREAK10__STATICRR },
    { "TILE_SCREENBREAK11", DVPTR(TILE_SCREENBREAK11), SCREENBREAK11__STATIC, SCREENBREAK11__STATICRR },
    { "TILE_SCREENBREAK12", DVPTR(TILE_SCREENBREAK12), SCREENBREAK12__STATIC, SCREENBREAK12__STATICRR },
    { "TILE_SCREENBREAK13", DVPTR(TILE_SCREENBREAK13), SCREENBREAK13__STATIC, SCREENBREAK13__STATICRR },
    { "TILE_MASKWALL1", DVPTR(TILE_MASKWALL1), MASKWALL1__STATIC, MASKWALL1__STATICRR },
    { "TILE_W_TECHWALL1", DVPTR(TILE_W_TECHWALL1), W_TECHWALL1__STATIC, W_TECHWALL1__STATICRR },
    { "TILE_W_TECHWALL2", DVPTR(TILE_W_TECHWALL2), W_TECHWALL2__STATIC, W_TECHWALL2__STATICRR },
    { "TILE_W_TECHWALL15", DVPTR(TILE_W_TECHWALL15), W_TECHWALL15__STATIC, W_TECHWALL15__STATICRR },
    { "TILE_W_TECHWALL3", DVPTR(TILE_W_TECHWALL3), W_TECHWALL3__STATIC, W_TECHWALL3__STATICRR },
    { "TILE_W_TECHWALL4", DVPTR(TILE_W_TECHWALL4), W_TECHWALL4__STATIC, W_TECHWALL4__STATICRR },
    { "TILE_W_TECHWALL10", DVPTR(TILE_W_TECHWALL10), W_TECHWALL10__STATIC, W_TECHWALL10__STATICRR },
    { "TILE_W_TECHWALL16", DVPTR(TILE_W_TECHWALL16), W_TECHWALL16__STATIC, W_TECHWALL16__STATICRR },
    { "TILE_WATERTILE2", DVPTR(TILE_WATERTILE2), WATERTILE2__STATIC, WATERTILE2__STATICRR },
    { "TILE_BPANNEL1", DVPTR(TILE_BPANNEL1), BPANNEL1__STATIC, BPANNEL1__STATICRR },
    { "TILE_PANNEL1", DVPTR(TILE_PANNEL1), PANNEL1__STATIC, PANNEL1__STATICRR },
    { "TILE_PANNEL2", DVPTR(TILE_PANNEL2), PANNEL2__STATIC, PANNEL2__STATICRR },
    { "TILE_WATERTILE", DVPTR(TILE_WATERTILE), WATERTILE__STATIC, WATERTILE__STATICRR },
    { "TILE_STATIC", DVPTR(TILE_STATIC), STATIC__STATIC, STATIC__STATICRR },
    { "TILE_W_SCREENBREAK", DVPTR(TILE_W_SCREENBREAK), W_SCREENBREAK__STATIC, W_SCREENBREAK__STATICRR },
    { "TILE_W_HITTECHWALL3", DVPTR(TILE_W_HITTECHWALL3), W_HITTECHWALL3__STATIC, W_HITTECHWALL3__STATICRR },
    { "TILE_W_HITTECHWALL4", DVPTR(TILE_W_HITTECHWALL4), W_HITTECHWALL4__STATIC, W_HITTECHWALL4__STATICRR },
    { "TILE_W_HITTECHWALL2", DVPTR(TILE_W_HITTECHWALL2), W_HITTECHWALL2__STATIC, W_HITTECHWALL2__STATICRR },
    { "TILE_W_HITTECHWALL1", DVPTR(TILE_W_HITTECHWALL1), W_HITTECHWALL1__STATIC, W_HITTECHWALL1__STATICRR },
    { "TILE_MASKWALL10", DVPTR(TILE_MASKWALL10), MASKWALL10__STATIC, MASKWALL10__STATICRR },
    { "TILE_MASKWALL11", DVPTR(TILE_MASKWALL11), MASKWALL11__STATIC, MASKWALL11__STATICRR },
    { "TILE_DOORTILE22", DVPTR(TILE_DOORTILE22), DOORTILE22__STATIC, DOORTILE22__STATICRR },
    { "TILE_FANSPRITE", DVPTR(TILE_FANSPRITE), FANSPRITE__STATIC, FANSPRITE__STATICRR },
    { "TILE_FANSPRITEBROKE", DVPTR(TILE_FANSPRITEBROKE), FANSPRITEBROKE__STATIC, FANSPRITEBROKE__STATICRR },
    { "TILE_FANSHADOW", DVPTR(TILE_FANSHADOW), FANSHADOW__STATIC, FANSHADOW__STATICRR },
    { "TILE_FANSHADOWBROKE", DVPTR(TILE_FANSHADOWBROKE), FANSHADOWBROKE__STATIC, FANSHADOWBROKE__STATICRR },
    { "TILE_DOORTILE18", DVPTR(TILE_DOORTILE18), DOORTILE18__STATIC, DOORTILE18__STATICRR },
    { "TILE_DOORTILE19", DVPTR(TILE_DOORTILE19), DOORTILE19__STATIC, DOORTILE19__STATICRR },
    { "TILE_DOORTILE20", DVPTR(TILE_DOORTILE20), DOORTILE20__STATIC, DOORTILE20__STATICRR },
    { "TILE_SATELLITE", DVPTR(TILE_SATELLITE), SATELLITE__STATIC, SATELLITE__STATICRR },
    { "TILE_VIEWSCREEN2", DVPTR(TILE_VIEWSCREEN2), VIEWSCREEN2__STATIC, VIEWSCREEN2__STATICRR },
    { "TILE_VIEWSCREENBROKE", DVPTR(TILE_VIEWSCREENBROKE), VIEWSCREENBROKE__STATIC, VIEWSCREENBROKE__STATICRR },
    { "TILE_VIEWSCREEN", DVPTR(TILE_VIEWSCREEN), VIEWSCREEN__STATIC, VIEWSCREEN__STATICRR },
    { "TILE_GLASS", DVPTR(TILE_GLASS), GLASS__STATIC, GLASS__STATICRR },
    { "TILE_GLASS2", DVPTR(TILE_GLASS2), GLASS2__STATIC, GLASS2__STATICRR },
    { "TILE_STAINGLASS1", DVPTR(TILE_STAINGLASS1), STAINGLASS1__STATIC, STAINGLASS1__STATICRR },
    { "TILE_MASKWALL5", DVPTR(TILE_MASKWALL5), MASKWALL5__STATIC, MASKWALL5__STATICRR },
    { "TILE_SATELITE", DVPTR(TILE_SATELITE), SATELITE__STATIC, SATELITE__STATICRR },
    { "TILE_FUELPOD", DVPTR(TILE_FUELPOD), FUELPOD__STATIC, FUELPOD__STATICRR },
    { "TILE_SLIMEPIPE", DVPTR(TILE_SLIMEPIPE), SLIMEPIPE__STATIC, SLIMEPIPE__STATICRR },
    { "TILE_CRACK1", DVPTR(TILE_CRACK1), CRACK1__STATIC, CRACK1__STATICRR },
    { "TILE_CRACK2", DVPTR(TILE_CRACK2), CRACK2__STATIC, CRACK2__STATICRR },
    { "TILE_CRACK3", DVPTR(TILE_CRACK3), CRACK3__STATIC, CRACK3__STATICRR },
    { "TILE_CRACK4", DVPTR(TILE_CRACK4), CRACK4__STATIC, CRACK4__STATICRR },
    { "TILE_FOOTPRINTS", DVPTR(TILE_FOOTPRINTS), FOOTPRINTS__STATIC, FOOTPRINTS__STATICRR },
    { "TILE_DOMELITE", DVPTR(TILE_DOMELITE), DOMELITE__STATIC, DOMELITE__STATICRR },
    { "TILE_CAMERAPOLE", DVPTR(TILE_CAMERAPOLE), CAMERAPOLE__STATIC, CAMERAPOLE__STATICRR },
    { "TILE_CHAIR1", DVPTR(TILE_CHAIR1), CHAIR1__STATIC, CHAIR1__STATICRR },
    { "TILE_CHAIR2", DVPTR(TILE_CHAIR2), CHAIR2__STATIC, CHAIR2__STATICRR },
    { "TILE_BROKENCHAIR", DVPTR(TILE_BROKENCHAIR), BROKENCHAIR__STATIC, BROKENCHAIR__STATICRR },
    { "TILE_MIRROR", DVPTR(TILE_MIRROR), MIRROR__STATIC, MIRROR__STATICRR },
    { "TILE_WATERFOUNTAIN", DVPTR(TILE_WATERFOUNTAIN), WATERFOUNTAIN__STATIC, WATERFOUNTAIN__STATICRR },
    { "TILE_WATERFOUNTAINBROKE", DVPTR(TILE_WATERFOUNTAINBROKE), WATERFOUNTAINBROKE__STATIC, WATERFOUNTAINBROKE__STATICRR },
    { "TILE_FEMMAG1", DVPTR(TILE_FEMMAG1), FEMMAG1__STATIC, FEMMAG1__STATICRR },
    { "TILE_TOILET", DVPTR(TILE_TOILET), TOILET__STATIC, TOILET__STATICRR },
    { "TILE_STALL", DVPTR(TILE_STALL), STALL__STATIC, STALL__STATICRR },
    { "TILE_STALLBROKE", DVPTR(TILE_STALLBROKE), STALLBROKE__STATIC, STALLBROKE__STATICRR },
    { "TILE_FEMMAG2", DVPTR(TILE_FEMMAG2), FEMMAG2__STATIC, FEMMAG2__STATICRR },
    { "TILE_REACTOR2", DVPTR(TILE_REACTOR2), REACTOR2__STATIC, REACTOR2__STATICRR },
    { "TILE_REACTOR2BURNT", DVPTR(TILE_REACTOR2BURNT), REACTOR2BURNT__STATIC, REACTOR2BURNT__STATICRR },
    { "TILE_REACTOR2SPARK", DVPTR(TILE_REACTOR2SPARK), REACTOR2SPARK__STATIC, REACTOR2SPARK__STATICRR },
    { "TILE_GRATE1", DVPTR(TILE_GRATE1), GRATE1__STATIC, GRATE1__STATICRR },
    { "TILE_BGRATE1", DVPTR(TILE_BGRATE1), BGRATE1__STATIC, BGRATE1__STATICRR },
    { "TILE_SOLARPANNEL", DVPTR(TILE_SOLARPANNEL), SOLARPANNEL__STATIC, SOLARPANNEL__STATICRR },
    { "TILE_NAKED1", DVPTR(TILE_NAKED1), NAKED1__STATIC, NAKED1__STATICRR },
    { "TILE_ANTENNA", DVPTR(TILE_ANTENNA), ANTENNA__STATIC, ANTENNA__STATICRR },
    { "TILE_MASKWALL12", DVPTR(TILE_MASKWALL12), MASKWALL12__STATIC, MASKWALL12__STATICRR },
    { "TILE_TOILETBROKE", DVPTR(TILE_TOILETBROKE), TOILETBROKE__STATIC, TOILETBROKE__STATICRR },
    { "TILE_PIPE2", DVPTR(TILE_PIPE2), PIPE2__STATIC, PIPE2__STATICRR },
    { "TILE_PIPE1B", DVPTR(TILE_PIPE1B), PIPE1B__STATIC, PIPE1B__STATICRR },
    { "TILE_PIPE3", DVPTR(TILE_PIPE3), PIPE3__STATIC, PIPE3__STATICRR },
    { "TILE_PIPE1", DVPTR(TILE_PIPE1), PIPE1__STATIC, PIPE1__STATICRR },
    { "TILE_CAMERA1", DVPTR(TILE_CAMERA1), CAMERA1__STATIC, CAMERA1__STATICRR },
    { "TILE_BRICK", DVPTR(TILE_BRICK), BRICK__STATIC, BRICK__STATICRR },
    { "TILE_SPLINTERWOOD", DVPTR(TILE_SPLINTERWOOD), SPLINTERWOOD__STATIC, SPLINTERWOOD__STATICRR },
    { "TILE_PIPE2B", DVPTR(TILE_PIPE2B), PIPE2B__STATIC, PIPE2B__STATICRR },
    { "TILE_BOLT1", DVPTR(TILE_BOLT1), BOLT1__STATIC, BOLT1__STATICRR },
    { "TILE_W_NUMBERS", DVPTR(TILE_W_NUMBERS), W_NUMBERS__STATIC, W_NUMBERS__STATICRR },
    { "TILE_WATERDRIP", DVPTR(TILE_WATERDRIP), WATERDRIP__STATIC, WATERDRIP__STATICRR },
    { "TILE_WATERBUBBLE", DVPTR(TILE_WATERBUBBLE), WATERBUBBLE__STATIC, WATERBUBBLE__STATICRR },
    { "TILE_WATERBUBBLEMAKER", DVPTR(TILE_WATERBUBBLEMAKER), WATERBUBBLEMAKER__STATIC, WATERBUBBLEMAKER__STATICRR },
    { "TILE_W_FORCEFIELD", DVPTR(TILE_W_FORCEFIELD), W_FORCEFIELD__STATIC, W_FORCEFIELD__STATICRR },
    { "TILE_VACUUM", DVPTR(TILE_VACUUM), VACUUM__STATIC, VACUUM__STATICRR },
    { "TILE_FOOTPRINTS2", DVPTR(TILE_FOOTPRINTS2), FOOTPRINTS2__STATIC, FOOTPRINTS2__STATICRR },
    { "TILE_FOOTPRINTS3", DVPTR(TILE_FOOTPRINTS3), FOOTPRINTS3__STATIC, FOOTPRINTS3__STATICRR },
    { "TILE_FOOTPRINTS4", DVPTR(TILE_FOOTPRINTS4), FOOTPRINTS4__STATIC, FOOTPRINTS4__STATICRR },
    { "TILE_EGG", DVPTR(TILE_EGG), EGG__STATIC, EGG__STATICRR },
    { "TILE_SCALE", DVPTR(TILE_SCALE), SCALE__STATIC, SCALE__STATICRR },
    { "TILE_CHAIR3", DVPTR(TILE_CHAIR3), CHAIR3__STATIC, CHAIR3__STATICRR },
    { "TILE_CAMERALIGHT", DVPTR(TILE_CAMERALIGHT), CAMERALIGHT__STATIC, CAMERALIGHT__STATICRR },
    { "TILE_MOVIECAMERA", DVPTR(TILE_MOVIECAMERA), MOVIECAMERA__STATIC, MOVIECAMERA__STATICRR },
    { "TILE_IVUNIT", DVPTR(TILE_IVUNIT), IVUNIT__STATIC, IVUNIT__STATICRR },
    { "TILE_POT1", DVPTR(TILE_POT1), POT1__STATIC, POT1__STATICRR },
    { "TILE_POT2", DVPTR(TILE_POT2), POT2__STATIC, POT2__STATICRR },
    { "TILE_POT3", DVPTR(TILE_POT3), POT3__STATIC, POT3__STATICRR },
    { "TILE_PIPE3B", DVPTR(TILE_PIPE3B), PIPE3B__STATIC, PIPE3B__STATICRR },
    { "TILE_WALLLIGHT3", DVPTR(TILE_WALLLIGHT3), WALLLIGHT3__STATIC, WALLLIGHT3__STATICRR },
    { "TILE_WALLLIGHTBUST3", DVPTR(TILE_WALLLIGHTBUST3), WALLLIGHTBUST3__STATIC, WALLLIGHTBUST3__STATICRR },
    { "TILE_WALLLIGHT1", DVPTR(TILE_WALLLIGHT1), WALLLIGHT1__STATIC, WALLLIGHT1__STATICRR },
    { "TILE_WALLLIGHTBUST1", DVPTR(TILE_WALLLIGHTBUST1), WALLLIGHTBUST1__STATIC, WALLLIGHTBUST1__STATICRR },
    { "TILE_WALLLIGHT2", DVPTR(TILE_WALLLIGHT2), WALLLIGHT2__STATIC, WALLLIGHT2__STATICRR },
    { "TILE_WALLLIGHTBUST2", DVPTR(TILE_WALLLIGHTBUST2), WALLLIGHTBUST2__STATIC, WALLLIGHTBUST2__STATICRR },
    { "TILE_LIGHTSWITCH2", DVPTR(TILE_LIGHTSWITCH2), LIGHTSWITCH2__STATIC, LIGHTSWITCH2__STATICRR },
    { "TILE_WAITTOBESEATED", DVPTR(TILE_WAITTOBESEATED), WAITTOBESEATED__STATIC, WAITTOBESEATED__STATICRR },
    { "TILE_DOORTILE14", DVPTR(TILE_DOORTILE14), DOORTILE14__STATIC, DOORTILE14__STATICRR },
    { "TILE_STATUE", DVPTR(TILE_STATUE), STATUE__STATIC, STATUE__STATICRR },
    { "TILE_MIKE", DVPTR(TILE_MIKE), MIKE__STATIC, MIKE__STATICRR },
    { "TILE_VASE", DVPTR(TILE_VASE), VASE__STATIC, VASE__STATICRR },
    { "TILE_SUSHIPLATE1", DVPTR(TILE_SUSHIPLATE1), SUSHIPLATE1__STATIC, SUSHIPLATE1__STATICRR },
    { "TILE_SUSHIPLATE2", DVPTR(TILE_SUSHIPLATE2), SUSHIPLATE2__STATIC, SUSHIPLATE2__STATICRR },
    { "TILE_SUSHIPLATE3", DVPTR(TILE_SUSHIPLATE3), SUSHIPLATE3__STATIC, SUSHIPLATE3__STATICRR },
    { "TILE_SUSHIPLATE4", DVPTR(TILE_SUSHIPLATE4), SUSHIPLATE4__STATIC, SUSHIPLATE4__STATICRR },
    { "TILE_DOORTILE16", DVPTR(TILE_DOORTILE16), DOORTILE16__STATIC, DOORTILE16__STATICRR },
    { "TILE_SUSHIPLATE5", DVPTR(TILE_SUSHIPLATE5), SUSHIPLATE5__STATIC, SUSHIPLATE5__STATICRR },
    { "TILE_OJ", DVPTR(TILE_OJ), OJ__STATIC, OJ__STATICRR },
    { "TILE_MASKWALL13", DVPTR(TILE_MASKWALL13), MASKWALL13__STATIC, MASKWALL13__STATICRR },
    { "TILE_HURTRAIL", DVPTR(TILE_HURTRAIL), HURTRAIL__STATIC, HURTRAIL__STATICRR },
    { "TILE_POWERSWITCH1", DVPTR(TILE_POWERSWITCH1), POWERSWITCH1__STATIC, POWERSWITCH1__STATICRR },
    { "TILE_LOCKSWITCH1", DVPTR(TILE_LOCKSWITCH1), LOCKSWITCH1__STATIC, LOCKSWITCH1__STATICRR },
    { "TILE_POWERSWITCH2", DVPTR(TILE_POWERSWITCH2), POWERSWITCH2__STATIC, POWERSWITCH2__STATICRR },
    { "TILE_ATM", DVPTR(TILE_ATM), ATM__STATIC, ATM__STATICRR },
    { "TILE_STATUEFLASH", DVPTR(TILE_STATUEFLASH), STATUEFLASH__STATIC, STATUEFLASH__STATICRR },
    { "TILE_ATMBROKE", DVPTR(TILE_ATMBROKE), ATMBROKE__STATIC, ATMBROKE__STATICRR },
    { "TILE_BIGHOLE2", DVPTR(TILE_BIGHOLE2), BIGHOLE2__STATIC, BIGHOLE2__STATICRR },
    { "TILE_STRIPEBALL", DVPTR(TILE_STRIPEBALL), STRIPEBALL__STATIC, STRIPEBALL__STATICRR },
    { "TILE_QUEBALL", DVPTR(TILE_QUEBALL), QUEBALL__STATIC, QUEBALL__STATICRR },
    { "TILE_POCKET", DVPTR(TILE_POCKET), POCKET__STATIC, POCKET__STATICRR },
    { "TILE_WOODENHORSE", DVPTR(TILE_WOODENHORSE), WOODENHORSE__STATIC, WOODENHORSE__STATICRR },
    { "TILE_TREE1", DVPTR(TILE_TREE1), TREE1__STATIC, TREE1__STATICRR },
    { "TILE_TREE2", DVPTR(TILE_TREE2), TREE2__STATIC, TREE2__STATICRR },
    { "TILE_CACTUS", DVPTR(TILE_CACTUS), CACTUS__STATIC, CACTUS__STATICRR },
    { "TILE_MASKWALL2", DVPTR(TILE_MASKWALL2), MASKWALL2__STATIC, MASKWALL2__STATICRR },
    { "TILE_MASKWALL3", DVPTR(TILE_MASKWALL3), MASKWALL3__STATIC, MASKWALL3__STATICRR },
    { "TILE_MASKWALL4", DVPTR(TILE_MASKWALL4), MASKWALL4__STATIC, MASKWALL4__STATICRR },
    { "TILE_FIREEXT", DVPTR(TILE_FIREEXT), FIREEXT__STATIC, FIREEXT__STATICRR },
    { "TILE_TOILETWATER", DVPTR(TILE_TOILETWATER), TOILETWATER__STATIC, TOILETWATER__STATICRR },
    { "TILE_NEON1", DVPTR(TILE_NEON1), NEON1__STATIC, NEON1__STATICRR },
    { "TILE_NEON2", DVPTR(TILE_NEON2), NEON2__STATIC, NEON2__STATICRR },
    { "TILE_CACTUSBROKE", DVPTR(TILE_CACTUSBROKE), CACTUSBROKE__STATIC, CACTUSBROKE__STATICRR },
    { "TILE_BOUNCEMINE", DVPTR(TILE_BOUNCEMINE), BOUNCEMINE__STATIC, BOUNCEMINE__STATICRR },
    { "TILE_BROKEFIREHYDRENT", DVPTR(TILE_BROKEFIREHYDRENT), BROKEFIREHYDRENT__STATIC, BROKEFIREHYDRENT__STATICRR },
    { "TILE_BOX", DVPTR(TILE_BOX), BOX__STATIC, BOX__STATICRR },
    { "TILE_BULLETHOLE", DVPTR(TILE_BULLETHOLE), BULLETHOLE__STATIC, BULLETHOLE__STATICRR },
    { "TILE_BOTTLE1", DVPTR(TILE_BOTTLE1), BOTTLE1__STATIC, BOTTLE1__STATICRR },
    { "TILE_BOTTLE2", DVPTR(TILE_BOTTLE2), BOTTLE2__STATIC, BOTTLE2__STATICRR },
    { "TILE_BOTTLE3", DVPTR(TILE_BOTTLE3), BOTTLE3__STATIC, BOTTLE3__STATICRR },
    { "TILE_BOTTLE4", DVPTR(TILE_BOTTLE4), BOTTLE4__STATIC, BOTTLE4__STATICRR },
    { "TILE_FEMPIC5", DVPTR(TILE_FEMPIC5), FEMPIC5__STATIC, FEMPIC5__STATICRR },
    { "TILE_FEMPIC6", DVPTR(TILE_FEMPIC6), FEMPIC6__STATIC, FEMPIC6__STATICRR },
    { "TILE_FEMPIC7", DVPTR(TILE_FEMPIC7), FEMPIC7__STATIC, FEMPIC7__STATICRR },
    { "TILE_HYDROPLANT", DVPTR(TILE_HYDROPLANT), HYDROPLANT__STATIC, HYDROPLANT__STATICRR },
    { "TILE_OCEANSPRITE1", DVPTR(TILE_OCEANSPRITE1), OCEANSPRITE1__STATIC, OCEANSPRITE1__STATICRR },
    { "TILE_OCEANSPRITE2", DVPTR(TILE_OCEANSPRITE2), OCEANSPRITE2__STATIC, OCEANSPRITE2__STATICRR },
    { "TILE_OCEANSPRITE3", DVPTR(TILE_OCEANSPRITE3), OCEANSPRITE3__STATIC, OCEANSPRITE3__STATICRR },
    { "TILE_OCEANSPRITE4", DVPTR(TILE_OCEANSPRITE4), OCEANSPRITE4__STATIC, OCEANSPRITE4__STATICRR },
    { "TILE_OCEANSPRITE5", DVPTR(TILE_OCEANSPRITE5), OCEANSPRITE5__STATIC, OCEANSPRITE5__STATICRR },
    { "TILE_GENERICPOLE", DVPTR(TILE_GENERICPOLE), GENERICPOLE__STATIC, GENERICPOLE__STATICRR },
    { "TILE_CONE", DVPTR(TILE_CONE), CONE__STATIC, CONE__STATICRR },
    { "TILE_HANGLIGHT", DVPTR(TILE_HANGLIGHT), HANGLIGHT__STATIC, HANGLIGHT__STATICRR },
    { "TILE_HYDRENT", DVPTR(TILE_HYDRENT), HYDRENT__STATIC, HYDRENT__STATICRR },
    { "TILE_MASKWALL14", DVPTR(TILE_MASKWALL14), MASKWALL14__STATIC, MASKWALL14__STATICRR },
    { "TILE_TIRE", DVPTR(TILE_TIRE), TIRE__STATIC, TIRE__STATICRR },
    { "TILE_PIPE5", DVPTR(TILE_PIPE5), PIPE5__STATIC, PIPE5__STATICRR },
    { "TILE_PIPE6", DVPTR(TILE_PIPE6), PIPE6__STATIC, PIPE6__STATICRR },
    { "TILE_PIPE4", DVPTR(TILE_PIPE4), PIPE4__STATIC, PIPE4__STATICRR },
    { "TILE_PIPE4B", DVPTR(TILE_PIPE4B), PIPE4B__STATIC, PIPE4B__STATICRR },
    { "TILE_BROKEHYDROPLANT", DVPTR(TILE_BROKEHYDROPLANT), BROKEHYDROPLANT__STATIC, BROKEHYDROPLANT__STATICRR },
    { "TILE_PIPE5B", DVPTR(TILE_PIPE5B), PIPE5B__STATIC, PIPE5B__STATICRR },
    { "TILE_NEON3", DVPTR(TILE_NEON3), NEON3__STATIC, NEON3__STATICRR },
    { "TILE_NEON4", DVPTR(TILE_NEON4), NEON4__STATIC, NEON4__STATICRR },
    { "TILE_NEON5", DVPTR(TILE_NEON5), NEON5__STATIC, NEON5__STATICRR },
    { "TILE_BOTTLE5", DVPTR(TILE_BOTTLE5), BOTTLE5__STATIC, BOTTLE5__STATICRR },
    { "TILE_BOTTLE6", DVPTR(TILE_BOTTLE6), BOTTLE6__STATIC, BOTTLE6__STATICRR },
    { "TILE_BOTTLE8", DVPTR(TILE_BOTTLE8), BOTTLE8__STATIC, BOTTLE8__STATICRR },
    { "TILE_SPOTLITE", DVPTR(TILE_SPOTLITE), SPOTLITE__STATIC, SPOTLITE__STATICRR },
    { "TILE_HANGOOZ", DVPTR(TILE_HANGOOZ), HANGOOZ__STATIC, HANGOOZ__STATICRR },
    { "TILE_MASKWALL15", DVPTR(TILE_MASKWALL15), MASKWALL15__STATIC, MASKWALL15__STATICRR },
    { "TILE_BOTTLE7", DVPTR(TILE_BOTTLE7), BOTTLE7__STATIC, BOTTLE7__STATICRR },
    { "TILE_HORSEONSIDE", DVPTR(TILE_HORSEONSIDE), HORSEONSIDE__STATIC, HORSEONSIDE__STATICRR },
    { "TILE_GLASSPIECES", DVPTR(TILE_GLASSPIECES), GLASSPIECES__STATIC, GLASSPIECES__STATICRR },
    { "TILE_HORSELITE", DVPTR(TILE_HORSELITE), HORSELITE__STATIC, HORSELITE__STATICRR },
    { "TILE_DONUTS", DVPTR(TILE_DONUTS), DONUTS__STATIC, DONUTS__STATICRR },
    { "TILE_NEON6", DVPTR(TILE_NEON6), NEON6__STATIC, NEON6__STATICRR },
    { "TILE_MASKWALL6", DVPTR(TILE_MASKWALL6), MASKWALL6__STATIC, MASKWALL6__STATICRR },
    { "TILE_CLOCK", DVPTR(TILE_CLOCK), CLOCK__STATIC, CLOCK__STATICRR },
    { "TILE_RUBBERCAN", DVPTR(TILE_RUBBERCAN), RUBBERCAN__STATIC, RUBBERCAN__STATICRR },
    { "TILE_BROKENCLOCK", DVPTR(TILE_BROKENCLOCK), BROKENCLOCK__STATIC, BROKENCLOCK__STATICRR },
    { "TILE_PLUG", DVPTR(TILE_PLUG), PLUG__STATIC, PLUG__STATICRR },
    { "TILE_OOZFILTER", DVPTR(TILE_OOZFILTER), OOZFILTER__STATIC, OOZFILTER__STATICRR },
    { "TILE_FLOORPLASMA", DVPTR(TILE_FLOORPLASMA), FLOORPLASMA__STATIC, FLOORPLASMA__STATICRR },
    { "TILE_REACTOR", DVPTR(TILE_REACTOR), REACTOR__STATIC, REACTOR__STATICRR },
    { "TILE_REACTORSPARK", DVPTR(TILE_REACTORSPARK), REACTORSPARK__STATIC, REACTORSPARK__STATICRR },
    { "TILE_REACTORBURNT", DVPTR(TILE_REACTORBURNT), REACTORBURNT__STATIC, REACTORBURNT__STATICRR },
    { "TILE_DOORTILE15", DVPTR(TILE_DOORTILE15), DOORTILE15__STATIC, DOORTILE15__STATICRR },
    { "TILE_HANDSWITCH", DVPTR(TILE_HANDSWITCH), HANDSWITCH__STATIC, HANDSWITCH__STATICRR },
    { "TILE_CIRCLEPANNEL", DVPTR(TILE_CIRCLEPANNEL), CIRCLEPANNEL__STATIC, CIRCLEPANNEL__STATICRR },
    { "TILE_CIRCLEPANNELBROKE", DVPTR(TILE_CIRCLEPANNELBROKE), CIRCLEPANNELBROKE__STATIC, CIRCLEPANNELBROKE__STATICRR },
    { "TILE_PULLSWITCH", DVPTR(TILE_PULLSWITCH), PULLSWITCH__STATIC, PULLSWITCH__STATICRR },
    { "TILE_MASKWALL8", DVPTR(TILE_MASKWALL8), MASKWALL8__STATIC, MASKWALL8__STATICRR },
    { "TILE_BIGHOLE", DVPTR(TILE_BIGHOLE), BIGHOLE__STATIC, BIGHOLE__STATICRR },
    { "TILE_ALIENSWITCH", DVPTR(TILE_ALIENSWITCH), ALIENSWITCH__STATIC, ALIENSWITCH__STATICRR },
    { "TILE_DOORTILE21", DVPTR(TILE_DOORTILE21), DOORTILE21__STATIC, DOORTILE21__STATICRR },
    { "TILE_HANDPRINTSWITCH", DVPTR(TILE_HANDPRINTSWITCH), HANDPRINTSWITCH__STATIC, HANDPRINTSWITCH__STATICRR },
    { "TILE_BOTTLE10", DVPTR(TILE_BOTTLE10), BOTTLE10__STATIC, BOTTLE10__STATICRR },
    { "TILE_BOTTLE11", DVPTR(TILE_BOTTLE11), BOTTLE11__STATIC, BOTTLE11__STATICRR },
    { "TILE_BOTTLE12", DVPTR(TILE_BOTTLE12), BOTTLE12__STATIC, BOTTLE12__STATICRR },
    { "TILE_BOTTLE13", DVPTR(TILE_BOTTLE13), BOTTLE13__STATIC, BOTTLE13__STATICRR },
    { "TILE_BOTTLE14", DVPTR(TILE_BOTTLE14), BOTTLE14__STATIC, BOTTLE14__STATICRR },
    { "TILE_BOTTLE15", DVPTR(TILE_BOTTLE15), BOTTLE15__STATIC, BOTTLE15__STATICRR },
    { "TILE_BOTTLE16", DVPTR(TILE_BOTTLE16), BOTTLE16__STATIC, BOTTLE16__STATICRR },
    { "TILE_BOTTLE17", DVPTR(TILE_BOTTLE17), BOTTLE17__STATIC, BOTTLE17__STATICRR },
    { "TILE_BOTTLE18", DVPTR(TILE_BOTTLE18), BOTTLE18__STATIC, BOTTLE18__STATICRR },
    { "TILE_BOTTLE19", DVPTR(TILE_BOTTLE19), BOTTLE19__STATIC, BOTTLE19__STATICRR },
    { "TILE_DOORTILE17", DVPTR(TILE_DOORTILE17), DOORTILE17__STATIC, DOORTILE17__STATICRR },
    { "TILE_MASKWALL7", DVPTR(TILE_MASKWALL7), MASKWALL7__STATIC, MASKWALL7__STATICRR },
    { "TILE_JAILBARBREAK", DVPTR(TILE_JAILBARBREAK), JAILBARBREAK__STATIC, JAILBARBREAK__STATICRR },
    { "TILE_DOORTILE11", DVPTR(TILE_DOORTILE11), DOORTILE11__STATIC, DOORTILE11__STATICRR },
    { "TILE_DOORTILE12", DVPTR(TILE_DOORTILE12), DOORTILE12__STATIC, DOORTILE12__STATICRR },
    { "TILE_VENDMACHINE", DVPTR(TILE_VENDMACHINE), VENDMACHINE__STATIC, VENDMACHINE__STATICRR },
    { "TILE_VENDMACHINEBROKE", DVPTR(TILE_VENDMACHINEBROKE), VENDMACHINEBROKE__STATIC, VENDMACHINEBROKE__STATICRR },
    { "TILE_COLAMACHINE", DVPTR(TILE_COLAMACHINE), COLAMACHINE__STATIC, COLAMACHINE__STATICRR },
    { "TILE_COLAMACHINEBROKE", DVPTR(TILE_COLAMACHINEBROKE), COLAMACHINEBROKE__STATIC, COLAMACHINEBROKE__STATICRR },
    { "TILE_CRANEPOLE", DVPTR(TILE_CRANEPOLE), CRANEPOLE__STATIC, CRANEPOLE__STATICRR },
    { "TILE_CRANE", DVPTR(TILE_CRANE), CRANE__STATIC, CRANE__STATICRR },
    { "TILE_BARBROKE", DVPTR(TILE_BARBROKE), BARBROKE__STATIC, BARBROKE__STATICRR },
    { "TILE_BLOODPOOL", DVPTR(TILE_BLOODPOOL), BLOODPOOL__STATIC, BLOODPOOL__STATICRR },
    { "TILE_NUKEBARREL", DVPTR(TILE_NUKEBARREL), NUKEBARREL__STATIC, NUKEBARREL__STATICRR },
    { "TILE_NUKEBARRELDENTED", DVPTR(TILE_NUKEBARRELDENTED), NUKEBARRELDENTED__STATIC, NUKEBARRELDENTED__STATICRR },
    { "TILE_NUKEBARRELLEAKED", DVPTR(TILE_NUKEBARRELLEAKED), NUKEBARRELLEAKED__STATIC, NUKEBARRELLEAKED__STATICRR },
    { "TILE_CANWITHSOMETHING", DVPTR(TILE_CANWITHSOMETHING), CANWITHSOMETHING__STATIC, CANWITHSOMETHING__STATICRR },
    { "TILE_MONEY", DVPTR(TILE_MONEY), MONEY__STATIC, MONEY__STATICRR },
    { "TILE_BANNER", DVPTR(TILE_BANNER), BANNER__STATIC, BANNER__STATICRR },
    { "TILE_EXPLODINGBARREL", DVPTR(TILE_EXPLODINGBARREL), EXPLODINGBARREL__STATIC, EXPLODINGBARREL__STATICRR },
    { "TILE_EXPLODINGBARREL2", DVPTR(TILE_EXPLODINGBARREL2), EXPLODINGBARREL2__STATIC, EXPLODINGBARREL2__STATICRR },
    { "TILE_FIREBARREL", DVPTR(TILE_FIREBARREL), FIREBARREL__STATIC, FIREBARREL__STATICRR },
    { "TILE_SEENINE", DVPTR(TILE_SEENINE), SEENINE__STATIC, SEENINE__STATICRR },
    { "TILE_SEENINEDEAD", DVPTR(TILE_SEENINEDEAD), SEENINEDEAD__STATIC, SEENINEDEAD__STATICRR },
    { "TILE_STEAM", DVPTR(TILE_STEAM), STEAM__STATIC, STEAM__STATICRR },
    { "TILE_CEILINGSTEAM", DVPTR(TILE_CEILINGSTEAM), CEILINGSTEAM__STATIC, CEILINGSTEAM__STATICRR },
    { "TILE_PIPE6B", DVPTR(TILE_PIPE6B), PIPE6B__STATIC, PIPE6B__STATICRR },
    { "TILE_TRANSPORTERBEAM", DVPTR(TILE_TRANSPORTERBEAM), TRANSPORTERBEAM__STATIC, TRANSPORTERBEAM__STATICRR },
    { "TILE_RAT", DVPTR(TILE_RAT), RAT__STATIC, RAT__STATICRR },
    { "TILE_TRASH", DVPTR(TILE_TRASH), TRASH__STATIC, TRASH__STATICRR },
    { "TILE_FEMPIC1", DVPTR(TILE_FEMPIC1), FEMPIC1__STATIC, FEMPIC1__STATICRR },
    { "TILE_FEMPIC2", DVPTR(TILE_FEMPIC2), FEMPIC2__STATIC, FEMPIC2__STATICRR },
    { "TILE_BLANKSCREEN", DVPTR(TILE_BLANKSCREEN), BLANKSCREEN__STATIC, BLANKSCREEN__STATICRR },
    { "TILE_PODFEM1", DVPTR(TILE_PODFEM1), PODFEM1__STATIC, PODFEM1__STATICRR },
    { "TILE_FEMPIC3", DVPTR(TILE_FEMPIC3), FEMPIC3__STATIC, FEMPIC3__STATICRR },
    { "TILE_FEMPIC4", DVPTR(TILE_FEMPIC4), FEMPIC4__STATIC, FEMPIC4__STATICRR },
    { "TILE_FEM1", DVPTR(TILE_FEM1), FEM1__STATIC, FEM1__STATICRR },
    { "TILE_FEM2", DVPTR(TILE_FEM2), FEM2__STATIC, FEM2__STATICRR },
    { "TILE_FEM3", DVPTR(TILE_FEM3), FEM3__STATIC, FEM3__STATICRR },
    { "TILE_FEM5", DVPTR(TILE_FEM5), FEM5__STATIC, FEM5__STATICRR },
    { "TILE_BLOODYPOLE", DVPTR(TILE_BLOODYPOLE), BLOODYPOLE__STATIC, BLOODYPOLE__STATICRR },
    { "TILE_FEM4", DVPTR(TILE_FEM4), FEM4__STATIC, FEM4__STATICRR },
    { "TILE_FEM6", DVPTR(TILE_FEM6), FEM6__STATIC, FEM6__STATICRR },
    { "TILE_FEM6PAD", DVPTR(TILE_FEM6PAD), FEM6PAD__STATIC, FEM6PAD__STATICRR },
    { "TILE_FEM8", DVPTR(TILE_FEM8), FEM8__STATIC, FEM8__STATICRR },
    { "TILE_HELECOPT", DVPTR(TILE_HELECOPT), HELECOPT__STATIC, HELECOPT__STATICRR },
    { "TILE_FETUSJIB", DVPTR(TILE_FETUSJIB), FETUSJIB__STATIC, FETUSJIB__STATICRR },
    { "TILE_HOLODUKE", DVPTR(TILE_HOLODUKE), HOLODUKE__STATIC, HOLODUKE__STATICRR },
    { "TILE_SPACEMARINE", DVPTR(TILE_SPACEMARINE), SPACEMARINE__STATIC, SPACEMARINE__STATICRR },
    { "TILE_INDY", DVPTR(TILE_INDY), INDY__STATIC, INDY__STATICRR },
    { "TILE_FETUS", DVPTR(TILE_FETUS), FETUS__STATIC, FETUS__STATICRR },
    { "TILE_FETUSBROKE", DVPTR(TILE_FETUSBROKE), FETUSBROKE__STATIC, FETUSBROKE__STATICRR },
    { "TILE_MONK", DVPTR(TILE_MONK), MONK__STATIC, MONK__STATICRR },
    { "TILE_LUKE", DVPTR(TILE_LUKE), LUKE__STATIC, LUKE__STATICRR },
    { "TILE_COOLEXPLOSION1", DVPTR(TILE_COOLEXPLOSION1), COOLEXPLOSION1__STATIC, COOLEXPLOSION1__STATICRR },
    { "TILE_WATERSPLASH2", DVPTR(TILE_WATERSPLASH2), WATERSPLASH2__STATIC, WATERSPLASH2__STATICRR },
    { "TILE_FIREVASE", DVPTR(TILE_FIREVASE), FIREVASE__STATIC, FIREVASE__STATICRR },
    { "TILE_SCRATCH", DVPTR(TILE_SCRATCH), SCRATCH__STATIC, SCRATCH__STATICRR },
    { "TILE_FEM7", DVPTR(TILE_FEM7), FEM7__STATIC, FEM7__STATICRR },
    { "TILE_APLAYERTOP", DVPTR(TILE_APLAYERTOP), APLAYERTOP__STATIC, APLAYERTOP__STATICRR },
    { "TILE_APLAYER", DVPTR(TILE_APLAYER), APLAYER__STATIC, APLAYER__STATICRR },
    { "TILE_PLAYERONWATER", DVPTR(TILE_PLAYERONWATER), PLAYERONWATER__STATIC, PLAYERONWATER__STATICRR },
    { "TILE_DUKELYINGDEAD", DVPTR(TILE_DUKELYINGDEAD), DUKELYINGDEAD__STATIC, DUKELYINGDEAD__STATICRR },
    { "TILE_DUKETORSO", DVPTR(TILE_DUKETORSO), DUKETORSO__STATIC, DUKETORSO__STATICRR },
    { "TILE_DUKEGUN", DVPTR(TILE_DUKEGUN), DUKEGUN__STATIC, DUKEGUN__STATICRR },
    { "TILE_DUKELEG", DVPTR(TILE_DUKELEG), DUKELEG__STATIC, DUKELEG__STATICRR },
    { "TILE_SHARK", DVPTR(TILE_SHARK), SHARK__STATIC, SHARK__STATICRR },
    { "TILE_BLOOD", DVPTR(TILE_BLOOD), BLOOD__STATIC, BLOOD__STATICRR },
    { "TILE_FIRELASER", DVPTR(TILE_FIRELASER), FIRELASER__STATIC, FIRELASER__STATICRR },
    { "TILE_TRANSPORTERSTAR", DVPTR(TILE_TRANSPORTERSTAR), TRANSPORTERSTAR__STATIC, TRANSPORTERSTAR__STATICRR },
    { "TILE_SPIT", DVPTR(TILE_SPIT), SPIT__STATIC, SPIT__STATICRR },
    { "TILE_LOOGIE", DVPTR(TILE_LOOGIE), LOOGIE__STATIC, LOOGIE__STATICRR },
    { "TILE_FIST", DVPTR(TILE_FIST), FIST__STATIC, FIST__STATICRR },
    { "TILE_FREEZEBLAST", DVPTR(TILE_FREEZEBLAST), FREEZEBLAST__STATIC, FREEZEBLAST__STATICRR },
    { "TILE_DEVISTATORBLAST", DVPTR(TILE_DEVISTATORBLAST), DEVISTATORBLAST__STATIC, DEVISTATORBLAST__STATICRR },
    { "TILE_SHRINKSPARK", DVPTR(TILE_SHRINKSPARK), SHRINKSPARK__STATIC, SHRINKSPARK__STATICRR },
    { "TILE_TONGUE", DVPTR(TILE_TONGUE), TONGUE__STATIC, TONGUE__STATICRR },
    { "TILE_MORTER", DVPTR(TILE_MORTER), MORTER__STATIC, MORTER__STATICRR },
    { "TILE_SHRINKEREXPLOSION", DVPTR(TILE_SHRINKEREXPLOSION), SHRINKEREXPLOSION__STATIC, SHRINKEREXPLOSION__STATICRR },
    { "TILE_RADIUSEXPLOSION", DVPTR(TILE_RADIUSEXPLOSION), RADIUSEXPLOSION__STATIC, RADIUSEXPLOSION__STATICRR },
    { "TILE_FORCERIPPLE", DVPTR(TILE_FORCERIPPLE), FORCERIPPLE__STATIC, FORCERIPPLE__STATICRR },
    { "TILE_LIZTROOP", DVPTR(TILE_LIZTROOP), LIZTROOP__STATIC, 0 },
    { "TILE_LIZTROOPRUNNING", DVPTR(TILE_LIZTROOPRUNNING), LIZTROOPRUNNING__STATIC, 0 },
    { "TILE_LIZTROOPSTAYPUT", DVPTR(TILE_LIZTROOPSTAYPUT), LIZTROOPSTAYPUT__STATIC, 0 },
    { "TILE_LIZTOP", DVPTR(TILE_LIZTOP), LIZTOP__STATIC, 0 },
    { "TILE_LIZTROOPSHOOT", DVPTR(TILE_LIZTROOPSHOOT), LIZTROOPSHOOT__STATIC, 0 },
    { "TILE_LIZTROOPJETPACK", DVPTR(TILE_LIZTROOPJETPACK), LIZTROOPJETPACK__STATIC, 0 },
    { "TILE_LIZTROOPDSPRITE", DVPTR(TILE_LIZTROOPDSPRITE), LIZTROOPDSPRITE__STATIC, 0 },
    { "TILE_LIZTROOPONTOILET", DVPTR(TILE_LIZTROOPONTOILET), LIZTROOPONTOILET__STATIC, 0 },
    { "TILE_LIZTROOPJUSTSIT", DVPTR(TILE_LIZTROOPJUSTSIT), LIZTROOPJUSTSIT__STATIC, 0 },
    { "TILE_LIZTROOPDUCKING", DVPTR(TILE_LIZTROOPDUCKING), LIZTROOPDUCKING__STATIC, 0 },
    { "TILE_HEADJIB1", DVPTR(TILE_HEADJIB1), HEADJIB1__STATIC, 0 },
    { "TILE_ARMJIB1", DVPTR(TILE_ARMJIB1), ARMJIB1__STATIC, 0 },
    { "TILE_LEGJIB1", DVPTR(TILE_LEGJIB1), LEGJIB1__STATIC, 0 },
    { "TILE_CANNONBALL", DVPTR(TILE_CANNONBALL), CANNONBALL__STATIC, CANNONBALL__STATICRR },
    { "TILE_OCTABRAIN", DVPTR(TILE_OCTABRAIN), OCTABRAIN__STATIC, 0 },
    { "TILE_OCTABRAINSTAYPUT", DVPTR(TILE_OCTABRAINSTAYPUT), OCTABRAINSTAYPUT__STATIC, 0 },
    { "TILE_OCTATOP", DVPTR(TILE_OCTATOP), OCTATOP__STATIC, 0 },
    { "TILE_OCTADEADSPRITE", DVPTR(TILE_OCTADEADSPRITE), OCTADEADSPRITE__STATIC, 0 },
    { "TILE_INNERJAW", DVPTR(TILE_INNERJAW), INNERJAW__STATIC, INNERJAW__STATICRR },
    { "TILE_DRONE", DVPTR(TILE_DRONE), DRONE__STATIC, DRONE__STATICRR },
    { "TILE_EXPLOSION2", DVPTR(TILE_EXPLOSION2), EXPLOSION2__STATIC, EXPLOSION2__STATICRR },
    { "TILE_COMMANDER", DVPTR(TILE_COMMANDER), COMMANDER__STATIC, 0 },
    { "TILE_COMMANDERSTAYPUT", DVPTR(TILE_COMMANDERSTAYPUT), COMMANDERSTAYPUT__STATIC, 0 },
    { "TILE_RECON", DVPTR(TILE_RECON), RECON__STATIC, RECON__STATICRR },
    { "TILE_TANK", DVPTR(TILE_TANK), TANK__STATIC, 0 },
    { "TILE_PIGCOP", DVPTR(TILE_PIGCOP), PIGCOP__STATIC, 0 },
    { "TILE_PIGCOPSTAYPUT", DVPTR(TILE_PIGCOPSTAYPUT), PIGCOPSTAYPUT__STATIC, 0 },
    { "TILE_PIGCOPDIVE", DVPTR(TILE_PIGCOPDIVE), PIGCOPDIVE__STATIC, 0 },
    { "TILE_PIGCOPDEADSPRITE", DVPTR(TILE_PIGCOPDEADSPRITE), PIGCOPDEADSPRITE__STATIC, 0 },
    { "TILE_PIGTOP", DVPTR(TILE_PIGTOP), PIGTOP__STATIC, 0 },
    { "TILE_LIZMAN", DVPTR(TILE_LIZMAN), LIZMAN__STATIC, 0 },
    { "TILE_LIZMANSTAYPUT", DVPTR(TILE_LIZMANSTAYPUT), LIZMANSTAYPUT__STATIC, 0 },
    { "TILE_LIZMANSPITTING", DVPTR(TILE_LIZMANSPITTING), LIZMANSPITTING__STATIC, 0 },
    { "TILE_LIZMANFEEDING", DVPTR(TILE_LIZMANFEEDING), LIZMANFEEDING__STATIC, 0 },
    { "TILE_LIZMANJUMP", DVPTR(TILE_LIZMANJUMP), LIZMANJUMP__STATIC, 0 },
    { "TILE_LIZMANDEADSPRITE", DVPTR(TILE_LIZMANDEADSPRITE), LIZMANDEADSPRITE__STATIC, 0 },
    { "TILE_FECES", DVPTR(TILE_FECES), FECES__STATIC, FECES__STATICRR },
    { "TILE_LIZMANHEAD1", DVPTR(TILE_LIZMANHEAD1), LIZMANHEAD1__STATIC, 0 },
    { "TILE_LIZMANARM1", DVPTR(TILE_LIZMANARM1), LIZMANARM1__STATIC, 0 },
    { "TILE_LIZMANLEG1", DVPTR(TILE_LIZMANLEG1), LIZMANLEG1__STATIC, 0 },
    { "TILE_EXPLOSION2BOT", DVPTR(TILE_EXPLOSION2BOT), EXPLOSION2BOT__STATIC, EXPLOSION2BOT__STATICRR },
    { "TILE_USERWEAPON", DVPTR(TILE_USERWEAPON), USERWEAPON__STATIC, USERWEAPON__STATICRR },
    { "TILE_HEADERBAR", DVPTR(TILE_HEADERBAR), HEADERBAR__STATIC, HEADERBAR__STATICRR },
    { "TILE_JIBS1", DVPTR(TILE_JIBS1), JIBS1__STATIC, JIBS1__STATICRR },
    { "TILE_JIBS2", DVPTR(TILE_JIBS2), JIBS2__STATIC, JIBS2__STATICRR },
    { "TILE_JIBS3", DVPTR(TILE_JIBS3), JIBS3__STATIC, JIBS3__STATICRR },
    { "TILE_JIBS4", DVPTR(TILE_JIBS4), JIBS4__STATIC, JIBS4__STATICRR },
    { "TILE_JIBS5", DVPTR(TILE_JIBS5), JIBS5__STATIC, JIBS5__STATICRR },
    { "TILE_BURNING", DVPTR(TILE_BURNING), BURNING__STATIC, BURNING__STATICRR },
    { "TILE_FIRE", DVPTR(TILE_FIRE), FIRE__STATIC, FIRE__STATICRR },
    { "TILE_JIBS6", DVPTR(TILE_JIBS6), JIBS6__STATIC, JIBS6__STATICRR },
    { "TILE_BLOODSPLAT1", DVPTR(TILE_BLOODSPLAT1), BLOODSPLAT1__STATIC, BLOODSPLAT1__STATICRR },
    { "TILE_BLOODSPLAT3", DVPTR(TILE_BLOODSPLAT3), BLOODSPLAT3__STATIC, BLOODSPLAT3__STATICRR },
    { "TILE_BLOODSPLAT2", DVPTR(TILE_BLOODSPLAT2), BLOODSPLAT2__STATIC, BLOODSPLAT2__STATICRR },
    { "TILE_BLOODSPLAT4", DVPTR(TILE_BLOODSPLAT4), BLOODSPLAT4__STATIC, BLOODSPLAT4__STATICRR },
    { "TILE_OOZ", DVPTR(TILE_OOZ), OOZ__STATIC, OOZ__STATICRR },
    { "TILE_OOZ2", DVPTR(TILE_OOZ2), OOZ2__STATIC, OOZ2__STATICRR },
    { "TILE_WALLBLOOD1", DVPTR(TILE_WALLBLOOD1), WALLBLOOD1__STATIC, WALLBLOOD1__STATICRR },
    { "TILE_WALLBLOOD2", DVPTR(TILE_WALLBLOOD2), WALLBLOOD2__STATIC, WALLBLOOD2__STATICRR },
    { "TILE_WALLBLOOD3", DVPTR(TILE_WALLBLOOD3), WALLBLOOD3__STATIC, WALLBLOOD3__STATICRR },
    { "TILE_WALLBLOOD4", DVPTR(TILE_WALLBLOOD4), WALLBLOOD4__STATIC, WALLBLOOD4__STATICRR },
    { "TILE_WALLBLOOD5", DVPTR(TILE_WALLBLOOD5), WALLBLOOD5__STATIC, WALLBLOOD5__STATICRR },
    { "TILE_WALLBLOOD6", DVPTR(TILE_WALLBLOOD6), WALLBLOOD6__STATIC, WALLBLOOD6__STATICRR },
    { "TILE_WALLBLOOD7", DVPTR(TILE_WALLBLOOD7), WALLBLOOD7__STATIC, WALLBLOOD7__STATICRR },
    { "TILE_WALLBLOOD8", DVPTR(TILE_WALLBLOOD8), WALLBLOOD8__STATIC, WALLBLOOD8__STATICRR },
    { "TILE_BURNING2", DVPTR(TILE_BURNING2), BURNING2__STATIC, BURNING2__STATICRR },
    { "TILE_FIRE2", DVPTR(TILE_FIRE2), FIRE2__STATIC, FIRE2__STATICRR },
    { "TILE_CRACKKNUCKLES", DVPTR(TILE_CRACKKNUCKLES), CRACKKNUCKLES__STATIC, CRACKKNUCKLES__STATICRR },
    { "TILE_SMALLSMOKE", DVPTR(TILE_SMALLSMOKE), SMALLSMOKE__STATIC, SMALLSMOKE__STATICRR },
    { "TILE_SMALLSMOKEMAKER", DVPTR(TILE_SMALLSMOKEMAKER), SMALLSMOKEMAKER__STATIC, SMALLSMOKEMAKER__STATICRR },
    { "TILE_FLOORFLAME", DVPTR(TILE_FLOORFLAME), FLOORFLAME__STATIC, FLOORFLAME__STATICRR },
    { "TILE_ROTATEGUN", DVPTR(TILE_ROTATEGUN), ROTATEGUN__STATIC, ROTATEGUN__STATICRR },
    { "TILE_GREENSLIME", DVPTR(TILE_GREENSLIME), GREENSLIME__STATIC, GREENSLIME__STATICRR },
    { "TILE_WATERDRIPSPLASH", DVPTR(TILE_WATERDRIPSPLASH), WATERDRIPSPLASH__STATIC, WATERDRIPSPLASH__STATICRR },
    { "TILE_SCRAP6", DVPTR(TILE_SCRAP6), SCRAP6__STATIC, SCRAP6__STATICRR },
    { "TILE_SCRAP1", DVPTR(TILE_SCRAP1), SCRAP1__STATIC, SCRAP1__STATICRR },
    { "TILE_SCRAP2", DVPTR(TILE_SCRAP2), SCRAP2__STATIC, SCRAP2__STATICRR },
    { "TILE_SCRAP3", DVPTR(TILE_SCRAP3), SCRAP3__STATIC, SCRAP3__STATICRR },
    { "TILE_SCRAP4", DVPTR(TILE_SCRAP4), SCRAP4__STATIC, SCRAP4__STATICRR },
    { "TILE_SCRAP5", DVPTR(TILE_SCRAP5), SCRAP5__STATIC, SCRAP5__STATICRR },
    { "TILE_ORGANTIC", DVPTR(TILE_ORGANTIC), ORGANTIC__STATIC, ORGANTIC__STATICRR },
    { "TILE_BETAVERSION", DVPTR(TILE_BETAVERSION), BETAVERSION__STATIC, BETAVERSION__STATICRR },
    { "TILE_PLAYERISHERE", DVPTR(TILE_PLAYERISHERE), PLAYERISHERE__STATIC, PLAYERISHERE__STATICRR },
    { "TILE_PLAYERWASHERE", DVPTR(TILE_PLAYERWASHERE), PLAYERWASHERE__STATIC, PLAYERWASHERE__STATICRR },
    { "TILE_SELECTDIR", DVPTR(TILE_SELECTDIR), SELECTDIR__STATIC, SELECTDIR__STATICRR },
    { "TILE_F1HELP", DVPTR(TILE_F1HELP), F1HELP__STATIC, F1HELP__STATICRR },
    { "TILE_NOTCHON", DVPTR(TILE_NOTCHON), NOTCHON__STATIC, NOTCHON__STATICRR },
    { "TILE_NOTCHOFF", DVPTR(TILE_NOTCHOFF), NOTCHOFF__STATIC, NOTCHOFF__STATICRR },
    { "TILE_GROWSPARK", DVPTR(TILE_GROWSPARK), GROWSPARK__STATIC, GROWSPARK__STATICRR },
    { "TILE_DUKEICON", DVPTR(TILE_DUKEICON), DUKEICON__STATIC, DUKEICON__STATICRR },
    { "TILE_BADGUYICON", DVPTR(TILE_BADGUYICON), BADGUYICON__STATIC, BADGUYICON__STATICRR },
    { "TILE_FOODICON", DVPTR(TILE_FOODICON), FOODICON__STATIC, FOODICON__STATICRR },
    { "TILE_GETICON", DVPTR(TILE_GETICON), GETICON__STATIC, GETICON__STATICRR },
    { "TILE_MENUSCREEN", DVPTR(TILE_MENUSCREEN), MENUSCREEN__STATIC, MENUSCREEN__STATICRR },
    { "TILE_MENUBAR", DVPTR(TILE_MENUBAR), MENUBAR__STATIC, MENUBAR__STATICRR },
    { "TILE_KILLSICON", DVPTR(TILE_KILLSICON), KILLSICON__STATIC, KILLSICON__STATICRR },
    { "TILE_FIRSTAID_ICON", DVPTR(TILE_FIRSTAID_ICON), FIRSTAID_ICON__STATIC, FIRSTAID_ICON__STATICRR },
    { "TILE_HEAT_ICON", DVPTR(TILE_HEAT_ICON), HEAT_ICON__STATIC, HEAT_ICON__STATICRR },
    { "TILE_BOTTOMSTATUSBAR", DVPTR(TILE_BOTTOMSTATUSBAR), BOTTOMSTATUSBAR__STATIC, BOTTOMSTATUSBAR__STATICRR },
    { "TILE_BOOT_ICON", DVPTR(TILE_BOOT_ICON), BOOT_ICON__STATIC, BOOT_ICON__STATICRR },
    { "TILE_FRAGBAR", DVPTR(TILE_FRAGBAR), FRAGBAR__STATIC, FRAGBAR__STATICRR },
    { "TILE_JETPACK_ICON", DVPTR(TILE_JETPACK_ICON), JETPACK_ICON__STATIC, JETPACK_ICON__STATICRR },
    { "TILE_AIRTANK_ICON", DVPTR(TILE_AIRTANK_ICON), AIRTANK_ICON__STATIC, AIRTANK_ICON__STATICRR },
    { "TILE_STEROIDS_ICON", DVPTR(TILE_STEROIDS_ICON), STEROIDS_ICON__STATIC, STEROIDS_ICON__STATICRR },
    { "TILE_HOLODUKE_ICON", DVPTR(TILE_HOLODUKE_ICON), HOLODUKE_ICON__STATIC, HOLODUKE_ICON__STATICRR },
    { "TILE_ACCESS_ICON", DVPTR(TILE_ACCESS_ICON), ACCESS_ICON__STATIC, ACCESS_ICON__STATICRR },
    { "TILE_DIGITALNUM", DVPTR(TILE_DIGITALNUM), DIGITALNUM__STATIC, DIGITALNUM__STATICRR },
    { "TILE_DUKECAR", DVPTR(TILE_DUKECAR), DUKECAR__STATIC, DUKECAR__STATICRR },
    { "TILE_CAMCORNER", DVPTR(TILE_CAMCORNER), CAMCORNER__STATIC, CAMCORNER__STATICRR },
    { "TILE_CAMLIGHT", DVPTR(TILE_CAMLIGHT), CAMLIGHT__STATIC, CAMLIGHT__STATICRR },
    { "TILE_LOGO", DVPTR(TILE_LOGO), LOGO__STATIC, LOGO__STATICRR },
    { "TILE_TITLE", DVPTR(TILE_TITLE), TITLE__STATIC, TITLE__STATICRR },
    { "TILE_NUKEWARNINGICON", DVPTR(TILE_NUKEWARNINGICON), NUKEWARNINGICON__STATIC, NUKEWARNINGICON__STATICRR },
    { "TILE_MOUSECURSOR", DVPTR(TILE_MOUSECURSOR), MOUSECURSOR__STATIC, MOUSECURSOR__STATICRR },
    { "TILE_SLIDEBAR", DVPTR(TILE_SLIDEBAR), SLIDEBAR__STATIC, SLIDEBAR__STATICRR },
    { "TILE_DREALMS", DVPTR(TILE_DREALMS), DREALMS__STATIC, DREALMS__STATICRR },
    { "TILE_BETASCREEN", DVPTR(TILE_BETASCREEN), BETASCREEN__STATIC, BETASCREEN__STATICRR },
    { "TILE_WINDOWBORDER1", DVPTR(TILE_WINDOWBORDER1), WINDOWBORDER1__STATIC, WINDOWBORDER1__STATICRR },
    { "TILE_TEXTBOX", DVPTR(TILE_TEXTBOX), TEXTBOX__STATIC, TEXTBOX__STATICRR },
    { "TILE_WINDOWBORDER2", DVPTR(TILE_WINDOWBORDER2), WINDOWBORDER2__STATIC, WINDOWBORDER2__STATICRR },
    { "TILE_DUKENUKEM", DVPTR(TILE_DUKENUKEM), DUKENUKEM__STATIC, DUKENUKEM__STATICRR },
    { "TILE_THREEDEE", DVPTR(TILE_THREEDEE), THREEDEE__STATIC, THREEDEE__STATICRR },
    { "TILE_INGAMEDUKETHREEDEE", DVPTR(TILE_INGAMEDUKETHREEDEE), INGAMEDUKETHREEDEE__STATIC, INGAMEDUKETHREEDEE__STATICRR },
    { "TILE_TENSCREEN", DVPTR(TILE_TENSCREEN), TENSCREEN__STATIC, TENSCREEN__STATICRR },
    { "TILE_PLUTOPAKSPRITE", DVPTR(TILE_PLUTOPAKSPRITE), PLUTOPAKSPRITE__STATIC, PLUTOPAKSPRITE__STATICRR },
    { "TILE_DEVISTATOR", DVPTR(TILE_DEVISTATOR), DEVISTATOR__STATIC, DEVISTATOR__STATICRR },
    { "TILE_KNEE", DVPTR(TILE_KNEE), KNEE__STATIC, KNEE__STATICRR },
    { "TILE_CROSSHAIR", DVPTR(TILE_CROSSHAIR), CROSSHAIR__STATIC, CROSSHAIR__STATICRR },
    { "TILE_FIRSTGUN", DVPTR(TILE_FIRSTGUN), FIRSTGUN__STATIC, FIRSTGUN__STATICRR },
    { "TILE_FIRSTGUNRELOAD", DVPTR(TILE_FIRSTGUNRELOAD), FIRSTGUNRELOAD__STATIC, FIRSTGUNRELOAD__STATICRR },
    { "TILE_FALLINGCLIP", DVPTR(TILE_FALLINGCLIP), FALLINGCLIP__STATIC, FALLINGCLIP__STATICRR },
    { "TILE_CLIPINHAND", DVPTR(TILE_CLIPINHAND), CLIPINHAND__STATIC, CLIPINHAND__STATICRR },
    { "TILE_HAND", DVPTR(TILE_HAND), HAND__STATIC, HAND__STATICRR },
    { "TILE_SHELL", DVPTR(TILE_SHELL), SHELL__STATIC, SHELL__STATICRR },
    { "TILE_SHOTGUNSHELL", DVPTR(TILE_SHOTGUNSHELL), SHOTGUNSHELL__STATIC, SHOTGUNSHELL__STATICRR },
    { "TILE_CHAINGUN", DVPTR(TILE_CHAINGUN), CHAINGUN__STATIC, CHAINGUN__STATICRR },
    { "TILE_RPGGUN", DVPTR(TILE_RPGGUN), RPGGUN__STATIC, RPGGUN__STATICRR },
    { "TILE_RPGMUZZLEFLASH", DVPTR(TILE_RPGMUZZLEFLASH), RPGMUZZLEFLASH__STATIC, RPGMUZZLEFLASH__STATICRR },
    { "TILE_FREEZE", DVPTR(TILE_FREEZE), FREEZE__STATIC, FREEZE__STATICRR },
    { "TILE_CATLITE", DVPTR(TILE_CATLITE), CATLITE__STATIC, CATLITE__STATICRR },
    { "TILE_SHRINKER", DVPTR(TILE_SHRINKER), SHRINKER__STATIC, SHRINKER__STATICRR },
    { "TILE_HANDHOLDINGLASER", DVPTR(TILE_HANDHOLDINGLASER), HANDHOLDINGLASER__STATIC, HANDHOLDINGLASER__STATICRR },
    { "TILE_TRIPBOMB", DVPTR(TILE_TRIPBOMB), TRIPBOMB__STATIC, TRIPBOMB__STATICRR },
    { "TILE_LASERLINE", DVPTR(TILE_LASERLINE), LASERLINE__STATIC, LASERLINE__STATICRR },
    { "TILE_HANDHOLDINGACCESS", DVPTR(TILE_HANDHOLDINGACCESS), HANDHOLDINGACCESS__STATIC, HANDHOLDINGACCESS__STATICRR },
    { "TILE_HANDREMOTE", DVPTR(TILE_HANDREMOTE), HANDREMOTE__STATIC, HANDREMOTE__STATICRR },
    { "TILE_HANDTHROW", DVPTR(TILE_HANDTHROW), HANDTHROW__STATIC, HANDTHROW__STATICRR },
    { "TILE_TIP", DVPTR(TILE_TIP), TIP__STATIC, TIP__STATICRR },
    { "TILE_GLAIR", DVPTR(TILE_GLAIR), GLAIR__STATIC, GLAIR__STATICRR },
    { "TILE_SCUBAMASK", DVPTR(TILE_SCUBAMASK), SCUBAMASK__STATIC, SCUBAMASK__STATICRR },
    { "TILE_SPACEMASK", DVPTR(TILE_SPACEMASK), SPACEMASK__STATIC, SPACEMASK__STATICRR },
    { "TILE_FORCESPHERE", DVPTR(TILE_FORCESPHERE), FORCESPHERE__STATIC, FORCESPHERE__STATICRR },
    { "TILE_SHOTSPARK1", DVPTR(TILE_SHOTSPARK1), SHOTSPARK1__STATIC, SHOTSPARK1__STATICRR },
    { "TILE_RPG", DVPTR(TILE_RPG), RPG__STATIC, RPG__STATICRR },
    { "TILE_LASERSITE", DVPTR(TILE_LASERSITE), LASERSITE__STATIC, 0 },
    { "TILE_SHOTGUN", DVPTR(TILE_SHOTGUN), SHOTGUN__STATIC, SHOTGUN__STATICRR },
    { "TILE_BOSS1", DVPTR(TILE_BOSS1), BOSS1__STATIC, BOSS1__STATICRR },
    { "TILE_BOSS1STAYPUT", DVPTR(TILE_BOSS1STAYPUT), BOSS1STAYPUT__STATIC, 0 },
    { "TILE_BOSS1SHOOT", DVPTR(TILE_BOSS1SHOOT), BOSS1SHOOT__STATIC, 0 },
    { "TILE_BOSS1LOB", DVPTR(TILE_BOSS1LOB), BOSS1LOB__STATIC, 0 },
    { "TILE_BOSSTOP", DVPTR(TILE_BOSSTOP), BOSSTOP__STATIC, 0 },
    { "TILE_BOSS2", DVPTR(TILE_BOSS2), BOSS2__STATIC, BOSS2__STATICRR },
    { "TILE_BOSS3", DVPTR(TILE_BOSS3), BOSS3__STATIC, BOSS3__STATICRR },
    { "TILE_SPINNINGNUKEICON", DVPTR(TILE_SPINNINGNUKEICON), SPINNINGNUKEICON__STATIC, SPINNINGNUKEICON__STATICRR },
    { "TILE_BIGFNTCURSOR", DVPTR(TILE_BIGFNTCURSOR), BIGFNTCURSOR__STATIC, BIGFNTCURSOR__STATICRR },
    { "TILE_SMALLFNTCURSOR", DVPTR(TILE_SMALLFNTCURSOR), SMALLFNTCURSOR__STATIC, SMALLFNTCURSOR__STATICRR },
    { "TILE_STARTALPHANUM", DVPTR(TILE_STARTALPHANUM), STARTALPHANUM__STATIC, STARTALPHANUM__STATICRR },
    { "TILE_ENDALPHANUM", DVPTR(TILE_ENDALPHANUM), ENDALPHANUM__STATIC, ENDALPHANUM__STATICRR },
    { "TILE_BIGALPHANUM", DVPTR(TILE_BIGALPHANUM), BIGALPHANUM__STATIC, BIGALPHANUM__STATICRR },
    { "TILE_BIGPERIOD", DVPTR(TILE_BIGPERIOD), BIGPERIOD__STATIC, BIGPERIOD__STATICRR },
    { "TILE_BIGCOMMA", DVPTR(TILE_BIGCOMMA), BIGCOMMA__STATIC, BIGCOMMA__STATICRR },
    { "BIGX", DVPTR(TILE_BIGX_), BIGX__STATIC, BIGX__STATICRR },
    { "TILE_BIGQ", DVPTR(TILE_BIGQ), BIGQ__STATIC, BIGQ__STATICRR },
    { "TILE_BIGSEMI", DVPTR(TILE_BIGSEMI), BIGSEMI__STATIC, BIGSEMI__STATICRR },
    { "TILE_BIGCOLIN", DVPTR(TILE_BIGCOLIN), BIGCOLIN__STATIC, BIGCOLIN__STATICRR },
    { "TILE_THREEBYFIVE", DVPTR(TILE_THREEBYFIVE), THREEBYFIVE__STATIC, THREEBYFIVE__STATICRR },
    { "TILE_BIGAPPOS", DVPTR(TILE_BIGAPPOS), BIGAPPOS__STATIC, BIGAPPOS__STATICRR },
    { "TILE_BLANK", DVPTR(TILE_BLANK), BLANK__STATIC, BLANK__STATICRR },
    { "TILE_MINIFONT", DVPTR(TILE_MINIFONT), MINIFONT__STATIC, MINIFONT__STATICRR },
    { "TILE_BUTTON1", DVPTR(TILE_BUTTON1), BUTTON1__STATIC, BUTTON1__STATICRR },
    { "TILE_GLASS3", DVPTR(TILE_GLASS3), GLASS3__STATIC, GLASS3__STATICRR },
    { "TILE_RESPAWNMARKERRED", DVPTR(TILE_RESPAWNMARKERRED), RESPAWNMARKERRED__STATIC, RESPAWNMARKERRED__STATICRR },
    { "TILE_RESPAWNMARKERYELLOW", DVPTR(TILE_RESPAWNMARKERYELLOW), RESPAWNMARKERYELLOW__STATIC, RESPAWNMARKERYELLOW__STATICRR },
    { "TILE_RESPAWNMARKERGREEN", DVPTR(TILE_RESPAWNMARKERGREEN), RESPAWNMARKERGREEN__STATIC, RESPAWNMARKERGREEN__STATICRR },
    { "TILE_BONUSSCREEN", DVPTR(TILE_BONUSSCREEN), BONUSSCREEN__STATIC, BONUSSCREEN__STATICRR },
    { "TILE_VIEWBORDER", DVPTR(TILE_VIEWBORDER), VIEWBORDER__STATIC, VIEWBORDER__STATICRR },
    { "TILE_VICTORY1", DVPTR(TILE_VICTORY1), VICTORY1__STATIC, VICTORY1__STATICRR },
    { "TILE_ORDERING", DVPTR(TILE_ORDERING), ORDERING__STATIC, ORDERING__STATICRR },
    { "TILE_TEXTSTORY", DVPTR(TILE_TEXTSTORY), TEXTSTORY__STATIC, TEXTSTORY__STATICRR },
    { "TILE_LOADSCREEN", DVPTR(TILE_LOADSCREEN), LOADSCREEN__STATIC, LOADSCREEN__STATICRR },
    { "TILE_BORNTOBEWILDSCREEN", DVPTR(TILE_BORNTOBEWILDSCREEN), BORNTOBEWILDSCREEN__STATIC, BORNTOBEWILDSCREEN__STATICRR },
    { "TILE_BLIMP", DVPTR(TILE_BLIMP), BLIMP__STATIC, BLIMP__STATICRR },
    { "TILE_FEM9", DVPTR(TILE_FEM9), FEM9__STATIC, FEM9__STATICRR },
    { "TILE_FOOTPRINT", DVPTR(TILE_FOOTPRINT), FOOTPRINT__STATIC, FOOTPRINT__STATICRR },
    { "TILE_POOP", DVPTR(TILE_POOP), POOP__STATIC, POOP__STATICRR },
    { "TILE_FRAMEEFFECT1", DVPTR(TILE_FRAMEEFFECT1), FRAMEEFFECT1__STATIC, FRAMEEFFECT1__STATICRR },
    { "TILE_PANNEL3", DVPTR(TILE_PANNEL3), PANNEL3__STATIC, PANNEL3__STATICRR },
    { "TILE_SCREENBREAK14", DVPTR(TILE_SCREENBREAK14), SCREENBREAK14__STATIC, SCREENBREAK14__STATICRR },
    { "TILE_SCREENBREAK15", DVPTR(TILE_SCREENBREAK15), SCREENBREAK15__STATIC, SCREENBREAK15__STATICRR },
    { "TILE_SCREENBREAK19", DVPTR(TILE_SCREENBREAK19), SCREENBREAK19__STATIC, SCREENBREAK19__STATICRR },
    { "TILE_SCREENBREAK16", DVPTR(TILE_SCREENBREAK16), SCREENBREAK16__STATIC, SCREENBREAK16__STATICRR },
    { "TILE_SCREENBREAK17", DVPTR(TILE_SCREENBREAK17), SCREENBREAK17__STATIC, SCREENBREAK17__STATICRR },
    { "TILE_SCREENBREAK18", DVPTR(TILE_SCREENBREAK18), SCREENBREAK18__STATIC, SCREENBREAK18__STATICRR },
    { "TILE_W_TECHWALL11", DVPTR(TILE_W_TECHWALL11), W_TECHWALL11__STATIC, W_TECHWALL11__STATICRR },
    { "TILE_W_TECHWALL12", DVPTR(TILE_W_TECHWALL12), W_TECHWALL12__STATIC, W_TECHWALL12__STATICRR },
    { "TILE_W_TECHWALL13", DVPTR(TILE_W_TECHWALL13), W_TECHWALL13__STATIC, W_TECHWALL13__STATICRR },
    { "TILE_W_TECHWALL14", DVPTR(TILE_W_TECHWALL14), W_TECHWALL14__STATIC, W_TECHWALL14__STATICRR },
    { "TILE_W_TECHWALL5", DVPTR(TILE_W_TECHWALL5), W_TECHWALL5__STATIC, W_TECHWALL5__STATICRR },
    { "TILE_W_TECHWALL6", DVPTR(TILE_W_TECHWALL6), W_TECHWALL6__STATIC, W_TECHWALL6__STATICRR },
    { "TILE_W_TECHWALL7", DVPTR(TILE_W_TECHWALL7), W_TECHWALL7__STATIC, W_TECHWALL7__STATICRR },
    { "TILE_W_TECHWALL8", DVPTR(TILE_W_TECHWALL8), W_TECHWALL8__STATIC, W_TECHWALL8__STATICRR },
    { "TILE_W_TECHWALL9", DVPTR(TILE_W_TECHWALL9), W_TECHWALL9__STATIC, W_TECHWALL9__STATICRR },
    { "TILE_BPANNEL3", DVPTR(TILE_BPANNEL3), BPANNEL3__STATIC, BPANNEL3__STATICRR },
    { "TILE_W_HITTECHWALL16", DVPTR(TILE_W_HITTECHWALL16), W_HITTECHWALL16__STATIC, W_HITTECHWALL16__STATICRR },
    { "TILE_W_HITTECHWALL10", DVPTR(TILE_W_HITTECHWALL10), W_HITTECHWALL10__STATIC, W_HITTECHWALL10__STATICRR },
    { "TILE_W_HITTECHWALL15", DVPTR(TILE_W_HITTECHWALL15), W_HITTECHWALL15__STATIC, W_HITTECHWALL15__STATICRR },
    { "TILE_W_MILKSHELF", DVPTR(TILE_W_MILKSHELF), W_MILKSHELF__STATIC, W_MILKSHELF__STATICRR },
    { "TILE_W_MILKSHELFBROKE", DVPTR(TILE_W_MILKSHELFBROKE), W_MILKSHELFBROKE__STATIC, W_MILKSHELFBROKE__STATICRR },
    { "TILE_PURPLELAVA", DVPTR(TILE_PURPLELAVA), PURPLELAVA__STATIC, PURPLELAVA__STATICRR },
    { "TILE_LAVABUBBLE", DVPTR(TILE_LAVABUBBLE), LAVABUBBLE__STATIC, LAVABUBBLE__STATICRR },
    { "TILE_DUKECUTOUT", DVPTR(TILE_DUKECUTOUT), DUKECUTOUT__STATIC, DUKECUTOUT__STATICRR },
    { "TILE_TARGET", DVPTR(TILE_TARGET), TARGET__STATIC, TARGET__STATICRR },
    { "TILE_GUNPOWDERBARREL", DVPTR(TILE_GUNPOWDERBARREL), GUNPOWDERBARREL__STATIC, GUNPOWDERBARREL__STATICRR },
    { "TILE_DUCK", DVPTR(TILE_DUCK), DUCK__STATIC, DUCK__STATICRR },
    { "TILE_HATRACK", DVPTR(TILE_HATRACK), HATRACK__STATIC, HATRACK__STATICRR },
    { "TILE_DESKLAMP", DVPTR(TILE_DESKLAMP), DESKLAMP__STATIC, DESKLAMP__STATICRR },
    { "TILE_COFFEEMACHINE", DVPTR(TILE_COFFEEMACHINE), COFFEEMACHINE__STATIC, COFFEEMACHINE__STATICRR },
    { "TILE_CUPS", DVPTR(TILE_CUPS), CUPS__STATIC, CUPS__STATICRR },
    { "TILE_GAVALS", DVPTR(TILE_GAVALS), GAVALS__STATIC, GAVALS__STATICRR },
    { "TILE_GAVALS2", DVPTR(TILE_GAVALS2), GAVALS2__STATIC, GAVALS2__STATICRR },
    { "TILE_POLICELIGHTPOLE", DVPTR(TILE_POLICELIGHTPOLE), POLICELIGHTPOLE__STATIC, POLICELIGHTPOLE__STATICRR },
    { "TILE_FLOORBASKET", DVPTR(TILE_FLOORBASKET), FLOORBASKET__STATIC, FLOORBASKET__STATICRR },
    { "TILE_PUKE", DVPTR(TILE_PUKE), PUKE__STATIC, PUKE__STATICRR },
    { "TILE_DOORTILE23", DVPTR(TILE_DOORTILE23), DOORTILE23__STATIC, DOORTILE23__STATICRR },
    { "TILE_TOPSECRET", DVPTR(TILE_TOPSECRET), TOPSECRET__STATIC, TOPSECRET__STATICRR },
    { "TILE_SPEAKER", DVPTR(TILE_SPEAKER), SPEAKER__STATIC, SPEAKER__STATICRR },
    { "TILE_TEDDYBEAR", DVPTR(TILE_TEDDYBEAR), TEDDYBEAR__STATIC, TEDDYBEAR__STATICRR },
    { "TILE_ROBOTDOG", DVPTR(TILE_ROBOTDOG), ROBOTDOG__STATIC, ROBOTDOG__STATICRR },
    { "TILE_ROBOTPIRATE", DVPTR(TILE_ROBOTPIRATE), ROBOTPIRATE__STATIC, ROBOTPIRATE__STATICRR },
    { "TILE_ROBOTMOUSE", DVPTR(TILE_ROBOTMOUSE), ROBOTMOUSE__STATIC, ROBOTMOUSE__STATICRR },
    { "TILE_MAIL", DVPTR(TILE_MAIL), MAIL__STATIC, MAIL__STATICRR },
    { "TILE_MAILBAG", DVPTR(TILE_MAILBAG), MAILBAG__STATIC, MAILBAG__STATICRR },
    { "TILE_HOTMEAT", DVPTR(TILE_HOTMEAT), HOTMEAT__STATIC, HOTMEAT__STATICRR },
    { "TILE_COFFEEMUG", DVPTR(TILE_COFFEEMUG), COFFEEMUG__STATIC, COFFEEMUG__STATICRR },
    { "TILE_DONUTS2", DVPTR(TILE_DONUTS2), DONUTS2__STATIC, DONUTS2__STATICRR },
    { "TILE_TRIPODCAMERA", DVPTR(TILE_TRIPODCAMERA), TRIPODCAMERA__STATIC, TRIPODCAMERA__STATICRR },
    { "TILE_METER", DVPTR(TILE_METER), METER__STATIC, METER__STATICRR },
    { "TILE_DESKPHONE", DVPTR(TILE_DESKPHONE), DESKPHONE__STATIC, DESKPHONE__STATICRR },
    { "TILE_GUMBALLMACHINE", DVPTR(TILE_GUMBALLMACHINE), GUMBALLMACHINE__STATIC, GUMBALLMACHINE__STATICRR },
    { "TILE_GUMBALLMACHINEBROKE", DVPTR(TILE_GUMBALLMACHINEBROKE), GUMBALLMACHINEBROKE__STATIC, GUMBALLMACHINEBROKE__STATICRR },
    { "TILE_PAPER", DVPTR(TILE_PAPER), PAPER__STATIC, PAPER__STATICRR },
    { "TILE_MACE", DVPTR(TILE_MACE), MACE__STATIC, MACE__STATICRR },
    { "TILE_GENERICPOLE2", DVPTR(TILE_GENERICPOLE2), GENERICPOLE2__STATIC, GENERICPOLE2__STATICRR },
    { "TILE_XXXSTACY", DVPTR(TILE_XXXSTACY), XXXSTACY__STATIC, XXXSTACY__STATICRR },
    { "TILE_WETFLOOR", DVPTR(TILE_WETFLOOR), WETFLOOR__STATIC, WETFLOOR__STATICRR },
    { "TILE_BROOM", DVPTR(TILE_BROOM), BROOM__STATIC, BROOM__STATICRR },
    { "TILE_MOP", DVPTR(TILE_MOP), MOP__STATIC, MOP__STATICRR },
    { "TILE_LETTER", DVPTR(TILE_LETTER), LETTER__STATIC, 0 },
    { "TILE_PIRATE1A", DVPTR(TILE_PIRATE1A), PIRATE1A__STATIC, PIRATE1A__STATICRR },
    { "TILE_PIRATE4A", DVPTR(TILE_PIRATE4A), PIRATE4A__STATIC, PIRATE4A__STATICRR },
    { "TILE_PIRATE2A", DVPTR(TILE_PIRATE2A), PIRATE2A__STATIC, PIRATE2A__STATICRR },
    { "TILE_PIRATE5A", DVPTR(TILE_PIRATE5A), PIRATE5A__STATIC, PIRATE5A__STATICRR },
    { "TILE_PIRATE3A", DVPTR(TILE_PIRATE3A), PIRATE3A__STATIC, PIRATE3A__STATICRR },
    { "TILE_PIRATE6A", DVPTR(TILE_PIRATE6A), PIRATE6A__STATIC, PIRATE6A__STATICRR },
    { "TILE_PIRATEHALF", DVPTR(TILE_PIRATEHALF), PIRATEHALF__STATIC, PIRATEHALF__STATICRR },
    { "TILE_CHESTOFGOLD", DVPTR(TILE_CHESTOFGOLD), CHESTOFGOLD__STATIC, CHESTOFGOLD__STATICRR },
    { "TILE_SIDEBOLT1", DVPTR(TILE_SIDEBOLT1), SIDEBOLT1__STATIC, SIDEBOLT1__STATICRR },
    { "TILE_FOODOBJECT1", DVPTR(TILE_FOODOBJECT1), FOODOBJECT1__STATIC, FOODOBJECT1__STATICRR },
    { "TILE_FOODOBJECT2", DVPTR(TILE_FOODOBJECT2), FOODOBJECT2__STATIC, FOODOBJECT2__STATICRR },
    { "TILE_FOODOBJECT3", DVPTR(TILE_FOODOBJECT3), FOODOBJECT3__STATIC, FOODOBJECT3__STATICRR },
    { "TILE_FOODOBJECT4", DVPTR(TILE_FOODOBJECT4), FOODOBJECT4__STATIC, FOODOBJECT4__STATICRR },
    { "TILE_FOODOBJECT5", DVPTR(TILE_FOODOBJECT5), FOODOBJECT5__STATIC, FOODOBJECT5__STATICRR },
    { "TILE_FOODOBJECT6", DVPTR(TILE_FOODOBJECT6), FOODOBJECT6__STATIC, FOODOBJECT6__STATICRR },
    { "TILE_FOODOBJECT7", DVPTR(TILE_FOODOBJECT7), FOODOBJECT7__STATIC, FOODOBJECT7__STATICRR },
    { "TILE_FOODOBJECT8", DVPTR(TILE_FOODOBJECT8), FOODOBJECT8__STATIC, FOODOBJECT8__STATICRR },
    { "TILE_FOODOBJECT9", DVPTR(TILE_FOODOBJECT9), FOODOBJECT9__STATIC, FOODOBJECT9__STATICRR },
    { "TILE_FOODOBJECT10", DVPTR(TILE_FOODOBJECT10), FOODOBJECT10__STATIC, FOODOBJECT10__STATICRR },
    { "TILE_FOODOBJECT11", DVPTR(TILE_FOODOBJECT11), FOODOBJECT11__STATIC, FOODOBJECT11__STATICRR },
    { "TILE_FOODOBJECT12", DVPTR(TILE_FOODOBJECT12), FOODOBJECT12__STATIC, FOODOBJECT12__STATICRR },
    { "TILE_FOODOBJECT13", DVPTR(TILE_FOODOBJECT13), FOODOBJECT13__STATIC, FOODOBJECT13__STATICRR },
    { "TILE_FOODOBJECT14", DVPTR(TILE_FOODOBJECT14), FOODOBJECT14__STATIC, FOODOBJECT14__STATICRR },
    { "TILE_FOODOBJECT15", DVPTR(TILE_FOODOBJECT15), FOODOBJECT15__STATIC, FOODOBJECT15__STATICRR },
    { "TILE_FOODOBJECT16", DVPTR(TILE_FOODOBJECT16), FOODOBJECT16__STATIC, FOODOBJECT16__STATICRR },
    { "TILE_FOODOBJECT17", DVPTR(TILE_FOODOBJECT17), FOODOBJECT17__STATIC, FOODOBJECT17__STATICRR },
    { "TILE_FOODOBJECT18", DVPTR(TILE_FOODOBJECT18), FOODOBJECT18__STATIC, FOODOBJECT18__STATICRR },
    { "TILE_FOODOBJECT19", DVPTR(TILE_FOODOBJECT19), FOODOBJECT19__STATIC, FOODOBJECT19__STATICRR },
    { "TILE_FOODOBJECT20", DVPTR(TILE_FOODOBJECT20), FOODOBJECT20__STATIC, FOODOBJECT20__STATICRR },
    { "TILE_HEADLAMP", DVPTR(TILE_HEADLAMP), HEADLAMP__STATIC, HEADLAMP__STATICRR },
    { "TILE_TAMPON", DVPTR(TILE_TAMPON), TAMPON__STATIC, TAMPON__STATICRR },
    { "TILE_SKINNEDCHICKEN", DVPTR(TILE_SKINNEDCHICKEN), SKINNEDCHICKEN__STATIC, SKINNEDCHICKEN__STATICRR },
    { "TILE_FEATHEREDCHICKEN", DVPTR(TILE_FEATHEREDCHICKEN), FEATHEREDCHICKEN__STATIC, FEATHEREDCHICKEN__STATICRR },
    { "TILE_ROBOTDOG2", DVPTR(TILE_ROBOTDOG2), ROBOTDOG2__STATIC, ROBOTDOG2__STATICRR },
    { "TILE_JOLLYMEAL", DVPTR(TILE_JOLLYMEAL), JOLLYMEAL__STATIC, JOLLYMEAL__STATICRR },
    { "TILE_DUKEBURGER", DVPTR(TILE_DUKEBURGER), DUKEBURGER__STATIC, DUKEBURGER__STATICRR },
    { "TILE_SHOPPINGCART", DVPTR(TILE_SHOPPINGCART), SHOPPINGCART__STATIC, SHOPPINGCART__STATICRR },
    { "TILE_CANWITHSOMETHING2", DVPTR(TILE_CANWITHSOMETHING2), CANWITHSOMETHING2__STATIC, CANWITHSOMETHING2__STATICRR },
    { "TILE_CANWITHSOMETHING3", DVPTR(TILE_CANWITHSOMETHING3), CANWITHSOMETHING3__STATIC, CANWITHSOMETHING3__STATICRR },
    { "TILE_CANWITHSOMETHING4", DVPTR(TILE_CANWITHSOMETHING4), CANWITHSOMETHING4__STATIC, CANWITHSOMETHING4__STATICRR },
    { "TILE_SNAKEP", DVPTR(TILE_SNAKEP), SNAKEP__STATIC, SNAKEP__STATICRR },
    { "TILE_DOLPHIN1", DVPTR(TILE_DOLPHIN1), DOLPHIN1__STATIC, DOLPHIN1__STATICRR },
    { "TILE_DOLPHIN2", DVPTR(TILE_DOLPHIN2), DOLPHIN2__STATIC, DOLPHIN2__STATICRR },
    { "TILE_NEWBEAST", DVPTR(TILE_NEWBEAST), NEWBEAST__STATIC, 0 },
    { "TILE_NEWBEASTSTAYPUT", DVPTR(TILE_NEWBEASTSTAYPUT), NEWBEASTSTAYPUT__STATIC, 0 },
    { "TILE_NEWBEASTJUMP", DVPTR(TILE_NEWBEASTJUMP), NEWBEASTJUMP__STATIC, 0 },
    { "TILE_NEWBEASTHANG", DVPTR(TILE_NEWBEASTHANG), NEWBEASTHANG__STATIC, 0 },
    { "TILE_NEWBEASTHANGDEAD", DVPTR(TILE_NEWBEASTHANGDEAD), NEWBEASTHANGDEAD__STATIC, 0 },
    { "TILE_BOSS4", DVPTR(TILE_BOSS4), BOSS4__STATIC, BOSS4__STATICRR },
    { "TILE_BOSS4STAYPUT", DVPTR(TILE_BOSS4STAYPUT), BOSS4STAYPUT__STATIC, 0 },
    { "TILE_FEM10", DVPTR(TILE_FEM10), FEM10__STATIC, FEM10__STATICRR },
    { "TILE_TOUGHGAL", DVPTR(TILE_TOUGHGAL), TOUGHGAL__STATIC, TOUGHGAL__STATICRR },
    { "TILE_MAN", DVPTR(TILE_MAN), MAN__STATIC, MAN__STATICRR },
    { "TILE_MAN2", DVPTR(TILE_MAN2), MAN2__STATIC, MAN2__STATICRR },
    { "TILE_WOMAN", DVPTR(TILE_WOMAN), WOMAN__STATIC, WOMAN__STATICRR },
    { "TILE_PLEASEWAIT", DVPTR(TILE_PLEASEWAIT), PLEASEWAIT__STATIC, PLEASEWAIT__STATICRR },
    { "TILE_NATURALLIGHTNING", DVPTR(TILE_NATURALLIGHTNING), NATURALLIGHTNING__STATIC, 0 },
    { "TILE_WEATHERWARN", DVPTR(TILE_WEATHERWARN), WEATHERWARN__STATIC, 0 },
    { "TILE_DUKETAG", DVPTR(TILE_DUKETAG), DUKETAG__STATIC, DUKETAG__STATICRR },
    { "TILE_SIGN1", DVPTR(TILE_SIGN1), SIGN1__STATIC, SIGN1__STATICRR },
    { "TILE_SIGN2", DVPTR(TILE_SIGN2), SIGN2__STATIC, SIGN2__STATICRR },
    { "TILE_JURYGUY", DVPTR(TILE_JURYGUY), JURYGUY__STATIC, JURYGUY__STATICRR },
    { "TILE_RRTILE11", DVPTR(TILE_RRTILE11), 0, RRTILE11__STATICRR },
    { "TILE_RPG2SPRITE", DVPTR(TILE_RPG2SPRITE), 0, RPG2SPRITE__STATICRR },
    { "TILE_RRTILE18", DVPTR(TILE_RRTILE18), 0, RRTILE18__STATICRR },
    { "TILE_RRTILE19", DVPTR(TILE_RRTILE19), 0, RRTILE19__STATICRR },
    { "TILE_RRTILE34", DVPTR(TILE_RRTILE34), 0, RRTILE34__STATICRR },
    { "TILE_RRTILE35", DVPTR(TILE_RRTILE35), 0, RRTILE35__STATICRR },
    { "TILE_DESTRUCTO", DVPTR(TILE_DESTRUCTO), 0, DESTRUCTO__STATICRR },
    { "TILE_RRTILE38", DVPTR(TILE_RRTILE38), 0, RRTILE38__STATICRR },
    { "TILE_RRTILE43", DVPTR(TILE_RRTILE43), 0, RRTILE43__STATICRR },
    { "TILE_GUTMETER", DVPTR(TILE_GUTMETER), 0, GUTMETER__STATICRR },
    { "TILE_RRTILE63", DVPTR(TILE_RRTILE63), 0, RRTILE63__STATICRR },
    { "TILE_RRTILE64", DVPTR(TILE_RRTILE64), 0, RRTILE64__STATICRR },
    { "TILE_RRTILE65", DVPTR(TILE_RRTILE65), 0, RRTILE65__STATICRR },
    { "TILE_RRTILE66", DVPTR(TILE_RRTILE66), 0, RRTILE66__STATICRR },
    { "TILE_RRTILE67", DVPTR(TILE_RRTILE67), 0, RRTILE67__STATICRR },
    { "TILE_RRTILE68", DVPTR(TILE_RRTILE68), 0, RRTILE68__STATICRR },
    { "TILE_SOUNDFX", DVPTR(TILE_SOUNDFX), 0, SOUNDFX__STATICRR },
    { "TILE_MOTOAMMO", DVPTR(TILE_MOTOAMMO), 0, MOTOAMMO__STATICRR },
    { "TILE_UFOBEAM", DVPTR(TILE_UFOBEAM), 0, UFOBEAM__STATICRR },
    { "TILE_RRTILE280", DVPTR(TILE_RRTILE280), 0, RRTILE280__STATICRR },
    { "TILE_RRTILE281", DVPTR(TILE_RRTILE281), 0, RRTILE281__STATICRR },
    { "TILE_RRTILE282", DVPTR(TILE_RRTILE282), 0, RRTILE282__STATICRR },
    { "TILE_RRTILE283", DVPTR(TILE_RRTILE283), 0, RRTILE283__STATICRR },
    { "TILE_RRTILE285", DVPTR(TILE_RRTILE285), 0, RRTILE285__STATICRR },
    { "TILE_RRTILE286", DVPTR(TILE_RRTILE286), 0, RRTILE286__STATICRR },
    { "TILE_RRTILE287", DVPTR(TILE_RRTILE287), 0, RRTILE287__STATICRR },
    { "TILE_RRTILE288", DVPTR(TILE_RRTILE288), 0, RRTILE288__STATICRR },
    { "TILE_RRTILE289", DVPTR(TILE_RRTILE289), 0, RRTILE289__STATICRR },
    { "TILE_RRTILE290", DVPTR(TILE_RRTILE290), 0, RRTILE290__STATICRR },
    { "TILE_RRTILE291", DVPTR(TILE_RRTILE291), 0, RRTILE291__STATICRR },
    { "TILE_RRTILE292", DVPTR(TILE_RRTILE292), 0, RRTILE292__STATICRR },
    { "TILE_RRTILE293", DVPTR(TILE_RRTILE293), 0, RRTILE293__STATICRR },
    { "TILE_RRTILE295", DVPTR(TILE_RRTILE295), 0, RRTILE295__STATICRR },
    { "TILE_RRTILE296", DVPTR(TILE_RRTILE296), 0, RRTILE296__STATICRR },
    { "TILE_RRTILE297", DVPTR(TILE_RRTILE297), 0, RRTILE297__STATICRR },
    { "TILE_CDPLAYER", DVPTR(TILE_CDPLAYER), 0, CDPLAYER__STATICRR },
    { "TILE_RRTILE380", DVPTR(TILE_RRTILE380), 0, RRTILE380__STATICRR },
    { "TILE_RRTILE403", DVPTR(TILE_RRTILE403), 0, RRTILE403__STATICRR },
    { "TILE_RRTILE409", DVPTR(TILE_RRTILE409), 0, RRTILE409__STATICRR },
    { "TILE_GUTMETER_LIGHT1", DVPTR(TILE_GUTMETER_LIGHT1), 0, GUTMETER_LIGHT1__STATICRR },
    { "TILE_GUTMETER_LIGHT2", DVPTR(TILE_GUTMETER_LIGHT2), 0, GUTMETER_LIGHT2__STATICRR },
    { "TILE_GUTMETER_LIGHT3", DVPTR(TILE_GUTMETER_LIGHT3), 0, GUTMETER_LIGHT3__STATICRR },
    { "TILE_GUTMETER_LIGHT4", DVPTR(TILE_GUTMETER_LIGHT4), 0, GUTMETER_LIGHT4__STATICRR },
    { "TILE_AMMO_ICON", DVPTR(TILE_AMMO_ICON), 0, AMMO_ICON__STATICRR },
    { "TILE_RRTILE409", DVPTR(TILE_RRTILE1076), 0, RRTILE1076__STATICRR },
    { "TILE_MUD", DVPTR(TILE_MUD), 0, MUD__STATICRR },
    { "TILE_EXPLOSION3", DVPTR(TILE_EXPLOSION3), 0, EXPLOSION3__STATICRR },
    { "TILE_RRTILE1636", DVPTR(TILE_RRTILE1636), 0, RRTILE1636__STATICRR },
    { "TILE_WEAPONBAR", DVPTR(TILE_WEAPONBAR), 0, WEAPONBAR__STATICRR },
    { "TILE_RRTILE1752", DVPTR(TILE_RRTILE1752), 0, RRTILE1752__STATICRR },
    { "TILE_RPG2", DVPTR(TILE_RPG2), 0, RPG2__STATICRR },
    { "TILE_RRTILE1790", DVPTR(TILE_RRTILE1790), 0, RRTILE1790__STATICRR },
    { "TILE_RRTILE1792", DVPTR(TILE_RRTILE1792), 0, RRTILE1792__STATICRR },
    { "TILE_RRTILE1801", DVPTR(TILE_RRTILE1801), 0, RRTILE1801__STATICRR },
    { "TILE_RRTILE1805", DVPTR(TILE_RRTILE1805), 0, RRTILE1805__STATICRR },
    { "TILE_RRTILE1807", DVPTR(TILE_RRTILE1807), 0, RRTILE1807__STATICRR },
    { "TILE_RRTILE1808", DVPTR(TILE_RRTILE1808), 0, RRTILE1808__STATICRR },
    { "TILE_RRTILE1812", DVPTR(TILE_RRTILE1812), 0, RRTILE1812__STATICRR },
    { "TILE_RRTILE1814", DVPTR(TILE_RRTILE1814), 0, RRTILE1814__STATICRR },
    { "TILE_RRTILE1817", DVPTR(TILE_RRTILE1817), 0, RRTILE1817__STATICRR },
    { "TILE_RRTILE1821", DVPTR(TILE_RRTILE1821), 0, RRTILE1821__STATICRR },
    { "TILE_RRTILE1824", DVPTR(TILE_RRTILE1824), 0, RRTILE1824__STATICRR },
    { "TILE_RRTILE1826", DVPTR(TILE_RRTILE1826), 0, RRTILE1826__STATICRR },
    { "TILE_RRTILE1850", DVPTR(TILE_RRTILE1850), 0, RRTILE1850__STATICRR },
    { "TILE_RRTILE1851", DVPTR(TILE_RRTILE1851), 0, RRTILE1851__STATICRR },
    { "TILE_RRTILE1856", DVPTR(TILE_RRTILE1856), 0, RRTILE1856__STATICRR },
    { "TILE_RRTILE1877", DVPTR(TILE_RRTILE1877), 0, RRTILE1877__STATICRR },
    { "TILE_RRTILE1878", DVPTR(TILE_RRTILE1878), 0, RRTILE1878__STATICRR },
    { "TILE_RRTILE1938", DVPTR(TILE_RRTILE1938), 0, RRTILE1938__STATICRR },
    { "TILE_RRTILE1939", DVPTR(TILE_RRTILE1939), 0, RRTILE1939__STATICRR },
    { "TILE_RRTILE1942", DVPTR(TILE_RRTILE1942), 0, RRTILE1942__STATICRR },
    { "TILE_RRTILE1944", DVPTR(TILE_RRTILE1944), 0, RRTILE1944__STATICRR },
    { "TILE_RRTILE1945", DVPTR(TILE_RRTILE1945), 0, RRTILE1945__STATICRR },
    { "TILE_RRTILE1947", DVPTR(TILE_RRTILE1947), 0, RRTILE1947__STATICRR },
    { "TILE_RRTILE1951", DVPTR(TILE_RRTILE1951), 0, RRTILE1951__STATICRR },
    { "TILE_RRTILE1952", DVPTR(TILE_RRTILE1952), 0, RRTILE1952__STATICRR },
    { "TILE_RRTILE1953", DVPTR(TILE_RRTILE1953), 0, RRTILE1953__STATICRR },
    { "TILE_RRTILE1961", DVPTR(TILE_RRTILE1961), 0, RRTILE1961__STATICRR },
    { "TILE_RRTILE1964", DVPTR(TILE_RRTILE1964), 0, RRTILE1964__STATICRR },
    { "TILE_RRTILE1973", DVPTR(TILE_RRTILE1973), 0, RRTILE1973__STATICRR },
    { "TILE_RRTILE1985", DVPTR(TILE_RRTILE1985), 0, RRTILE1985__STATICRR },
    { "TILE_RRTILE1986", DVPTR(TILE_RRTILE1986), 0, RRTILE1986__STATICRR },
    { "TILE_RRTILE1987", DVPTR(TILE_RRTILE1987), 0, RRTILE1987__STATICRR },
    { "TILE_RRTILE1988", DVPTR(TILE_RRTILE1988), 0, RRTILE1988__STATICRR },
    { "TILE_RRTILE1990", DVPTR(TILE_RRTILE1990), 0, RRTILE1990__STATICRR },
    { "TILE_RRTILE1995", DVPTR(TILE_RRTILE1995), 0, RRTILE1995__STATICRR },
    { "TILE_RRTILE1996", DVPTR(TILE_RRTILE1996), 0, RRTILE1996__STATICRR },
    { "TILE_RRTILE2004", DVPTR(TILE_RRTILE2004), 0, RRTILE2004__STATICRR },
    { "TILE_RRTILE2005", DVPTR(TILE_RRTILE2005), 0, RRTILE2005__STATICRR },
    { "TILE_POPCORN", DVPTR(TILE_POPCORN), 0, POPCORN__STATICRR },
    { "TILE_RRTILE2022", DVPTR(TILE_RRTILE2022), 0, RRTILE2022__STATICRR },
    { "TILE_LANEPICS", DVPTR(TILE_LANEPICS), 0, LANEPICS__STATICRR },
    { "TILE_RRTILE2025", DVPTR(TILE_RRTILE2025), 0, RRTILE2025__STATICRR },
    { "TILE_RRTILE2026", DVPTR(TILE_RRTILE2026), 0, RRTILE2026__STATICRR },
    { "TILE_RRTILE2027", DVPTR(TILE_RRTILE2027), 0, RRTILE2027__STATICRR },
    { "TILE_RRTILE2028", DVPTR(TILE_RRTILE2028), 0, RRTILE2028__STATICRR },
    { "TILE_RRTILE2034", DVPTR(TILE_RRTILE2034), 0, RRTILE2034__STATICRR },
    { "TILE_RRTILE2050", DVPTR(TILE_RRTILE2050), 0, RRTILE2050__STATICRR },
    { "TILE_RRTILE2052", DVPTR(TILE_RRTILE2052), 0, RRTILE2052__STATICRR },
    { "TILE_RRTILE2053", DVPTR(TILE_RRTILE2053), 0, RRTILE2053__STATICRR },
    { "TILE_RRTILE2056", DVPTR(TILE_RRTILE2056), 0, RRTILE2056__STATICRR },
    { "TILE_RRTILE2060", DVPTR(TILE_RRTILE2060), 0, RRTILE2060__STATICRR },
    { "TILE_RRTILE2072", DVPTR(TILE_RRTILE2072), 0, RRTILE2072__STATICRR },
    { "TILE_RRTILE2074", DVPTR(TILE_RRTILE2074), 0, RRTILE2074__STATICRR },
    { "TILE_RRTILE2075", DVPTR(TILE_RRTILE2075), 0, RRTILE2075__STATICRR },
    { "TILE_RRTILE2083", DVPTR(TILE_RRTILE2083), 0, RRTILE2083__STATICRR },
    { "TILE_RRTILE2097", DVPTR(TILE_RRTILE2097), 0, RRTILE2097__STATICRR },
    { "TILE_RRTILE2121", DVPTR(TILE_RRTILE2121), 0, RRTILE2121__STATICRR },
    { "TILE_RRTILE2122", DVPTR(TILE_RRTILE2122), 0, RRTILE2122__STATICRR },
    { "TILE_RRTILE2123", DVPTR(TILE_RRTILE2123), 0, RRTILE2123__STATICRR },
    { "TILE_RRTILE2124", DVPTR(TILE_RRTILE2124), 0, RRTILE2124__STATICRR },
    { "TILE_RRTILE2125", DVPTR(TILE_RRTILE2125), 0, RRTILE2125__STATICRR },
    { "TILE_RRTILE2126", DVPTR(TILE_RRTILE2126), 0, RRTILE2126__STATICRR },
    { "TILE_RRTILE2137", DVPTR(TILE_RRTILE2137), 0, RRTILE2137__STATICRR },
    { "TILE_RRTILE2132", DVPTR(TILE_RRTILE2132), 0, RRTILE2132__STATICRR },
    { "TILE_RRTILE2136", DVPTR(TILE_RRTILE2136), 0, RRTILE2136__STATICRR },
    { "TILE_RRTILE2139", DVPTR(TILE_RRTILE2139), 0, RRTILE2139__STATICRR },
    { "TILE_RRTILE2150", DVPTR(TILE_RRTILE2150), 0, RRTILE2150__STATICRR },
    { "TILE_RRTILE2151", DVPTR(TILE_RRTILE2151), 0, RRTILE2151__STATICRR },
    { "TILE_RRTILE2152", DVPTR(TILE_RRTILE2152), 0, RRTILE2152__STATICRR },
    { "TILE_RRTILE2156", DVPTR(TILE_RRTILE2156), 0, RRTILE2156__STATICRR },
    { "TILE_RRTILE2157", DVPTR(TILE_RRTILE2157), 0, RRTILE2157__STATICRR },
    { "TILE_RRTILE2158", DVPTR(TILE_RRTILE2158), 0, RRTILE2158__STATICRR },
    { "TILE_RRTILE2159", DVPTR(TILE_RRTILE2159), 0, RRTILE2159__STATICRR },
    { "TILE_RRTILE2160", DVPTR(TILE_RRTILE2160), 0, RRTILE2160__STATICRR },
    { "TILE_RRTILE2161", DVPTR(TILE_RRTILE2161), 0, RRTILE2161__STATICRR },
    { "TILE_RRTILE2175", DVPTR(TILE_RRTILE2175), 0, RRTILE2175__STATICRR },
    { "TILE_RRTILE2176", DVPTR(TILE_RRTILE2176), 0, RRTILE2176__STATICRR },
    { "TILE_RRTILE2178", DVPTR(TILE_RRTILE2178), 0, RRTILE2178__STATICRR },
    { "TILE_RRTILE2186", DVPTR(TILE_RRTILE2186), 0, RRTILE2186__STATICRR },
    { "TILE_RRTILE2214", DVPTR(TILE_RRTILE2214), 0, RRTILE2214__STATICRR },
    { "TILE_RRTILE2319", DVPTR(TILE_RRTILE2319), 0, RRTILE2319__STATICRR },
    { "TILE_RRTILE2321", DVPTR(TILE_RRTILE2321), 0, RRTILE2321__STATICRR },
    { "TILE_RRTILE2326", DVPTR(TILE_RRTILE2326), 0, RRTILE2326__STATICRR },
    { "TILE_RRTILE2329", DVPTR(TILE_RRTILE2329), 0, RRTILE2329__STATICRR },
    { "TILE_RRTILE2357", DVPTR(TILE_RRTILE2357), 0, RRTILE2357__STATICRR },
    { "TILE_RRTILE2382", DVPTR(TILE_RRTILE2382), 0, RRTILE2382__STATICRR },
    { "TILE_RRTILE2430", DVPTR(TILE_RRTILE2430), 0, RRTILE2430__STATICRR },
    { "TILE_RRTILE2431", DVPTR(TILE_RRTILE2431), 0, RRTILE2431__STATICRR },
    { "TILE_RRTILE2432", DVPTR(TILE_RRTILE2432), 0, RRTILE2432__STATICRR },
    { "TILE_RRTILE2437", DVPTR(TILE_RRTILE2437), 0, RRTILE2437__STATICRR },
    { "TILE_RRTILE2443", DVPTR(TILE_RRTILE2443), 0, RRTILE2443__STATICRR },
    { "TILE_RRTILE2445", DVPTR(TILE_RRTILE2445), 0, RRTILE2445__STATICRR },
    { "TILE_RRTILE2446", DVPTR(TILE_RRTILE2446), 0, RRTILE2446__STATICRR },
    { "TILE_RRTILE2450", DVPTR(TILE_RRTILE2450), 0, RRTILE2450__STATICRR },
    { "TILE_RRTILE2451", DVPTR(TILE_RRTILE2451), 0, RRTILE2451__STATICRR },
    { "TILE_RRTILE2455", DVPTR(TILE_RRTILE2455), 0, RRTILE2455__STATICRR },
    { "TILE_RRTILE2460", DVPTR(TILE_RRTILE2460), 0, RRTILE2460__STATICRR },
    { "TILE_RRTILE2465", DVPTR(TILE_RRTILE2465), 0, RRTILE2465__STATICRR },
    { "TILE_RRTILE2560", DVPTR(TILE_RRTILE2560), 0, RRTILE2560__STATICRR },
    { "TILE_RRTILE2562", DVPTR(TILE_RRTILE2562), 0, RRTILE2562__STATICRR },
    { "TILE_RRTILE2564", DVPTR(TILE_RRTILE2564), 0, RRTILE2564__STATICRR },
    { "TILE_RRTILE2573", DVPTR(TILE_RRTILE2573), 0, RRTILE2573__STATICRR },
    { "TILE_RRTILE2574", DVPTR(TILE_RRTILE2574), 0, RRTILE2574__STATICRR },
    { "TILE_RRTILE2577", DVPTR(TILE_RRTILE2577), 0, RRTILE2577__STATICRR },
    { "TILE_RRTILE2578", DVPTR(TILE_RRTILE2578), 0, RRTILE2578__STATICRR },
    { "TILE_RRTILE2581", DVPTR(TILE_RRTILE2581), 0, RRTILE2581__STATICRR },
    { "TILE_RRTILE2583", DVPTR(TILE_RRTILE2583), 0, RRTILE2583__STATICRR },
    { "TILE_RRTILE2604", DVPTR(TILE_RRTILE2604), 0, RRTILE2604__STATICRR },
    { "TILE_RRTILE2610", DVPTR(TILE_RRTILE2610), 0, RRTILE2610__STATICRR },
    { "TILE_RRTILE2613", DVPTR(TILE_RRTILE2613), 0, RRTILE2613__STATICRR },
    { "TILE_RRTILE2621", DVPTR(TILE_RRTILE2621), 0, RRTILE2621__STATICRR },
    { "TILE_RRTILE2622", DVPTR(TILE_RRTILE2622), 0, RRTILE2622__STATICRR },
    { "TILE_RRTILE2636", DVPTR(TILE_RRTILE2636), 0, RRTILE2636__STATICRR },
    { "TILE_RRTILE2637", DVPTR(TILE_RRTILE2637), 0, RRTILE2637__STATICRR },
    { "TILE_RRTILE2654", DVPTR(TILE_RRTILE2654), 0, RRTILE2654__STATICRR },
    { "TILE_RRTILE2656", DVPTR(TILE_RRTILE2656), 0, RRTILE2656__STATICRR },
    { "TILE_RRTILE2676", DVPTR(TILE_RRTILE2676), 0, RRTILE2676__STATICRR },
    { "TILE_RRTILE2689", DVPTR(TILE_RRTILE2689), 0, RRTILE2689__STATICRR },
    { "TILE_RRTILE2697", DVPTR(TILE_RRTILE2697), 0, RRTILE2697__STATICRR },
    { "TILE_RRTILE2702", DVPTR(TILE_RRTILE2702), 0, RRTILE2702__STATICRR },
    { "TILE_RRTILE2707", DVPTR(TILE_RRTILE2707), 0, RRTILE2707__STATICRR },
    { "TILE_RRTILE2732", DVPTR(TILE_RRTILE2732), 0, RRTILE2732__STATICRR },
    { "TILE_RRTILE2030", DVPTR(TILE_RRTILE2030), 0, RRTILE2030__STATICRR },
    { "TILE_RRTILE2831", DVPTR(TILE_RRTILE2831), 0, RRTILE2831__STATICRR },
    { "TILE_RRTILE2832", DVPTR(TILE_RRTILE2832), 0, RRTILE2832__STATICRR },
    { "TILE_RRTILE2842", DVPTR(TILE_RRTILE2842), 0, RRTILE2842__STATICRR },
    { "TILE_RRTILE2859", DVPTR(TILE_RRTILE2859), 0, RRTILE2859__STATICRR },
    { "TILE_RRTILE2876", DVPTR(TILE_RRTILE2876), 0, RRTILE2876__STATICRR },
    { "TILE_RRTILE2878", DVPTR(TILE_RRTILE2878), 0, RRTILE2878__STATICRR },
    { "TILE_RRTILE2879", DVPTR(TILE_RRTILE2879), 0, RRTILE2879__STATICRR },
    { "TILE_RRTILE2893", DVPTR(TILE_RRTILE2893), 0, RRTILE2893__STATICRR },
    { "TILE_RRTILE2894", DVPTR(TILE_RRTILE2894), 0, RRTILE2894__STATICRR },
    { "TILE_RRTILE2898", DVPTR(TILE_RRTILE2898), 0, RRTILE2898__STATICRR },
    { "TILE_RRTILE2899", DVPTR(TILE_RRTILE2899), 0, RRTILE2899__STATICRR },
    { "TILE_RRTILE2915", DVPTR(TILE_RRTILE2915), 0, RRTILE2915__STATICRR },
    { "TILE_RRTILE2940", DVPTR(TILE_RRTILE2940), 0, RRTILE2940__STATICRR },
    { "TILE_RRTILE2944", DVPTR(TILE_RRTILE2944), 0, RRTILE2944__STATICRR },
    { "TILE_RRTILE2945", DVPTR(TILE_RRTILE2945), 0, RRTILE2945__STATICRR },
    { "TILE_RRTILE2946", DVPTR(TILE_RRTILE2946), 0, RRTILE2946__STATICRR },
    { "TILE_RRTILE2947", DVPTR(TILE_RRTILE2947), 0, RRTILE2947__STATICRR },
    { "TILE_RRTILE2948", DVPTR(TILE_RRTILE2948), 0, RRTILE2948__STATICRR },
    { "TILE_RRTILE2949", DVPTR(TILE_RRTILE2949), 0, RRTILE2949__STATICRR },
    { "TILE_RRTILE2961", DVPTR(TILE_RRTILE2961), 0, RRTILE2961__STATICRR },
    { "TILE_RRTILE2970", DVPTR(TILE_RRTILE2970), 0, RRTILE2970__STATICRR },
    { "TILE_RRTILE2977", DVPTR(TILE_RRTILE2977), 0, RRTILE2977__STATICRR },
    { "TILE_RRTILE2978", DVPTR(TILE_RRTILE2978), 0, RRTILE2978__STATICRR },
    { "TILE_RRTILE2990", DVPTR(TILE_RRTILE2990), 0, RRTILE2990__STATICRR },
    { "TILE_RRTILE3073", DVPTR(TILE_RRTILE3073), 0, RRTILE3073__STATICRR },
    { "TILE_RRTILE3083", DVPTR(TILE_RRTILE3083), 0, RRTILE3083__STATICRR },
    { "TILE_RRTILE3100", DVPTR(TILE_RRTILE3100), 0, RRTILE3100__STATICRR },
    { "TILE_RRTILE3114", DVPTR(TILE_RRTILE3114), 0, RRTILE3114__STATICRR },
    { "TILE_RRTILE3115", DVPTR(TILE_RRTILE3115), 0, RRTILE3115__STATICRR },
    { "TILE_RRTILE3116", DVPTR(TILE_RRTILE3116), 0, RRTILE3116__STATICRR },
    { "TILE_RRTILE3117", DVPTR(TILE_RRTILE3117), 0, RRTILE3117__STATICRR },
    { "TILE_RRTILE3120", DVPTR(TILE_RRTILE3120), 0, RRTILE3120__STATICRR },
    { "TILE_RRTILE3121", DVPTR(TILE_RRTILE3121), 0, RRTILE3121__STATICRR },
    { "TILE_RRTILE3122", DVPTR(TILE_RRTILE3122), 0, RRTILE3122__STATICRR },
    { "TILE_RRTILE3123", DVPTR(TILE_RRTILE3123), 0, RRTILE3123__STATICRR },
    { "TILE_RRTILE3124", DVPTR(TILE_RRTILE3124), 0, RRTILE3124__STATICRR },
    { "TILE_RRTILE3132", DVPTR(TILE_RRTILE3132), 0, RRTILE3132__STATICRR },
    { "TILE_RRTILE3139", DVPTR(TILE_RRTILE3139), 0, RRTILE3139__STATICRR },
    { "TILE_RRTILE3144", DVPTR(TILE_RRTILE3144), 0, RRTILE3144__STATICRR },
    { "TILE_RRTILE3152", DVPTR(TILE_RRTILE3152), 0, RRTILE3152__STATICRR },
    { "TILE_RRTILE3153", DVPTR(TILE_RRTILE3153), 0, RRTILE3153__STATICRR },
    { "TILE_RRTILE3155", DVPTR(TILE_RRTILE3155), 0, RRTILE3155__STATICRR },
    { "TILE_RRTILE3171", DVPTR(TILE_RRTILE3171), 0, RRTILE3171__STATICRR },
    { "TILE_RRTILE3172", DVPTR(TILE_RRTILE3172), 0, RRTILE3172__STATICRR },
    { "TILE_RRTILE3190", DVPTR(TILE_RRTILE3190), 0, RRTILE3190__STATICRR },
    { "TILE_RRTILE3191", DVPTR(TILE_RRTILE3191), 0, RRTILE3191__STATICRR },
    { "TILE_RRTILE3192", DVPTR(TILE_RRTILE3192), 0, RRTILE3192__STATICRR },
    { "TILE_RRTILE3195", DVPTR(TILE_RRTILE3195), 0, RRTILE3195__STATICRR },
    { "TILE_RRTILE3200", DVPTR(TILE_RRTILE3200), 0, RRTILE3200__STATICRR },
    { "TILE_RRTILE3201", DVPTR(TILE_RRTILE3201), 0, RRTILE3201__STATICRR },
    { "TILE_RRTILE3202", DVPTR(TILE_RRTILE3202), 0, RRTILE3202__STATICRR },
    { "TILE_RRTILE3203", DVPTR(TILE_RRTILE3203), 0, RRTILE3203__STATICRR },
    { "TILE_RRTILE3204", DVPTR(TILE_RRTILE3204), 0, RRTILE3204__STATICRR },
    { "TILE_RRTILE3205", DVPTR(TILE_RRTILE3205), 0, RRTILE3205__STATICRR },
    { "TILE_RRTILE3206", DVPTR(TILE_RRTILE3206), 0, RRTILE3206__STATICRR },
    { "TILE_RRTILE3207", DVPTR(TILE_RRTILE3207), 0, RRTILE3207__STATICRR },
    { "TILE_RRTILE3208", DVPTR(TILE_RRTILE3208), 0, RRTILE3208__STATICRR },
    { "TILE_RRTILE3209", DVPTR(TILE_RRTILE3209), 0, RRTILE3209__STATICRR },
    { "TILE_RRTILE3216", DVPTR(TILE_RRTILE3216), 0, RRTILE3216__STATICRR },
    { "TILE_RRTILE3218", DVPTR(TILE_RRTILE3218), 0, RRTILE3218__STATICRR },
    { "TILE_RRTILE3219", DVPTR(TILE_RRTILE3219), 0, RRTILE3219__STATICRR },
    { "TILE_RRTILE3232", DVPTR(TILE_RRTILE3232), 0, RRTILE3232__STATICRR },
    { "TILE_SHOTGUNSHELLS", DVPTR(TILE_SHOTGUNSHELLS), 0, SHOTGUNSHELLS__STATICRR },
    { "TILE_CIRCLESTUCK", DVPTR(TILE_CIRCLESTUCK), 0, CIRCLESTUCK__STATICRR },
    { "TILE_RRTILE3410", DVPTR(TILE_RRTILE3410), 0, RRTILE3410__STATICRR },
    { "TILE_LUMBERBLADE", DVPTR(TILE_LUMBERBLADE), 0, LUMBERBLADE__STATICRR },
    { "TILE_BOWLINGBALLH", DVPTR(TILE_BOWLINGBALLH), 0, BOWLINGBALLH__STATICRR },
    { "TILE_BOWLINGBALL", DVPTR(TILE_BOWLINGBALL), 0, BOWLINGBALL__STATICRR },
    { "TILE_BOWLINGBALLSPRITE", DVPTR(TILE_BOWLINGBALLSPRITE), 0, BOWLINGBALLSPRITE__STATICRR },
    { "TILE_POWDERH", DVPTR(TILE_POWDERH), 0, POWDERH__STATICRR },
    { "TILE_RRTILE3440", DVPTR(TILE_RRTILE3440), 0, RRTILE3440__STATICRR },
    { "TILE_RRTILE3462", DVPTR(TILE_RRTILE3462), 0, RRTILE3462__STATICRR },
    { "TILE_OWHIP", DVPTR(TILE_OWHIP), 0, OWHIP__STATICRR },
    { "TILE_UWHIP", DVPTR(TILE_UWHIP), 0, UWHIP__STATICRR },
    { "TILE_RPGGUN2", DVPTR(TILE_RPGGUN2), 0, RPGGUN2__STATICRR },
    { "TILE_RRTILE3497", DVPTR(TILE_RRTILE3497), 0, RRTILE3497__STATICRR },
    { "TILE_RRTILE3498", DVPTR(TILE_RRTILE3498), 0, RRTILE3498__STATICRR },
    { "TILE_RRTILE3499", DVPTR(TILE_RRTILE3499), 0, RRTILE3499__STATICRR },
    { "TILE_RRTILE3500", DVPTR(TILE_RRTILE3500), 0, RRTILE3500__STATICRR },
    { "TILE_SLINGBLADE", DVPTR(TILE_SLINGBLADE), 0, SLINGBLADE__STATICRR },
    { "TILE_RRTILE3584", DVPTR(TILE_RRTILE3584), 0, RRTILE3584__STATICRR },
    { "TILE_RRTILE3586", DVPTR(TILE_RRTILE3586), 0, RRTILE3586__STATICRR },
    { "TILE_RRTILE3587", DVPTR(TILE_RRTILE3587), 0, RRTILE3587__STATICRR },
    { "TILE_RRTILE3600", DVPTR(TILE_RRTILE3600), 0, RRTILE3600__STATICRR },
    { "TILE_RRTILE3631", DVPTR(TILE_RRTILE3631), 0, RRTILE3631__STATICRR },
    { "TILE_RRTILE3635", DVPTR(TILE_RRTILE3635), 0, RRTILE3635__STATICRR },
    { "TILE_RRTILE3637", DVPTR(TILE_RRTILE3637), 0, RRTILE3637__STATICRR },
    { "TILE_RRTILE3643", DVPTR(TILE_RRTILE3643), 0, RRTILE3643__STATICRR },
    { "TILE_RRTILE3647", DVPTR(TILE_RRTILE3647), 0, RRTILE3647__STATICRR },
    { "TILE_RRTILE3652", DVPTR(TILE_RRTILE3652), 0, RRTILE3652__STATICRR },
    { "TILE_RRTILE3653", DVPTR(TILE_RRTILE3653), 0, RRTILE3653__STATICRR },
    { "TILE_RRTILE3668", DVPTR(TILE_RRTILE3668), 0, RRTILE3668__STATICRR },
    { "TILE_RRTILE3671", DVPTR(TILE_RRTILE3671), 0, RRTILE3671__STATICRR },
    { "TILE_RRTILE3673", DVPTR(TILE_RRTILE3673), 0, RRTILE3673__STATICRR },
    { "TILE_RRTILE3677", DVPTR(TILE_RRTILE3677), 0, RRTILE3677__STATICRR },
    { "TILE_RRTILE3684", DVPTR(TILE_RRTILE3684), 0, RRTILE3684__STATICRR },
    { "TILE_RRTILE3708", DVPTR(TILE_RRTILE3708), 0, RRTILE3708__STATICRR },
    { "TILE_RRTILE3714", DVPTR(TILE_RRTILE3714), 0, RRTILE3714__STATICRR },
    { "TILE_RRTILE3716", DVPTR(TILE_RRTILE3716), 0, RRTILE3716__STATICRR },
    { "TILE_RRTILE3720", DVPTR(TILE_RRTILE3720), 0, RRTILE3720__STATICRR },
    { "TILE_RRTILE3723", DVPTR(TILE_RRTILE3723), 0, RRTILE3723__STATICRR },
    { "TILE_RRTILE3725", DVPTR(TILE_RRTILE3725), 0, RRTILE3725__STATICRR },
    { "TILE_RRTILE3737", DVPTR(TILE_RRTILE3737), 0, RRTILE3737__STATICRR },
    { "TILE_RRTILE3754", DVPTR(TILE_RRTILE3754), 0, RRTILE3754__STATICRR },
    { "TILE_RRTILE3762", DVPTR(TILE_RRTILE3762), 0, RRTILE3762__STATICRR },
    { "TILE_RRTILE3763", DVPTR(TILE_RRTILE3763), 0, RRTILE3763__STATICRR },
    { "TILE_RRTILE3764", DVPTR(TILE_RRTILE3764), 0, RRTILE3764__STATICRR },
    { "TILE_RRTILE3765", DVPTR(TILE_RRTILE3765), 0, RRTILE3765__STATICRR },
    { "TILE_RRTILE3767", DVPTR(TILE_RRTILE3767), 0, RRTILE3767__STATICRR },
    { "TILE_RRTILE3773", DVPTR(TILE_RRTILE3773), 0, RRTILE3773__STATICRR },
    { "TILE_RRTILE3774", DVPTR(TILE_RRTILE3774), 0, RRTILE3774__STATICRR },
    { "TILE_RRTILE3793", DVPTR(TILE_RRTILE3793), 0, RRTILE3793__STATICRR },
    { "TILE_RRTILE3795", DVPTR(TILE_RRTILE3795), 0, RRTILE3795__STATICRR },
    { "TILE_RRTILE3804", DVPTR(TILE_RRTILE3804), 0, RRTILE3804__STATICRR },
    { "TILE_RRTILE3814", DVPTR(TILE_RRTILE3814), 0, RRTILE3814__STATICRR },
    { "TILE_RRTILE3815", DVPTR(TILE_RRTILE3815), 0, RRTILE3815__STATICRR },
    { "TILE_RRTILE3819", DVPTR(TILE_RRTILE3819), 0, RRTILE3819__STATICRR },
    { "TILE_RRTILE3827", DVPTR(TILE_RRTILE3827), 0, RRTILE3827__STATICRR },
    { "TILE_RRTILE3837", DVPTR(TILE_RRTILE3837), 0, RRTILE3837__STATICRR },
    { "TILE_RRTILE5014", DVPTR(TILE_RRTILE5014), 0, RRTILE5014__STATICRR },
    { "TILE_RRTILE5016", DVPTR(TILE_RRTILE5016), 0, RRTILE5016__STATICRR },
    { "TILE_RRTILE5017", DVPTR(TILE_RRTILE5017), 0, RRTILE5017__STATICRR },
    { "TILE_RRTILE5018", DVPTR(TILE_RRTILE5018), 0, RRTILE5018__STATICRR },
    { "TILE_RRTILE5019", DVPTR(TILE_RRTILE5019), 0, RRTILE5019__STATICRR },
    { "TILE_RRTILE5020", DVPTR(TILE_RRTILE5020), 0, RRTILE5020__STATICRR },
    { "TILE_RRTILE5021", DVPTR(TILE_RRTILE5021), 0, RRTILE5021__STATICRR },
    { "TILE_RRTILE5022", DVPTR(TILE_RRTILE5022), 0, RRTILE5022__STATICRR },
    { "TILE_RRTILE5023", DVPTR(TILE_RRTILE5023), 0, RRTILE5023__STATICRR },
    { "TILE_RRTILE5024", DVPTR(TILE_RRTILE5024), 0, RRTILE5024__STATICRR },
    { "TILE_RRTILE5025", DVPTR(TILE_RRTILE5025), 0, RRTILE5025__STATICRR },
    { "TILE_RRTILE5026", DVPTR(TILE_RRTILE5026), 0, RRTILE5026__STATICRR },
    { "TILE_RRTILE5027", DVPTR(TILE_RRTILE5027), 0, RRTILE5027__STATICRR },
    { "TILE_RRTILE5029", DVPTR(TILE_RRTILE5029), 0, RRTILE5029__STATICRR },
    { "TILE_RRTILE5030", DVPTR(TILE_RRTILE5030), 0, RRTILE5030__STATICRR },
    { "TILE_RRTILE5031", DVPTR(TILE_RRTILE5031), 0, RRTILE5031__STATICRR },
    { "TILE_RRTILE5032", DVPTR(TILE_RRTILE5032), 0, RRTILE5032__STATICRR },
    { "TILE_RRTILE5033", DVPTR(TILE_RRTILE5033), 0, RRTILE5033__STATICRR },
    { "TILE_RRTILE5034", DVPTR(TILE_RRTILE5034), 0, RRTILE5034__STATICRR },
    { "TILE_RRTILE5035", DVPTR(TILE_RRTILE5035), 0, RRTILE5035__STATICRR },
    { "TILE_RRTILE5036", DVPTR(TILE_RRTILE5036), 0, RRTILE5036__STATICRR },
    { "TILE_RRTILE5037", DVPTR(TILE_RRTILE5037), 0, RRTILE5037__STATICRR },
    { "TILE_RRTILE5038", DVPTR(TILE_RRTILE5038), 0, RRTILE5038__STATICRR },
    { "TILE_RRTILE5039", DVPTR(TILE_RRTILE5039), 0, RRTILE5039__STATICRR },
    { "TILE_RRTILE5040", DVPTR(TILE_RRTILE5040), 0, RRTILE5040__STATICRR },
    { "TILE_RRTILE5041", DVPTR(TILE_RRTILE5041), 0, RRTILE5041__STATICRR },
    { "TILE_RRTILE5043", DVPTR(TILE_RRTILE5043), 0, RRTILE5043__STATICRR },
    { "TILE_RRTILE5044", DVPTR(TILE_RRTILE5044), 0, RRTILE5044__STATICRR },
    { "TILE_RRTILE5045", DVPTR(TILE_RRTILE5045), 0, RRTILE5045__STATICRR },
    { "TILE_RRTILE5046", DVPTR(TILE_RRTILE5046), 0, RRTILE5046__STATICRR },
    { "TILE_RRTILE5047", DVPTR(TILE_RRTILE5047), 0, RRTILE5047__STATICRR },
    { "TILE_RRTILE5048", DVPTR(TILE_RRTILE5048), 0, RRTILE5048__STATICRR },
    { "TILE_RRTILE5049", DVPTR(TILE_RRTILE5049), 0, RRTILE5049__STATICRR },
    { "TILE_RRTILE5050", DVPTR(TILE_RRTILE5050), 0, RRTILE5050__STATICRR },
    { "TILE_RRTILE5051", DVPTR(TILE_RRTILE5051), 0, RRTILE5051__STATICRR },
    { "TILE_RRTILE5052", DVPTR(TILE_RRTILE5052), 0, RRTILE5052__STATICRR },
    { "TILE_RRTILE5053", DVPTR(TILE_RRTILE5053), 0, RRTILE5053__STATICRR },
    { "TILE_RRTILE5054", DVPTR(TILE_RRTILE5054), 0, RRTILE5054__STATICRR },
    { "TILE_RRTILE5055", DVPTR(TILE_RRTILE5055), 0, RRTILE5055__STATICRR },
    { "TILE_RRTILE5056", DVPTR(TILE_RRTILE5056), 0, RRTILE5056__STATICRR },
    { "TILE_RRTILE5057", DVPTR(TILE_RRTILE5057), 0, RRTILE5057__STATICRR },
    { "TILE_RRTILE5058", DVPTR(TILE_RRTILE5058), 0, RRTILE5058__STATICRR },
    { "TILE_RRTILE5059", DVPTR(TILE_RRTILE5059), 0, RRTILE5059__STATICRR },
    { "TILE_RRTILE5061", DVPTR(TILE_RRTILE5061), 0, RRTILE5061__STATICRR },
    { "TILE_RRTILE5062", DVPTR(TILE_RRTILE5062), 0, RRTILE5062__STATICRR },
    { "TILE_RRTILE5063", DVPTR(TILE_RRTILE5063), 0, RRTILE5063__STATICRR },
    { "TILE_RRTILE5064", DVPTR(TILE_RRTILE5064), 0, RRTILE5064__STATICRR },
    { "TILE_RRTILE5065", DVPTR(TILE_RRTILE5065), 0, RRTILE5065__STATICRR },
    { "TILE_RRTILE5066", DVPTR(TILE_RRTILE5066), 0, RRTILE5066__STATICRR },
    { "TILE_RRTILE5067", DVPTR(TILE_RRTILE5067), 0, RRTILE5067__STATICRR },
    { "TILE_RRTILE5068", DVPTR(TILE_RRTILE5068), 0, RRTILE5068__STATICRR },
    { "TILE_RRTILE5069", DVPTR(TILE_RRTILE5069), 0, RRTILE5069__STATICRR },
    { "TILE_RRTILE5070", DVPTR(TILE_RRTILE5070), 0, RRTILE5070__STATICRR },
    { "TILE_RRTILE5071", DVPTR(TILE_RRTILE5071), 0, RRTILE5071__STATICRR },
    { "TILE_RRTILE5072", DVPTR(TILE_RRTILE5072), 0, RRTILE5072__STATICRR },
    { "TILE_RRTILE5073", DVPTR(TILE_RRTILE5073), 0, RRTILE5073__STATICRR },
    { "TILE_RRTILE5074", DVPTR(TILE_RRTILE5074), 0, RRTILE5074__STATICRR },
    { "TILE_RRTILE5075", DVPTR(TILE_RRTILE5075), 0, RRTILE5075__STATICRR },
    { "TILE_RRTILE5076", DVPTR(TILE_RRTILE5076), 0, RRTILE5076__STATICRR },
    { "TILE_RRTILE5077", DVPTR(TILE_RRTILE5077), 0, RRTILE5077__STATICRR },
    { "TILE_RRTILE5078", DVPTR(TILE_RRTILE5078), 0, RRTILE5078__STATICRR },
    { "TILE_RRTILE5079", DVPTR(TILE_RRTILE5079), 0, RRTILE5079__STATICRR },
    { "TILE_RRTILE5080", DVPTR(TILE_RRTILE5080), 0, RRTILE5080__STATICRR },
    { "TILE_RRTILE5081", DVPTR(TILE_RRTILE5081), 0, RRTILE5081__STATICRR },
    { "TILE_RRTILE5082", DVPTR(TILE_RRTILE5082), 0, RRTILE5082__STATICRR },
    { "TILE_RRTILE5083", DVPTR(TILE_RRTILE5083), 0, RRTILE5083__STATICRR },
    { "TILE_RRTILE5084", DVPTR(TILE_RRTILE5084), 0, RRTILE5084__STATICRR },
    { "TILE_RRTILE5085", DVPTR(TILE_RRTILE5085), 0, RRTILE5085__STATICRR },
    { "TILE_RRTILE5086", DVPTR(TILE_RRTILE5086), 0, RRTILE5086__STATICRR },
    { "TILE_RRTILE5087", DVPTR(TILE_RRTILE5087), 0, RRTILE5087__STATICRR },
    { "TILE_RRTILE5088", DVPTR(TILE_RRTILE5088), 0, RRTILE5088__STATICRR },
    { "TILE_RRTILE5090", DVPTR(TILE_RRTILE5090), 0, RRTILE5090__STATICRR },
    { "TILE_RRTILE6144", DVPTR(TILE_RRTILE6144), 0, RRTILE6144__STATICRR },
    { "RRTILE7010", DVPTR(TILE_RRTILE7110), 0, RRTILE7110__STATICRR },
    { "RRTILE7011", DVPTR(TILE_RRTILE7111), 0, RRTILE7111__STATICRR },
    { "RRTILE7012", DVPTR(TILE_RRTILE7112), 0, RRTILE7112__STATICRR },
    { "RRTILE7013", DVPTR(TILE_RRTILE7113), 0, RRTILE7113__STATICRR },
    { "TILE_MOTOGUN", DVPTR(TILE_MOTOGUN), 0, MOTOGUN__STATICRR },
    { "TILE_RRTILE7169", DVPTR(TILE_RRTILE7169), 0, RRTILE7169__STATICRR },
    { "TILE_MOTOHIT", DVPTR(TILE_MOTOHIT), 0, MOTOHIT__STATICRR },
    { "TILE_BOATHIT", DVPTR(TILE_BOATHIT), 0, BOATHIT__STATICRR },
    { "TILE_RRTILE7184", DVPTR(TILE_RRTILE7184), 0, RRTILE7184__STATICRR },
    { "TILE_RRTILE7190", DVPTR(TILE_RRTILE7190), 0, RRTILE7190__STATICRR },
    { "TILE_RRTILE7191", DVPTR(TILE_RRTILE7191), 0, RRTILE7191__STATICRR },
    { "TILE_RRTILE7213", DVPTR(TILE_RRTILE7213), 0, RRTILE7213__STATICRR },
    { "TILE_RRTILE7219", DVPTR(TILE_RRTILE7219), 0, RRTILE7219__STATICRR },
    { "TILE_EMPTYBIKE", DVPTR(TILE_EMPTYBIKE), 0, EMPTYBIKE__STATICRR },
    { "TILE_EMPTYBOAT", DVPTR(TILE_EMPTYBOAT), 0, EMPTYBOAT__STATICRR },
    { "TILE_RRTILE7424", DVPTR(TILE_RRTILE7424), 0, RRTILE7424__STATICRR },
    { "TILE_RRTILE7430", DVPTR(TILE_RRTILE7430), 0, RRTILE7430__STATICRR },
    { "TILE_RRTILE7433", DVPTR(TILE_RRTILE7433), 0, RRTILE7433__STATICRR },
    { "TILE_RRTILE7441", DVPTR(TILE_RRTILE7441), 0, RRTILE7441__STATICRR },
    { "TILE_RRTILE7547", DVPTR(TILE_RRTILE7547), 0, RRTILE7547__STATICRR },
    { "TILE_RRTILE7467", DVPTR(TILE_RRTILE7467), 0, RRTILE7467__STATICRR },
    { "TILE_RRTILE7469", DVPTR(TILE_RRTILE7469), 0, RRTILE7469__STATICRR },
    { "TILE_RRTILE7470", DVPTR(TILE_RRTILE7470), 0, RRTILE7470__STATICRR },
    { "TILE_RRTILE7475", DVPTR(TILE_RRTILE7475), 0, RRTILE7475__STATICRR },
    { "TILE_RRTILE7478", DVPTR(TILE_RRTILE7478), 0, RRTILE7478__STATICRR },
    { "TILE_RRTILE7505", DVPTR(TILE_RRTILE7505), 0, RRTILE7505__STATICRR },
    { "TILE_RRTILE7506", DVPTR(TILE_RRTILE7506), 0, RRTILE7506__STATICRR },
    { "TILE_RRTILE7534", DVPTR(TILE_RRTILE7534), 0, RRTILE7534__STATICRR },
    { "TILE_RRTILE7540", DVPTR(TILE_RRTILE7540), 0, RRTILE7540__STATICRR },
    { "TILE_RRTILE7533", DVPTR(TILE_RRTILE7533), 0, RRTILE7533__STATICRR },
    { "TILE_RRTILE7545", DVPTR(TILE_RRTILE7545), 0, RRTILE7545__STATICRR },
    { "TILE_RRTILE7552", DVPTR(TILE_RRTILE7552), 0, RRTILE7552__STATICRR },
    { "TILE_RRTILE7553", DVPTR(TILE_RRTILE7553), 0, RRTILE7553__STATICRR },
    { "TILE_RRTILE7554", DVPTR(TILE_RRTILE7554), 0, RRTILE7554__STATICRR },
    { "TILE_RRTILE7555", DVPTR(TILE_RRTILE7555), 0, RRTILE7555__STATICRR },
    { "TILE_RRTILE7557", DVPTR(TILE_RRTILE7557), 0, RRTILE7557__STATICRR },
    { "TILE_RRTILE7558", DVPTR(TILE_RRTILE7558), 0, RRTILE7558__STATICRR },
    { "TILE_RRTILE7559", DVPTR(TILE_RRTILE7559), 0, RRTILE7559__STATICRR },
    { "TILE_RRTILE7561", DVPTR(TILE_RRTILE7561), 0, RRTILE7561__STATICRR },
    { "TILE_RRTILE7566", DVPTR(TILE_RRTILE7566), 0, RRTILE7566__STATICRR },
    { "TILE_RRTILE7568", DVPTR(TILE_RRTILE7568), 0, RRTILE7568__STATICRR },
    { "TILE_RRTILE7574", DVPTR(TILE_RRTILE7574), 0, RRTILE7574__STATICRR },
    { "TILE_RRTILE7575", DVPTR(TILE_RRTILE7575), 0, RRTILE7575__STATICRR },
    { "TILE_RRTILE7576", DVPTR(TILE_RRTILE7576), 0, RRTILE7576__STATICRR },
    { "TILE_RRTILE7578", DVPTR(TILE_RRTILE7578), 0, RRTILE7578__STATICRR },
    { "TILE_RRTILE7579", DVPTR(TILE_RRTILE7579), 0, RRTILE7579__STATICRR },
    { "TILE_RRTILE7580", DVPTR(TILE_RRTILE7580), 0, RRTILE7580__STATICRR },
    { "TILE_RRTILE7595", DVPTR(TILE_RRTILE7595), 0, RRTILE7595__STATICRR },
    { "TILE_RRTILE7629", DVPTR(TILE_RRTILE7629), 0, RRTILE7629__STATICRR },
    { "TILE_RRTILE7636", DVPTR(TILE_RRTILE7636), 0, RRTILE7636__STATICRR },
    { "TILE_RRTILE7638", DVPTR(TILE_RRTILE7638), 0, RRTILE7638__STATICRR },
    { "TILE_RRTILE7640", DVPTR(TILE_RRTILE7640), 0, RRTILE7640__STATICRR },
    { "TILE_RRTILE7644", DVPTR(TILE_RRTILE7644), 0, RRTILE7644__STATICRR },
    { "TILE_RRTILE7646", DVPTR(TILE_RRTILE7646), 0, RRTILE7646__STATICRR },
    { "TILE_RRTILE7648", DVPTR(TILE_RRTILE7648), 0, RRTILE7648__STATICRR },
    { "TILE_RRTILE7650", DVPTR(TILE_RRTILE7650), 0, RRTILE7650__STATICRR },
    { "TILE_RRTILE7653", DVPTR(TILE_RRTILE7653), 0, RRTILE7653__STATICRR },
    { "TILE_RRTILE7655", DVPTR(TILE_RRTILE7655), 0, RRTILE7655__STATICRR },
    { "TILE_RRTILE7657", DVPTR(TILE_RRTILE7657), 0, RRTILE7657__STATICRR },
    { "TILE_RRTILE7659", DVPTR(TILE_RRTILE7659), 0, RRTILE7659__STATICRR },
    { "TILE_RRTILE7691", DVPTR(TILE_RRTILE7691), 0, RRTILE7691__STATICRR },
    { "TILE_RRTILE7694", DVPTR(TILE_RRTILE7694), 0, RRTILE7694__STATICRR },
    { "TILE_RRTILE7696", DVPTR(TILE_RRTILE7696), 0, RRTILE7696__STATICRR },
    { "TILE_RRTILE7697", DVPTR(TILE_RRTILE7697), 0, RRTILE7697__STATICRR },
    { "TILE_RRTILE7700", DVPTR(TILE_RRTILE7700), 0, RRTILE7700__STATICRR },
    { "TILE_RRTILE7702", DVPTR(TILE_RRTILE7702), 0, RRTILE7702__STATICRR },
    { "TILE_RRTILE7704", DVPTR(TILE_RRTILE7704), 0, RRTILE7704__STATICRR },
    { "TILE_RRTILE7705", DVPTR(TILE_RRTILE7705), 0, RRTILE7705__STATICRR },
    { "TILE_RRTILE7711", DVPTR(TILE_RRTILE7711), 0, RRTILE7711__STATICRR },
    { "TILE_RRTILE7716", DVPTR(TILE_RRTILE7716), 0, RRTILE7716__STATICRR },
    { "TILE_RRTILE7756", DVPTR(TILE_RRTILE7756), 0, RRTILE7756__STATICRR },
    { "TILE_RRTILE7768", DVPTR(TILE_RRTILE7768), 0, RRTILE7768__STATICRR },
    { "TILE_RRTILE7806", DVPTR(TILE_RRTILE7806), 0, RRTILE7806__STATICRR },
    { "TILE_RRTILE7820", DVPTR(TILE_RRTILE7820), 0, RRTILE7820__STATICRR },
    { "TILE_RRTILE7859", DVPTR(TILE_RRTILE7859), 0, RRTILE7859__STATICRR },
    { "TILE_RRTILE7870", DVPTR(TILE_RRTILE7870), 0, RRTILE7870__STATICRR },
    { "TILE_RRTILE7873", DVPTR(TILE_RRTILE7873), 0, RRTILE7873__STATICRR },
    { "TILE_RRTILE7875", DVPTR(TILE_RRTILE7875), 0, RRTILE7875__STATICRR },
    { "TILE_RRTILE7876", DVPTR(TILE_RRTILE7876), 0, RRTILE7876__STATICRR },
    { "TILE_RRTILE7879", DVPTR(TILE_RRTILE7879), 0, RRTILE7879__STATICRR },
    { "TILE_RRTILE7881", DVPTR(TILE_RRTILE7881), 0, RRTILE7881__STATICRR },
    { "TILE_RRTILE7883", DVPTR(TILE_RRTILE7883), 0, RRTILE7883__STATICRR },
    { "TILE_RRTILE7885", DVPTR(TILE_RRTILE7885), 0, RRTILE7885__STATICRR },
    { "TILE_RRTILE7886", DVPTR(TILE_RRTILE7886), 0, RRTILE7886__STATICRR },
    { "TILE_RRTILE7887", DVPTR(TILE_RRTILE7887), 0, RRTILE7887__STATICRR },
    { "TILE_RRTILE7888", DVPTR(TILE_RRTILE7888), 0, RRTILE7888__STATICRR },
    { "TILE_RRTILE7889", DVPTR(TILE_RRTILE7889), 0, RRTILE7889__STATICRR },
    { "TILE_RRTILE7890", DVPTR(TILE_RRTILE7890), 0, RRTILE7890__STATICRR },
    { "TILE_RRTILE7900", DVPTR(TILE_RRTILE7900), 0, RRTILE7900__STATICRR },
    { "TILE_RRTILE7901", DVPTR(TILE_RRTILE7901), 0, RRTILE7901__STATICRR },
    { "TILE_RRTILE7906", DVPTR(TILE_RRTILE7906), 0, RRTILE7906__STATICRR },
    { "TILE_RRTILE7912", DVPTR(TILE_RRTILE7912), 0, RRTILE7912__STATICRR },
    { "TILE_RRTILE7913", DVPTR(TILE_RRTILE7913), 0, RRTILE7913__STATICRR },
    { "TILE_RRTILE7936", DVPTR(TILE_RRTILE7936), 0, RRTILE7936__STATICRR },
    { "TILE_RRTILE8047", DVPTR(TILE_RRTILE8047), 0, RRTILE8047__STATICRR },
    { "TILE_MULTISWITCH2", DVPTR(TILE_MULTISWITCH2), 0, MULTISWITCH2__STATICRR },
    { "TILE_RRTILE8059", DVPTR(TILE_RRTILE8059), 0, RRTILE8059__STATICRR },
    { "TILE_RRTILE8060", DVPTR(TILE_RRTILE8060), 0, RRTILE8060__STATICRR },
    { "TILE_RRTILE8063", DVPTR(TILE_RRTILE8063), 0, RRTILE8063__STATICRR },
    { "TILE_RRTILE8067", DVPTR(TILE_RRTILE8067), 0, RRTILE8067__STATICRR },
    { "TILE_RRTILE8076", DVPTR(TILE_RRTILE8076), 0, RRTILE8076__STATICRR },
    { "TILE_RRTILE8094", DVPTR(TILE_RRTILE8094), 0, RRTILE8094__STATICRR },
    { "TILE_RRTILE8096", DVPTR(TILE_RRTILE8096), 0, RRTILE8096__STATICRR },
    { "TILE_RRTILE8099", DVPTR(TILE_RRTILE8099), 0, RRTILE8099__STATICRR },
    { "TILE_RRTILE8106", DVPTR(TILE_RRTILE8106), 0, RRTILE8106__STATICRR },
    { "TILE_RRTILE8162", DVPTR(TILE_RRTILE8162), 0, RRTILE8162__STATICRR },
    { "TILE_RRTILE8163", DVPTR(TILE_RRTILE8163), 0, RRTILE8163__STATICRR },
    { "TILE_RRTILE8164", DVPTR(TILE_RRTILE8164), 0, RRTILE8164__STATICRR },
    { "TILE_RRTILE8165", DVPTR(TILE_RRTILE8165), 0, RRTILE8165__STATICRR },
    { "TILE_RRTILE8166", DVPTR(TILE_RRTILE8166), 0, RRTILE8166__STATICRR },
    { "TILE_RRTILE8167", DVPTR(TILE_RRTILE8167), 0, RRTILE8167__STATICRR },
    { "TILE_RRTILE8168", DVPTR(TILE_RRTILE8168), 0, RRTILE8168__STATICRR },
    { "TILE_RRTILE8192", DVPTR(TILE_RRTILE8192), 0, RRTILE8192__STATICRR },
    { "TILE_RRTILE8193", DVPTR(TILE_RRTILE8193), 0, RRTILE8193__STATICRR },
    { "TILE_RRTILE8215", DVPTR(TILE_RRTILE8215), 0, RRTILE8215__STATICRR },
    { "TILE_RRTILE8216", DVPTR(TILE_RRTILE8216), 0, RRTILE8216__STATICRR },
    { "TILE_RRTILE8217", DVPTR(TILE_RRTILE8217), 0, RRTILE8217__STATICRR },
    { "TILE_RRTILE8218", DVPTR(TILE_RRTILE8218), 0, RRTILE8218__STATICRR },
    { "TILE_RRTILE8220", DVPTR(TILE_RRTILE8220), 0, RRTILE8220__STATICRR },
    { "TILE_RRTILE8221", DVPTR(TILE_RRTILE8221), 0, RRTILE8221__STATICRR },
    { "TILE_RRTILE8222", DVPTR(TILE_RRTILE8222), 0, RRTILE8222__STATICRR },
    { "TILE_RRTILE8223", DVPTR(TILE_RRTILE8223), 0, RRTILE8223__STATICRR },
    { "TILE_RRTILE8224", DVPTR(TILE_RRTILE8224), 0, RRTILE8224__STATICRR },
    { "TILE_RRTILE8227", DVPTR(TILE_RRTILE8227), 0, RRTILE8227__STATICRR },
    { "TILE_RRTILE8312", DVPTR(TILE_RRTILE8312), 0, RRTILE8312__STATICRR },
    { "TILE_RRTILE8370", DVPTR(TILE_RRTILE8370), 0, RRTILE8370__STATICRR },
    { "TILE_RRTILE8371", DVPTR(TILE_RRTILE8371), 0, RRTILE8371__STATICRR },
    { "TILE_RRTILE8372", DVPTR(TILE_RRTILE8372), 0, RRTILE8372__STATICRR },
    { "TILE_RRTILE8373", DVPTR(TILE_RRTILE8373), 0, RRTILE8373__STATICRR },
    { "TILE_RRTILE8379", DVPTR(TILE_RRTILE8379), 0, RRTILE8379__STATICRR },
    { "TILE_RRTILE8380", DVPTR(TILE_RRTILE8380), 0, RRTILE8380__STATICRR },
    { "TILE_RRTILE8385", DVPTR(TILE_RRTILE8385), 0, RRTILE8385__STATICRR },
    { "TILE_RRTILE8386", DVPTR(TILE_RRTILE8386), 0, RRTILE8386__STATICRR },
    { "TILE_RRTILE8387", DVPTR(TILE_RRTILE8387), 0, RRTILE8387__STATICRR },
    { "TILE_RRTILE8388", DVPTR(TILE_RRTILE8388), 0, RRTILE8388__STATICRR },
    { "TILE_RRTILE8389", DVPTR(TILE_RRTILE8389), 0, RRTILE8389__STATICRR },
    { "TILE_RRTILE8390", DVPTR(TILE_RRTILE8390), 0, RRTILE8390__STATICRR },
    { "TILE_RRTILE8391", DVPTR(TILE_RRTILE8391), 0, RRTILE8391__STATICRR },
    { "TILE_RRTILE8392", DVPTR(TILE_RRTILE8392), 0, RRTILE8392__STATICRR },
    { "TILE_RRTILE8394", DVPTR(TILE_RRTILE8394), 0, RRTILE8394__STATICRR },
    { "TILE_RRTILE8395", DVPTR(TILE_RRTILE8395), 0, RRTILE8395__STATICRR },
    { "TILE_RRTILE8396", DVPTR(TILE_RRTILE8396), 0, RRTILE8396__STATICRR },
    { "TILE_RRTILE8397", DVPTR(TILE_RRTILE8397), 0, RRTILE8397__STATICRR },
    { "TILE_RRTILE8398", DVPTR(TILE_RRTILE8398), 0, RRTILE8398__STATICRR },
    { "TILE_RRTILE8399", DVPTR(TILE_RRTILE8399), 0, RRTILE8399__STATICRR },
    { "TILE_RRTILE8423", DVPTR(TILE_RRTILE8423), 0, RRTILE8423__STATICRR },
    { "TILE_RRTILE8448", DVPTR(TILE_RRTILE8448), 0, RRTILE8448__STATICRR },
    { "TILE_RRTILE8450", DVPTR(TILE_RRTILE8450), 0, RRTILE8450__STATICRR },
    { "TILE_BOATAMMO", DVPTR(TILE_BOATAMMO), 0, BOATAMMO__STATICRR },
    { "TILE_RRTILE8461", DVPTR(TILE_RRTILE8461), 0, RRTILE8461__STATICRR },
    { "TILE_RRTILE8462", DVPTR(TILE_RRTILE8462), 0, RRTILE8462__STATICRR },
    { "TILE_RRTILE8464", DVPTR(TILE_RRTILE8464), 0, RRTILE8464__STATICRR },
    { "TILE_RRTILE8475", DVPTR(TILE_RRTILE8475), 0, RRTILE8475__STATICRR },
    { "TILE_RRTILE8487", DVPTR(TILE_RRTILE8487), 0, RRTILE8487__STATICRR },
    { "TILE_RRTILE8488", DVPTR(TILE_RRTILE8488), 0, RRTILE8488__STATICRR },
    { "TILE_RRTILE8489", DVPTR(TILE_RRTILE8489), 0, RRTILE8489__STATICRR },
    { "TILE_RRTILE8490", DVPTR(TILE_RRTILE8490), 0, RRTILE8490__STATICRR },
    { "TILE_RRTILE8496", DVPTR(TILE_RRTILE8496), 0, RRTILE8496__STATICRR },
    { "TILE_RRTILE8497", DVPTR(TILE_RRTILE8497), 0, RRTILE8497__STATICRR },
    { "TILE_RRTILE8498", DVPTR(TILE_RRTILE8498), 0, RRTILE8498__STATICRR },
    { "TILE_RRTILE8499", DVPTR(TILE_RRTILE8499), 0, RRTILE8499__STATICRR },
    { "TILE_RRTILE8503", DVPTR(TILE_RRTILE8503), 0, RRTILE8503__STATICRR },
    { "TILE_RRTILE8525", DVPTR(TILE_RRTILE8525), 0, RRTILE8525__STATICRR },
    { "TILE_RRTILE8537", DVPTR(TILE_RRTILE8537), 0, RRTILE8537__STATICRR },
    { "TILE_RRTILE8565", DVPTR(TILE_RRTILE8565), 0, RRTILE8565__STATICRR },
    { "TILE_RRTILE8567", DVPTR(TILE_RRTILE8567), 0, RRTILE8567__STATICRR },
    { "TILE_RRTILE8568", DVPTR(TILE_RRTILE8568), 0, RRTILE8568__STATICRR },
    { "TILE_RRTILE8569", DVPTR(TILE_RRTILE8569), 0, RRTILE8569__STATICRR },
    { "TILE_RRTILE8570", DVPTR(TILE_RRTILE8570), 0, RRTILE8570__STATICRR },
    { "TILE_RRTILE8571", DVPTR(TILE_RRTILE8571), 0, RRTILE8571__STATICRR },
    { "TILE_RRTILE8579", DVPTR(TILE_RRTILE8579), 0, RRTILE8579__STATICRR },
    { "TILE_RRTILE8588", DVPTR(TILE_RRTILE8588), 0, RRTILE8588__STATICRR },
    { "TILE_RRTILE8589", DVPTR(TILE_RRTILE8589), 0, RRTILE8589__STATICRR },
    { "TILE_RRTILE8590", DVPTR(TILE_RRTILE8590), 0, RRTILE8590__STATICRR },
    { "TILE_RRTILE8591", DVPTR(TILE_RRTILE8591), 0, RRTILE8591__STATICRR },
    { "TILE_RRTILE8592", DVPTR(TILE_RRTILE8592), 0, RRTILE8592__STATICRR },
    { "TILE_RRTILE8593", DVPTR(TILE_RRTILE8593), 0, RRTILE8593__STATICRR },
    { "TILE_RRTILE8594", DVPTR(TILE_RRTILE8594), 0, RRTILE8594__STATICRR },
    { "TILE_RRTILE8595", DVPTR(TILE_RRTILE8595), 0, RRTILE8595__STATICRR },
    { "TILE_RRTILE8596", DVPTR(TILE_RRTILE8596), 0, RRTILE8596__STATICRR },
    { "TILE_RRTILE8598", DVPTR(TILE_RRTILE8598), 0, RRTILE8598__STATICRR },
    { "TILE_RRTILE8605", DVPTR(TILE_RRTILE8605), 0, RRTILE8605__STATICRR },
    { "TILE_RRTILE8608", DVPTR(TILE_RRTILE8608), 0, RRTILE8608__STATICRR },
    { "TILE_RRTILE8609", DVPTR(TILE_RRTILE8609), 0, RRTILE8609__STATICRR },
    { "TILE_RRTILE8611", DVPTR(TILE_RRTILE8611), 0, RRTILE8611__STATICRR },
    { "TILE_RRTILE8617", DVPTR(TILE_RRTILE8617), 0, RRTILE8617__STATICRR },
    { "TILE_RRTILE8618", DVPTR(TILE_RRTILE8618), 0, RRTILE8618__STATICRR },
    { "TILE_RRTILE8620", DVPTR(TILE_RRTILE8620), 0, RRTILE8620__STATICRR },
    { "TILE_RRTILE8621", DVPTR(TILE_RRTILE8621), 0, RRTILE8621__STATICRR },
    { "TILE_RRTILE8622", DVPTR(TILE_RRTILE8622), 0, RRTILE8622__STATICRR },
    { "TILE_RRTILE8623", DVPTR(TILE_RRTILE8623), 0, RRTILE8623__STATICRR },
    { "TILE_RRTILE8624", DVPTR(TILE_RRTILE8624), 0, RRTILE8624__STATICRR },
    { "TILE_RRTILE8640", DVPTR(TILE_RRTILE8640), 0, RRTILE8640__STATICRR },
    { "TILE_RRTILE8651", DVPTR(TILE_RRTILE8651), 0, RRTILE8651__STATICRR },
    { "TILE_RRTILE8660", DVPTR(TILE_RRTILE8660), 0, RRTILE8660__STATICRR },
    { "TILE_RRTILE8677", DVPTR(TILE_RRTILE8677), 0, RRTILE8677__STATICRR },
    { "TILE_RRTILE8679", DVPTR(TILE_RRTILE8679), 0, RRTILE8679__STATICRR },
    { "TILE_RRTILE8680", DVPTR(TILE_RRTILE8680), 0, RRTILE8680__STATICRR },
    { "TILE_RRTILE8681", DVPTR(TILE_RRTILE8681), 0, RRTILE8681__STATICRR },
    { "TILE_RRTILE8682", DVPTR(TILE_RRTILE8682), 0, RRTILE8682__STATICRR },
    { "TILE_RRTILE8683", DVPTR(TILE_RRTILE8683), 0, RRTILE8683__STATICRR },
    { "TILE_RRTILE8704", DVPTR(TILE_RRTILE8704), 0, RRTILE8704__STATICRR },
    { "TILE_BOULDER", DVPTR(TILE_BOULDER), 0, BOULDER__STATICRR },
    { "TILE_BOULDER1", DVPTR(TILE_BOULDER1), 0, BOULDER1__STATICRR },
    { "TILE_TORNADO", DVPTR(TILE_TORNADO), 0, TORNADO__STATICRR },
    { "TILE_CHEERBOMB", DVPTR(TILE_CHEERBOMB), 0, CHEERBOMB__STATICRR },
    { "TILE_CHEERBLADE", DVPTR(TILE_CHEERBLADE), 0, CHEERBLADE__STATICRR },
    { "TILE_DOGATTACK", DVPTR(TILE_DOGATTACK), 0, DOGATTACK__STATICRR },
    { "TILE_BILLYWALK", DVPTR(TILE_BILLYWALK), 0, BILLYWALK__STATICRR },
    { "TILE_BILLYDIE", DVPTR(TILE_BILLYDIE), 0, BILLYDIE__STATICRR },
    { "TILE_BILLYCOCK", DVPTR(TILE_BILLYCOCK), 0, BILLYCOCK__STATICRR },
    { "TILE_BILLYRAY", DVPTR(TILE_BILLYRAY), 0, BILLYRAY__STATICRR },
    { "TILE_BILLYRAYSTAYPUT", DVPTR(TILE_BILLYRAYSTAYPUT), 0, BILLYRAYSTAYPUT__STATICRR },
    { "TILE_BILLYBUT", DVPTR(TILE_BILLYBUT), 0, BILLYBUT__STATICRR },
    { "TILE_BILLYSCRATCH", DVPTR(TILE_BILLYSCRATCH), 0, BILLYSCRATCH__STATICRR },
    { "TILE_BILLYSNIFF", DVPTR(TILE_BILLYSNIFF), 0, BILLYSNIFF__STATICRR },
    { "TILE_BILLYWOUND", DVPTR(TILE_BILLYWOUND), 0, BILLYWOUND__STATICRR },
    { "TILE_BILLYGORE", DVPTR(TILE_BILLYGORE), 0, BILLYGORE__STATICRR },
    { "TILE_BILLYJIBA", DVPTR(TILE_BILLYJIBA), 0, BILLYJIBA__STATICRR },
    { "TILE_BILLYJIBB", DVPTR(TILE_BILLYJIBB), 0, BILLYJIBB__STATICRR },
    { "TILE_BRAYSNIPER", DVPTR(TILE_BRAYSNIPER), 0, BRAYSNIPER__STATICRR },
    { "TILE_DOGRUN", DVPTR(TILE_DOGRUN), 0, DOGRUN__STATICRR },
    { "TILE_DOGDIE", DVPTR(TILE_DOGDIE), 0, DOGDIE__STATICRR },
    { "TILE_DOGDEAD", DVPTR(TILE_DOGDEAD), 0, DOGDEAD__STATICRR },
    { "TILE_DOGBARK", DVPTR(TILE_DOGBARK), 0, DOGBARK__STATICRR },
    { "TILE_LTH", DVPTR(TILE_LTH), 0, LTH__STATICRR },
    { "TILE_LTHSTRAFE", DVPTR(TILE_LTHSTRAFE), 0, LTHSTRAFE__STATICRR },
    { "TILE_HULKHANG", DVPTR(TILE_HULKHANG), 0, HULKHANG__STATICRR },
    { "TILE_HULKHANGDEAD", DVPTR(TILE_HULKHANGDEAD), 0, HULKHANGDEAD__STATICRR },
    { "TILE_HULKJUMP", DVPTR(TILE_HULKJUMP), 0, HULKJUMP__STATICRR },
    { "TILE_LTHLOAD", DVPTR(TILE_LTHLOAD), 0, LTHLOAD__STATICRR },
    { "TILE_LTHDIE", DVPTR(TILE_LTHDIE), 0, LTHDIE__STATICRR },
    { "TILE_BUBBASCRATCH", DVPTR(TILE_BUBBASCRATCH), 0, BUBBASCRATCH__STATICRR },
    { "TILE_BUBBANOSE", DVPTR(TILE_BUBBANOSE), 0, BUBBANOSE__STATICRR },
    { "TILE_BUBBAPISS", DVPTR(TILE_BUBBAPISS), 0, BUBBAPISS__STATICRR },
    { "TILE_BUBBASTAND", DVPTR(TILE_BUBBASTAND), 0, BUBBASTAND__STATICRR },
    { "TILE_BUBBAOUCH", DVPTR(TILE_BUBBAOUCH), 0, BUBBAOUCH__STATICRR },
    { "TILE_BUBBADIE", DVPTR(TILE_BUBBADIE), 0, BUBBADIE__STATICRR },
    { "TILE_BUBBADEAD", DVPTR(TILE_BUBBADEAD), 0, BUBBADEAD__STATICRR },
    { "TILE_HULK", DVPTR(TILE_HULK), 0, HULK__STATICRR },
    { "TILE_HULKSTAYPUT", DVPTR(TILE_HULKSTAYPUT), 0, HULKSTAYPUT__STATICRR },
    { "TILE_HULKA", DVPTR(TILE_HULKA), 0, HULKA__STATICRR },
    { "TILE_HULKB", DVPTR(TILE_HULKB), 0, HULKB__STATICRR },
    { "TILE_HULKC", DVPTR(TILE_HULKC), 0, HULKC__STATICRR },
    { "TILE_HULKJIBA", DVPTR(TILE_HULKJIBA), 0, HULKJIBA__STATICRR },
    { "TILE_HULKJIBB", DVPTR(TILE_HULKJIBB), 0, HULKJIBB__STATICRR },
    { "TILE_HULKJIBC", DVPTR(TILE_HULKJIBC), 0, HULKJIBC__STATICRR },
    { "TILE_SBSWIPE", DVPTR(TILE_SBSWIPE), 0, SBSWIPE__STATICRR },
    { "TILE_SBPAIN", DVPTR(TILE_SBPAIN), 0, SBPAIN__STATICRR },
    { "TILE_SBDIE", DVPTR(TILE_SBDIE), 0, SBDIE__STATICRR },
    { "TILE_HEN", DVPTR(TILE_HEN), 0, HEN__STATICRR },
    { "TILE_HENSTAYPUT", DVPTR(TILE_HENSTAYPUT), 0, HENSTAYPUT__STATICRR },
    { "TILE_HENSTAND", DVPTR(TILE_HENSTAND), 0, HENSTAND__STATICRR },
    { "TILE_PIG", DVPTR(TILE_PIG), 0, PIG__STATICRR },
    { "TILE_PIGSTAYPUT", DVPTR(TILE_PIGSTAYPUT), 0, PIGSTAYPUT__STATICRR },
    { "TILE_PIGEAT", DVPTR(TILE_PIGEAT), 0, PIGEAT__STATICRR },
    { "TILE_SBMOVE", DVPTR(TILE_SBMOVE), 0, SBMOVE__STATICRR },
    { "TILE_SBSPIT", DVPTR(TILE_SBSPIT), 0, SBSPIT__STATICRR },
    { "TILE_SBDIP", DVPTR(TILE_SBDIP), 0, SBDIP__STATICRR },
    { "TILE_MINION", DVPTR(TILE_MINION), 0, MINION__STATICRR },
    { "TILE_MINIONSTAYPUT", DVPTR(TILE_MINIONSTAYPUT), 0, MINIONSTAYPUT__STATICRR },
    { "TILE_UFO1", DVPTR(TILE_UFO1), 0, UFO1__STATICRR },
    { "TILE_UFO2", DVPTR(TILE_UFO2), 0, UFO2__STATICRR },
    { "TILE_UFO3", DVPTR(TILE_UFO3), 0, UFO3__STATICRR },
    { "TILE_UFO4", DVPTR(TILE_UFO4), 0, UFO4__STATICRR },
    { "TILE_UFO5", DVPTR(TILE_UFO5), 0, UFO5__STATICRR },
    { "TILE_MINJIBA", DVPTR(TILE_MINJIBA), 0, MINJIBA__STATICRR },
    { "TILE_MINJIBB", DVPTR(TILE_MINJIBB), 0, MINJIBB__STATICRR },
    { "TILE_MINJIBC", DVPTR(TILE_MINJIBC), 0, MINJIBC__STATICRR },
    { "TILE_COW", DVPTR(TILE_COW), 0, COW__STATICRR },
    { "TILE_COOT", DVPTR(TILE_COOT), 0, COOT__STATICRR },
    { "TILE_COOTSTAYPUT", DVPTR(TILE_COOTSTAYPUT), 0, COOTSTAYPUT__STATICRR },
    { "TILE_COOTSHOOT", DVPTR(TILE_COOTSHOOT), 0, COOTSHOOT__STATICRR },
    { "TILE_COOTDIE", DVPTR(TILE_COOTDIE), 0, COOTDIE__STATICRR },
    { "TILE_COOTDUCK", DVPTR(TILE_COOTDUCK), 0, COOTDUCK__STATICRR },
    { "TILE_COOTPAIN", DVPTR(TILE_COOTPAIN), 0, COOTPAIN__STATICRR },
    { "TILE_COOTTRANS", DVPTR(TILE_COOTTRANS), 0, COOTTRANS__STATICRR },
    { "TILE_COOTGETUP", DVPTR(TILE_COOTGETUP), 0, COOTGETUP__STATICRR },
    { "TILE_COOTJIBA", DVPTR(TILE_COOTJIBA), 0, COOTJIBA__STATICRR },
    { "TILE_COOTJIBB", DVPTR(TILE_COOTJIBB), 0, COOTJIBB__STATICRR },
    { "TILE_COOTJIBC", DVPTR(TILE_COOTJIBC), 0, COOTJIBC__STATICRR },
    { "TILE_VIXEN", DVPTR(TILE_VIXEN), 0, VIXEN__STATICRR },
    { "TILE_VIXENPAIN", DVPTR(TILE_VIXENPAIN), 0, VIXENPAIN__STATICRR },
    { "TILE_VIXENDIE", DVPTR(TILE_VIXENDIE), 0, VIXENDIE__STATICRR },
    { "TILE_VIXENSHOOT", DVPTR(TILE_VIXENSHOOT), 0, VIXENSHOOT__STATICRR },
    { "TILE_VIXENWDN", DVPTR(TILE_VIXENWDN), 0, VIXENWDN__STATICRR },
    { "TILE_VIXENWUP", DVPTR(TILE_VIXENWUP), 0, VIXENWUP__STATICRR },
    { "TILE_VIXENKICK", DVPTR(TILE_VIXENKICK), 0, VIXENKICK__STATICRR },
    { "TILE_VIXENTELE", DVPTR(TILE_VIXENTELE), 0, VIXENTELE__STATICRR },
    { "TILE_VIXENTEAT", DVPTR(TILE_VIXENTEAT), 0, VIXENTEAT__STATICRR },
    { "TILE_BIKEJIBA", DVPTR(TILE_BIKEJIBA), 0, BIKEJIBA__STATICRR },
    { "TILE_BIKEJIBB", DVPTR(TILE_BIKEJIBB), 0, BIKEJIBB__STATICRR },
    { "TILE_BIKEJIBC", DVPTR(TILE_BIKEJIBC), 0, BIKEJIBC__STATICRR },
    { "TILE_BIKERB", DVPTR(TILE_BIKERB), 0, BIKERB__STATICRR },
    { "TILE_BIKERBV2", DVPTR(TILE_BIKERBV2), 0, BIKERBV2__STATICRR },
    { "TILE_BIKER", DVPTR(TILE_BIKER), 0, BIKER__STATICRR },
    { "TILE_BIKERJIBA", DVPTR(TILE_BIKERJIBA), 0, BIKERJIBA__STATICRR },
    { "TILE_BIKERJIBB", DVPTR(TILE_BIKERJIBB), 0, BIKERJIBB__STATICRR },
    { "TILE_BIKERJIBC", DVPTR(TILE_BIKERJIBC), 0, BIKERJIBC__STATICRR },
    { "TILE_BIKERJIBD", DVPTR(TILE_BIKERJIBD), 0, BIKERJIBD__STATICRR },
    { "TILE_MAKEOUT", DVPTR(TILE_MAKEOUT), 0, MAKEOUT__STATICRR },
    { "TILE_CHEERB", DVPTR(TILE_CHEERB), 0, CHEERB__STATICRR },
    { "TILE_CHEER", DVPTR(TILE_CHEER), 0, CHEER__STATICRR },
    { "TILE_CHEERSTAYPUT", DVPTR(TILE_CHEERSTAYPUT), 0, CHEERSTAYPUT__STATICRR },
    { "TILE_CHEERJIBA", DVPTR(TILE_CHEERJIBA), 0, CHEERJIBA__STATICRR },
    { "TILE_CHEERJIBB", DVPTR(TILE_CHEERJIBB), 0, CHEERJIBB__STATICRR },
    { "TILE_CHEERJIBC", DVPTR(TILE_CHEERJIBC), 0, CHEERJIBC__STATICRR },
    { "TILE_CHEERJIBD", DVPTR(TILE_CHEERJIBD), 0, CHEERJIBD__STATICRR },
    { "TILE_FBOATJIBA", DVPTR(TILE_FBOATJIBA), 0, FBOATJIBA__STATICRR },
    { "TILE_FBOATJIBB", DVPTR(TILE_FBOATJIBB), 0, FBOATJIBB__STATICRR },
    { "TILE_COOTPLAY", DVPTR(TILE_COOTPLAY), 0, COOTPLAY__STATICRR },
    { "TILE_BILLYPLAY", DVPTR(TILE_BILLYPLAY), 0, BILLYPLAY__STATICRR },
    { "TILE_MINIONBOAT", DVPTR(TILE_MINIONBOAT), 0, MINIONBOAT__STATICRR },
    { "TILE_HULKBOAT", DVPTR(TILE_HULKBOAT), 0, HULKBOAT__STATICRR },
    { "TILE_CHEERBOAT", DVPTR(TILE_CHEERBOAT), 0, CHEERBOAT__STATICRR },
    { "TILE_RRTILE7274", DVPTR(TILE_RRTILE7274), 0, RRTILE7274__STATICRR },
    { "TILE_RABBIT", DVPTR(TILE_RABBIT), 0, RABBIT__STATICRR },
    { "TILE_RABBITJIBA", DVPTR(TILE_RABBITJIBA), 0, RABBITJIBA__STATICRR },
    { "TILE_RABBITJIBB", DVPTR(TILE_RABBITJIBB), 0, RABBITJIBB__STATICRR },
    { "TILE_RABBITJIBC", DVPTR(TILE_RABBITJIBC), 0, RABBITJIBC__STATICRR },
    { "TILE_ROCK", DVPTR(TILE_ROCK), 0, ROCK__STATICRR },
    { "TILE_ROCK2", DVPTR(TILE_ROCK2), 0, ROCK2__STATICRR },
    { "TILE_MAMACLOUD", DVPTR(TILE_MAMACLOUD), 0, MAMACLOUD__STATICRR },
    { "TILE_MAMA", DVPTR(TILE_MAMA), 0, MAMA__STATICRR },
    { "TILE_MAMAJIBA", DVPTR(TILE_MAMAJIBA), 0, MAMAJIBA__STATICRR },
    { "TILE_MAMAJIBB", DVPTR(TILE_MAMAJIBB), 0, MAMAJIBB__STATICRR },
    { NULL, NULL, -1, -1 },
};

int32_t TILE_SECTOREFFECTOR = SECTOREFFECTOR__STATIC;
int32_t TILE_ACTIVATOR = ACTIVATOR__STATIC;
int32_t TILE_TOUCHPLATE = TOUCHPLATE__STATIC;
int32_t TILE_ACTIVATORLOCKED = ACTIVATORLOCKED__STATIC;
int32_t TILE_MUSICANDSFX = MUSICANDSFX__STATIC;
int32_t TILE_LOCATORS = LOCATORS__STATIC;
int32_t TILE_CYCLER = CYCLER__STATIC;
int32_t TILE_MASTERSWITCH = MASTERSWITCH__STATIC;
int32_t TILE_RESPAWN = RESPAWN__STATIC;
int32_t TILE_GPSPEED = GPSPEED__STATIC;
int32_t TILE_FOF = FOF__STATIC;
int32_t TILE_ARROW = ARROW__STATIC;
int32_t TILE_FIRSTGUNSPRITE = FIRSTGUNSPRITE__STATIC;
int32_t TILE_CHAINGUNSPRITE = CHAINGUNSPRITE__STATIC;
int32_t TILE_RPGSPRITE = RPGSPRITE__STATIC;
int32_t TILE_FREEZESPRITE = FREEZESPRITE__STATIC;
int32_t TILE_SHRINKERSPRITE = SHRINKERSPRITE__STATIC;
int32_t TILE_HEAVYHBOMB = HEAVYHBOMB__STATIC;
int32_t TILE_TRIPBOMBSPRITE = TRIPBOMBSPRITE__STATIC;
int32_t TILE_SHOTGUNSPRITE = SHOTGUNSPRITE__STATIC;
int32_t TILE_DEVISTATORSPRITE = DEVISTATORSPRITE__STATIC;
int32_t TILE_HEALTHBOX = HEALTHBOX__STATIC;
int32_t TILE_AMMOBOX = AMMOBOX__STATIC;
int32_t TILE_GROWSPRITEICON = GROWSPRITEICON__STATIC;
int32_t TILE_INVENTORYBOX = INVENTORYBOX__STATIC;
int32_t TILE_FREEZEAMMO = FREEZEAMMO__STATIC;
int32_t TILE_AMMO = AMMO__STATIC;
int32_t TILE_BATTERYAMMO = BATTERYAMMO__STATIC;
int32_t TILE_DEVISTATORAMMO = DEVISTATORAMMO__STATIC;
int32_t TILE_RPGAMMO = RPGAMMO__STATIC;
int32_t TILE_GROWAMMO = GROWAMMO__STATIC;
int32_t TILE_CRYSTALAMMO = CRYSTALAMMO__STATIC;
int32_t TILE_HBOMBAMMO = HBOMBAMMO__STATIC;
int32_t TILE_AMMOLOTS = AMMOLOTS__STATIC;
int32_t TILE_SHOTGUNAMMO = SHOTGUNAMMO__STATIC;
int32_t TILE_COLA = COLA__STATIC;
int32_t TILE_SIXPAK = SIXPAK__STATIC;
int32_t TILE_FIRSTAID = FIRSTAID__STATIC;
int32_t TILE_SHIELD = SHIELD__STATIC;
int32_t TILE_STEROIDS = STEROIDS__STATIC;
int32_t TILE_AIRTANK = AIRTANK__STATIC;
int32_t TILE_JETPACK = JETPACK__STATIC;
int32_t TILE_HEATSENSOR = HEATSENSOR__STATIC;
int32_t TILE_ACCESSCARD = ACCESSCARD__STATIC;
int32_t TILE_BOOTS = BOOTS__STATIC;
int32_t TILE_MIRRORBROKE = MIRRORBROKE__STATIC;
int32_t TILE_CLOUDYOCEAN = CLOUDYOCEAN__STATIC;
int32_t TILE_CLOUDYSKIES = CLOUDYSKIES__STATIC;
int32_t TILE_MOONSKY1 = MOONSKY1__STATIC;
int32_t TILE_MOONSKY2 = MOONSKY2__STATIC;
int32_t TILE_MOONSKY3 = MOONSKY3__STATIC;
int32_t TILE_MOONSKY4 = MOONSKY4__STATIC;
int32_t TILE_BIGORBIT1 = BIGORBIT1__STATIC;
int32_t TILE_BIGORBIT2 = BIGORBIT2__STATIC;
int32_t TILE_BIGORBIT3 = BIGORBIT3__STATIC;
int32_t TILE_BIGORBIT4 = BIGORBIT4__STATIC;
int32_t TILE_BIGORBIT5 = BIGORBIT5__STATIC;
int32_t TILE_LA = LA__STATIC;
int32_t TILE_REDSKY1 = REDSKY1__STATIC;
int32_t TILE_REDSKY2 = REDSKY2__STATIC;
int32_t TILE_ATOMICHEALTH = ATOMICHEALTH__STATIC;
int32_t TILE_TECHLIGHT2 = TECHLIGHT2__STATIC;
int32_t TILE_TECHLIGHTBUST2 = TECHLIGHTBUST2__STATIC;
int32_t TILE_TECHLIGHT4 = TECHLIGHT4__STATIC;
int32_t TILE_TECHLIGHTBUST4 = TECHLIGHTBUST4__STATIC;
int32_t TILE_WALLLIGHT4 = WALLLIGHT4__STATIC;
int32_t TILE_WALLLIGHTBUST4 = WALLLIGHTBUST4__STATIC;
int32_t TILE_ACCESSSWITCH = ACCESSSWITCH__STATIC;
int32_t TILE_SLOTDOOR = SLOTDOOR__STATIC;
int32_t TILE_LIGHTSWITCH = LIGHTSWITCH__STATIC;
int32_t TILE_SPACEDOORSWITCH = SPACEDOORSWITCH__STATIC;
int32_t TILE_SPACELIGHTSWITCH = SPACELIGHTSWITCH__STATIC;
int32_t TILE_FRANKENSTINESWITCH = FRANKENSTINESWITCH__STATIC;
int32_t TILE_NUKEBUTTON = NUKEBUTTON__STATIC;
int32_t TILE_MULTISWITCH = MULTISWITCH__STATIC;
int32_t TILE_DOORTILE5 = DOORTILE5__STATIC;
int32_t TILE_DOORTILE6 = DOORTILE6__STATIC;
int32_t TILE_DOORTILE1 = DOORTILE1__STATIC;
int32_t TILE_DOORTILE2 = DOORTILE2__STATIC;
int32_t TILE_DOORTILE3 = DOORTILE3__STATIC;
int32_t TILE_DOORTILE4 = DOORTILE4__STATIC;
int32_t TILE_DOORTILE7 = DOORTILE7__STATIC;
int32_t TILE_DOORTILE8 = DOORTILE8__STATIC;
int32_t TILE_DOORTILE9 = DOORTILE9__STATIC;
int32_t TILE_DOORTILE10 = DOORTILE10__STATIC;
int32_t TILE_DOORSHOCK = DOORSHOCK__STATIC;
int32_t TILE_DIPSWITCH = DIPSWITCH__STATIC;
int32_t TILE_DIPSWITCH2 = DIPSWITCH2__STATIC;
int32_t TILE_TECHSWITCH = TECHSWITCH__STATIC;
int32_t TILE_DIPSWITCH3 = DIPSWITCH3__STATIC;
int32_t TILE_ACCESSSWITCH2 = ACCESSSWITCH2__STATIC;
int32_t TILE_REFLECTWATERTILE = REFLECTWATERTILE__STATIC;
int32_t TILE_FLOORSLIME = FLOORSLIME__STATIC;
int32_t TILE_BIGFORCE = BIGFORCE__STATIC;
int32_t TILE_EPISODE = EPISODE__STATIC;
int32_t TILE_MASKWALL9 = MASKWALL9__STATIC;
int32_t TILE_W_LIGHT = W_LIGHT__STATIC;
int32_t TILE_SCREENBREAK1 = SCREENBREAK1__STATIC;
int32_t TILE_SCREENBREAK2 = SCREENBREAK2__STATIC;
int32_t TILE_SCREENBREAK3 = SCREENBREAK3__STATIC;
int32_t TILE_SCREENBREAK4 = SCREENBREAK4__STATIC;
int32_t TILE_SCREENBREAK5 = SCREENBREAK5__STATIC;
int32_t TILE_SCREENBREAK6 = SCREENBREAK6__STATIC;
int32_t TILE_SCREENBREAK7 = SCREENBREAK7__STATIC;
int32_t TILE_SCREENBREAK8 = SCREENBREAK8__STATIC;
int32_t TILE_SCREENBREAK9 = SCREENBREAK9__STATIC;
int32_t TILE_SCREENBREAK10 = SCREENBREAK10__STATIC;
int32_t TILE_SCREENBREAK11 = SCREENBREAK11__STATIC;
int32_t TILE_SCREENBREAK12 = SCREENBREAK12__STATIC;
int32_t TILE_SCREENBREAK13 = SCREENBREAK13__STATIC;
int32_t TILE_MASKWALL1 = MASKWALL1__STATIC;
int32_t TILE_W_TECHWALL1 = W_TECHWALL1__STATIC;
int32_t TILE_W_TECHWALL2 = W_TECHWALL2__STATIC;
int32_t TILE_W_TECHWALL15 = W_TECHWALL15__STATIC;
int32_t TILE_W_TECHWALL3 = W_TECHWALL3__STATIC;
int32_t TILE_W_TECHWALL4 = W_TECHWALL4__STATIC;
int32_t TILE_W_TECHWALL10 = W_TECHWALL10__STATIC;
int32_t TILE_W_TECHWALL16 = W_TECHWALL16__STATIC;
int32_t TILE_WATERTILE2 = WATERTILE2__STATIC;
int32_t TILE_BPANNEL1 = BPANNEL1__STATIC;
int32_t TILE_PANNEL1 = PANNEL1__STATIC;
int32_t TILE_PANNEL2 = PANNEL2__STATIC;
int32_t TILE_WATERTILE = WATERTILE__STATIC;
int32_t TILE_STATIC = STATIC__STATIC;
int32_t TILE_W_SCREENBREAK = W_SCREENBREAK__STATIC;
int32_t TILE_W_HITTECHWALL3 = W_HITTECHWALL3__STATIC;
int32_t TILE_W_HITTECHWALL4 = W_HITTECHWALL4__STATIC;
int32_t TILE_W_HITTECHWALL2 = W_HITTECHWALL2__STATIC;
int32_t TILE_W_HITTECHWALL1 = W_HITTECHWALL1__STATIC;
int32_t TILE_MASKWALL10 = MASKWALL10__STATIC;
int32_t TILE_MASKWALL11 = MASKWALL11__STATIC;
int32_t TILE_DOORTILE22 = DOORTILE22__STATIC;
int32_t TILE_FANSPRITE = FANSPRITE__STATIC;
int32_t TILE_FANSPRITEBROKE = FANSPRITEBROKE__STATIC;
int32_t TILE_FANSHADOW = FANSHADOW__STATIC;
int32_t TILE_FANSHADOWBROKE = FANSHADOWBROKE__STATIC;
int32_t TILE_DOORTILE18 = DOORTILE18__STATIC;
int32_t TILE_DOORTILE19 = DOORTILE19__STATIC;
int32_t TILE_DOORTILE20 = DOORTILE20__STATIC;
int32_t TILE_SATELLITE = SATELLITE__STATIC;
int32_t TILE_VIEWSCREEN2 = VIEWSCREEN2__STATIC;
int32_t TILE_VIEWSCREENBROKE = VIEWSCREENBROKE__STATIC;
int32_t TILE_VIEWSCREEN = VIEWSCREEN__STATIC;
int32_t TILE_GLASS = GLASS__STATIC;
int32_t TILE_GLASS2 = GLASS2__STATIC;
int32_t TILE_STAINGLASS1 = STAINGLASS1__STATIC;
int32_t TILE_MASKWALL5 = MASKWALL5__STATIC;
int32_t TILE_SATELITE = SATELITE__STATIC;
int32_t TILE_FUELPOD = FUELPOD__STATIC;
int32_t TILE_SLIMEPIPE = SLIMEPIPE__STATIC;
int32_t TILE_CRACK1 = CRACK1__STATIC;
int32_t TILE_CRACK2 = CRACK2__STATIC;
int32_t TILE_CRACK3 = CRACK3__STATIC;
int32_t TILE_CRACK4 = CRACK4__STATIC;
int32_t TILE_FOOTPRINTS = FOOTPRINTS__STATIC;
int32_t TILE_DOMELITE = DOMELITE__STATIC;
int32_t TILE_CAMERAPOLE = CAMERAPOLE__STATIC;
int32_t TILE_CHAIR1 = CHAIR1__STATIC;
int32_t TILE_CHAIR2 = CHAIR2__STATIC;
int32_t TILE_BROKENCHAIR = BROKENCHAIR__STATIC;
int32_t TILE_MIRROR = MIRROR__STATIC;
int32_t TILE_WATERFOUNTAIN = WATERFOUNTAIN__STATIC;
int32_t TILE_WATERFOUNTAINBROKE = WATERFOUNTAINBROKE__STATIC;
int32_t TILE_FEMMAG1 = FEMMAG1__STATIC;
int32_t TILE_TOILET = TOILET__STATIC;
int32_t TILE_STALL = STALL__STATIC;
int32_t TILE_STALLBROKE = STALLBROKE__STATIC;
int32_t TILE_FEMMAG2 = FEMMAG2__STATIC;
int32_t TILE_REACTOR2 = REACTOR2__STATIC;
int32_t TILE_REACTOR2BURNT = REACTOR2BURNT__STATIC;
int32_t TILE_REACTOR2SPARK = REACTOR2SPARK__STATIC;
int32_t TILE_GRATE1 = GRATE1__STATIC;
int32_t TILE_BGRATE1 = BGRATE1__STATIC;
int32_t TILE_SOLARPANNEL = SOLARPANNEL__STATIC;
int32_t TILE_NAKED1 = NAKED1__STATIC;
int32_t TILE_ANTENNA = ANTENNA__STATIC;
int32_t TILE_MASKWALL12 = MASKWALL12__STATIC;
int32_t TILE_TOILETBROKE = TOILETBROKE__STATIC;
int32_t TILE_PIPE2 = PIPE2__STATIC;
int32_t TILE_PIPE1B = PIPE1B__STATIC;
int32_t TILE_PIPE3 = PIPE3__STATIC;
int32_t TILE_PIPE1 = PIPE1__STATIC;
int32_t TILE_CAMERA1 = CAMERA1__STATIC;
int32_t TILE_BRICK = BRICK__STATIC;
int32_t TILE_SPLINTERWOOD = SPLINTERWOOD__STATIC;
int32_t TILE_PIPE2B = PIPE2B__STATIC;
int32_t TILE_BOLT1 = BOLT1__STATIC;
int32_t TILE_W_NUMBERS = W_NUMBERS__STATIC;
int32_t TILE_WATERDRIP = WATERDRIP__STATIC;
int32_t TILE_WATERBUBBLE = WATERBUBBLE__STATIC;
int32_t TILE_WATERBUBBLEMAKER = WATERBUBBLEMAKER__STATIC;
int32_t TILE_W_FORCEFIELD = W_FORCEFIELD__STATIC;
int32_t TILE_VACUUM = VACUUM__STATIC;
int32_t TILE_FOOTPRINTS2 = FOOTPRINTS2__STATIC;
int32_t TILE_FOOTPRINTS3 = FOOTPRINTS3__STATIC;
int32_t TILE_FOOTPRINTS4 = FOOTPRINTS4__STATIC;
int32_t TILE_EGG = EGG__STATIC;
int32_t TILE_SCALE = SCALE__STATIC;
int32_t TILE_CHAIR3 = CHAIR3__STATIC;
int32_t TILE_CAMERALIGHT = CAMERALIGHT__STATIC;
int32_t TILE_MOVIECAMERA = MOVIECAMERA__STATIC;
int32_t TILE_IVUNIT = IVUNIT__STATIC;
int32_t TILE_POT1 = POT1__STATIC;
int32_t TILE_POT2 = POT2__STATIC;
int32_t TILE_POT3 = POT3__STATIC;
int32_t TILE_PIPE3B = PIPE3B__STATIC;
int32_t TILE_WALLLIGHT3 = WALLLIGHT3__STATIC;
int32_t TILE_WALLLIGHTBUST3 = WALLLIGHTBUST3__STATIC;
int32_t TILE_WALLLIGHT1 = WALLLIGHT1__STATIC;
int32_t TILE_WALLLIGHTBUST1 = WALLLIGHTBUST1__STATIC;
int32_t TILE_WALLLIGHT2 = WALLLIGHT2__STATIC;
int32_t TILE_WALLLIGHTBUST2 = WALLLIGHTBUST2__STATIC;
int32_t TILE_LIGHTSWITCH2 = LIGHTSWITCH2__STATIC;
int32_t TILE_WAITTOBESEATED = WAITTOBESEATED__STATIC;
int32_t TILE_DOORTILE14 = DOORTILE14__STATIC;
int32_t TILE_STATUE = STATUE__STATIC;
int32_t TILE_MIKE = MIKE__STATIC;
int32_t TILE_VASE = VASE__STATIC;
int32_t TILE_SUSHIPLATE1 = SUSHIPLATE1__STATIC;
int32_t TILE_SUSHIPLATE2 = SUSHIPLATE2__STATIC;
int32_t TILE_SUSHIPLATE3 = SUSHIPLATE3__STATIC;
int32_t TILE_SUSHIPLATE4 = SUSHIPLATE4__STATIC;
int32_t TILE_DOORTILE16 = DOORTILE16__STATIC;
int32_t TILE_SUSHIPLATE5 = SUSHIPLATE5__STATIC;
int32_t TILE_OJ = OJ__STATIC;
int32_t TILE_MASKWALL13 = MASKWALL13__STATIC;
int32_t TILE_HURTRAIL = HURTRAIL__STATIC;
int32_t TILE_POWERSWITCH1 = POWERSWITCH1__STATIC;
int32_t TILE_LOCKSWITCH1 = LOCKSWITCH1__STATIC;
int32_t TILE_POWERSWITCH2 = POWERSWITCH2__STATIC;
int32_t TILE_ATM = ATM__STATIC;
int32_t TILE_STATUEFLASH = STATUEFLASH__STATIC;
int32_t TILE_ATMBROKE = ATMBROKE__STATIC;
int32_t TILE_BIGHOLE2 = BIGHOLE2__STATIC;
int32_t TILE_STRIPEBALL = STRIPEBALL__STATIC;
int32_t TILE_QUEBALL = QUEBALL__STATIC;
int32_t TILE_POCKET = POCKET__STATIC;
int32_t TILE_WOODENHORSE = WOODENHORSE__STATIC;
int32_t TILE_TREE1 = TREE1__STATIC;
int32_t TILE_TREE2 = TREE2__STATIC;
int32_t TILE_CACTUS = CACTUS__STATIC;
int32_t TILE_MASKWALL2 = MASKWALL2__STATIC;
int32_t TILE_MASKWALL3 = MASKWALL3__STATIC;
int32_t TILE_MASKWALL4 = MASKWALL4__STATIC;
int32_t TILE_FIREEXT = FIREEXT__STATIC;
int32_t TILE_TOILETWATER = TOILETWATER__STATIC;
int32_t TILE_NEON1 = NEON1__STATIC;
int32_t TILE_NEON2 = NEON2__STATIC;
int32_t TILE_CACTUSBROKE = CACTUSBROKE__STATIC;
int32_t TILE_BOUNCEMINE = BOUNCEMINE__STATIC;
int32_t TILE_BROKEFIREHYDRENT = BROKEFIREHYDRENT__STATIC;
int32_t TILE_BOX = BOX__STATIC;
int32_t TILE_BULLETHOLE = BULLETHOLE__STATIC;
int32_t TILE_BOTTLE1 = BOTTLE1__STATIC;
int32_t TILE_BOTTLE2 = BOTTLE2__STATIC;
int32_t TILE_BOTTLE3 = BOTTLE3__STATIC;
int32_t TILE_BOTTLE4 = BOTTLE4__STATIC;
int32_t TILE_FEMPIC5 = FEMPIC5__STATIC;
int32_t TILE_FEMPIC6 = FEMPIC6__STATIC;
int32_t TILE_FEMPIC7 = FEMPIC7__STATIC;
int32_t TILE_HYDROPLANT = HYDROPLANT__STATIC;
int32_t TILE_OCEANSPRITE1 = OCEANSPRITE1__STATIC;
int32_t TILE_OCEANSPRITE2 = OCEANSPRITE2__STATIC;
int32_t TILE_OCEANSPRITE3 = OCEANSPRITE3__STATIC;
int32_t TILE_OCEANSPRITE4 = OCEANSPRITE4__STATIC;
int32_t TILE_OCEANSPRITE5 = OCEANSPRITE5__STATIC;
int32_t TILE_GENERICPOLE = GENERICPOLE__STATIC;
int32_t TILE_CONE = CONE__STATIC;
int32_t TILE_HANGLIGHT = HANGLIGHT__STATIC;
int32_t TILE_HYDRENT = HYDRENT__STATIC;
int32_t TILE_MASKWALL14 = MASKWALL14__STATIC;
int32_t TILE_TIRE = TIRE__STATIC;
int32_t TILE_PIPE5 = PIPE5__STATIC;
int32_t TILE_PIPE6 = PIPE6__STATIC;
int32_t TILE_PIPE4 = PIPE4__STATIC;
int32_t TILE_PIPE4B = PIPE4B__STATIC;
int32_t TILE_BROKEHYDROPLANT = BROKEHYDROPLANT__STATIC;
int32_t TILE_PIPE5B = PIPE5B__STATIC;
int32_t TILE_NEON3 = NEON3__STATIC;
int32_t TILE_NEON4 = NEON4__STATIC;
int32_t TILE_NEON5 = NEON5__STATIC;
int32_t TILE_BOTTLE5 = BOTTLE5__STATIC;
int32_t TILE_BOTTLE6 = BOTTLE6__STATIC;
int32_t TILE_BOTTLE8 = BOTTLE8__STATIC;
int32_t TILE_SPOTLITE = SPOTLITE__STATIC;
int32_t TILE_HANGOOZ = HANGOOZ__STATIC;
int32_t TILE_MASKWALL15 = MASKWALL15__STATIC;
int32_t TILE_BOTTLE7 = BOTTLE7__STATIC;
int32_t TILE_HORSEONSIDE = HORSEONSIDE__STATIC;
int32_t TILE_GLASSPIECES = GLASSPIECES__STATIC;
int32_t TILE_HORSELITE = HORSELITE__STATIC;
int32_t TILE_DONUTS = DONUTS__STATIC;
int32_t TILE_NEON6 = NEON6__STATIC;
int32_t TILE_MASKWALL6 = MASKWALL6__STATIC;
int32_t TILE_CLOCK = CLOCK__STATIC;
int32_t TILE_RUBBERCAN = RUBBERCAN__STATIC;
int32_t TILE_BROKENCLOCK = BROKENCLOCK__STATIC;
int32_t TILE_PLUG = PLUG__STATIC;
int32_t TILE_OOZFILTER = OOZFILTER__STATIC;
int32_t TILE_FLOORPLASMA = FLOORPLASMA__STATIC;
int32_t TILE_REACTOR = REACTOR__STATIC;
int32_t TILE_REACTORSPARK = REACTORSPARK__STATIC;
int32_t TILE_REACTORBURNT = REACTORBURNT__STATIC;
int32_t TILE_DOORTILE15 = DOORTILE15__STATIC;
int32_t TILE_HANDSWITCH = HANDSWITCH__STATIC;
int32_t TILE_CIRCLEPANNEL = CIRCLEPANNEL__STATIC;
int32_t TILE_CIRCLEPANNELBROKE = CIRCLEPANNELBROKE__STATIC;
int32_t TILE_PULLSWITCH = PULLSWITCH__STATIC;
int32_t TILE_MASKWALL8 = MASKWALL8__STATIC;
int32_t TILE_BIGHOLE = BIGHOLE__STATIC;
int32_t TILE_ALIENSWITCH = ALIENSWITCH__STATIC;
int32_t TILE_DOORTILE21 = DOORTILE21__STATIC;
int32_t TILE_HANDPRINTSWITCH = HANDPRINTSWITCH__STATIC;
int32_t TILE_BOTTLE10 = BOTTLE10__STATIC;
int32_t TILE_BOTTLE11 = BOTTLE11__STATIC;
int32_t TILE_BOTTLE12 = BOTTLE12__STATIC;
int32_t TILE_BOTTLE13 = BOTTLE13__STATIC;
int32_t TILE_BOTTLE14 = BOTTLE14__STATIC;
int32_t TILE_BOTTLE15 = BOTTLE15__STATIC;
int32_t TILE_BOTTLE16 = BOTTLE16__STATIC;
int32_t TILE_BOTTLE17 = BOTTLE17__STATIC;
int32_t TILE_BOTTLE18 = BOTTLE18__STATIC;
int32_t TILE_BOTTLE19 = BOTTLE19__STATIC;
int32_t TILE_DOORTILE17 = DOORTILE17__STATIC;
int32_t TILE_MASKWALL7 = MASKWALL7__STATIC;
int32_t TILE_JAILBARBREAK = JAILBARBREAK__STATIC;
int32_t TILE_DOORTILE11 = DOORTILE11__STATIC;
int32_t TILE_DOORTILE12 = DOORTILE12__STATIC;
int32_t TILE_VENDMACHINE = VENDMACHINE__STATIC;
int32_t TILE_VENDMACHINEBROKE = VENDMACHINEBROKE__STATIC;
int32_t TILE_COLAMACHINE = COLAMACHINE__STATIC;
int32_t TILE_COLAMACHINEBROKE = COLAMACHINEBROKE__STATIC;
int32_t TILE_CRANEPOLE = CRANEPOLE__STATIC;
int32_t TILE_CRANE = CRANE__STATIC;
int32_t TILE_BARBROKE = BARBROKE__STATIC;
int32_t TILE_BLOODPOOL = BLOODPOOL__STATIC;
int32_t TILE_NUKEBARREL = NUKEBARREL__STATIC;
int32_t TILE_NUKEBARRELDENTED = NUKEBARRELDENTED__STATIC;
int32_t TILE_NUKEBARRELLEAKED = NUKEBARRELLEAKED__STATIC;
int32_t TILE_CANWITHSOMETHING = CANWITHSOMETHING__STATIC;
int32_t TILE_MONEY = MONEY__STATIC;
int32_t TILE_BANNER = BANNER__STATIC;
int32_t TILE_EXPLODINGBARREL = EXPLODINGBARREL__STATIC;
int32_t TILE_EXPLODINGBARREL2 = EXPLODINGBARREL2__STATIC;
int32_t TILE_FIREBARREL = FIREBARREL__STATIC;
int32_t TILE_SEENINE = SEENINE__STATIC;
int32_t TILE_SEENINEDEAD = SEENINEDEAD__STATIC;
int32_t TILE_STEAM = STEAM__STATIC;
int32_t TILE_CEILINGSTEAM = CEILINGSTEAM__STATIC;
int32_t TILE_PIPE6B = PIPE6B__STATIC;
int32_t TILE_TRANSPORTERBEAM = TRANSPORTERBEAM__STATIC;
int32_t TILE_RAT = RAT__STATIC;
int32_t TILE_TRASH = TRASH__STATIC;
int32_t TILE_FEMPIC1 = FEMPIC1__STATIC;
int32_t TILE_FEMPIC2 = FEMPIC2__STATIC;
int32_t TILE_BLANKSCREEN = BLANKSCREEN__STATIC;
int32_t TILE_PODFEM1 = PODFEM1__STATIC;
int32_t TILE_FEMPIC3 = FEMPIC3__STATIC;
int32_t TILE_FEMPIC4 = FEMPIC4__STATIC;
int32_t TILE_FEM1 = FEM1__STATIC;
int32_t TILE_FEM2 = FEM2__STATIC;
int32_t TILE_FEM3 = FEM3__STATIC;
int32_t TILE_FEM5 = FEM5__STATIC;
int32_t TILE_BLOODYPOLE = BLOODYPOLE__STATIC;
int32_t TILE_FEM4 = FEM4__STATIC;
int32_t TILE_FEM6 = FEM6__STATIC;
int32_t TILE_FEM6PAD = FEM6PAD__STATIC;
int32_t TILE_FEM8 = FEM8__STATIC;
int32_t TILE_HELECOPT = HELECOPT__STATIC;
int32_t TILE_FETUSJIB = FETUSJIB__STATIC;
int32_t TILE_HOLODUKE = HOLODUKE__STATIC;
int32_t TILE_SPACEMARINE = SPACEMARINE__STATIC;
int32_t TILE_INDY = INDY__STATIC;
int32_t TILE_FETUS = FETUS__STATIC;
int32_t TILE_FETUSBROKE = FETUSBROKE__STATIC;
int32_t TILE_MONK = MONK__STATIC;
int32_t TILE_LUKE = LUKE__STATIC;
int32_t TILE_COOLEXPLOSION1 = COOLEXPLOSION1__STATIC;
int32_t TILE_WATERSPLASH2 = WATERSPLASH2__STATIC;
int32_t TILE_FIREVASE = FIREVASE__STATIC;
int32_t TILE_SCRATCH = SCRATCH__STATIC;
int32_t TILE_FEM7 = FEM7__STATIC;
int32_t TILE_APLAYERTOP = APLAYERTOP__STATIC;
int32_t TILE_APLAYER = APLAYER__STATIC;
int32_t TILE_PLAYERONWATER = PLAYERONWATER__STATIC;
int32_t TILE_DUKELYINGDEAD = DUKELYINGDEAD__STATIC;
int32_t TILE_DUKETORSO = DUKETORSO__STATIC;
int32_t TILE_DUKEGUN = DUKEGUN__STATIC;
int32_t TILE_DUKELEG = DUKELEG__STATIC;
int32_t TILE_SHARK = SHARK__STATIC;
int32_t TILE_BLOOD = BLOOD__STATIC;
int32_t TILE_FIRELASER = FIRELASER__STATIC;
int32_t TILE_TRANSPORTERSTAR = TRANSPORTERSTAR__STATIC;
int32_t TILE_SPIT = SPIT__STATIC;
int32_t TILE_LOOGIE = LOOGIE__STATIC;
int32_t TILE_FIST = FIST__STATIC;
int32_t TILE_FREEZEBLAST = FREEZEBLAST__STATIC;
int32_t TILE_DEVISTATORBLAST = DEVISTATORBLAST__STATIC;
int32_t TILE_SHRINKSPARK = SHRINKSPARK__STATIC;
int32_t TILE_TONGUE = TONGUE__STATIC;
int32_t TILE_MORTER = MORTER__STATIC;
int32_t TILE_SHRINKEREXPLOSION = SHRINKEREXPLOSION__STATIC;
int32_t TILE_RADIUSEXPLOSION = RADIUSEXPLOSION__STATIC;
int32_t TILE_FORCERIPPLE = FORCERIPPLE__STATIC;
int32_t TILE_LIZTROOP = LIZTROOP__STATIC;
int32_t TILE_LIZTROOPRUNNING = LIZTROOPRUNNING__STATIC;
int32_t TILE_LIZTROOPSTAYPUT = LIZTROOPSTAYPUT__STATIC;
int32_t TILE_LIZTOP = LIZTOP__STATIC;
int32_t TILE_LIZTROOPSHOOT = LIZTROOPSHOOT__STATIC;
int32_t TILE_LIZTROOPJETPACK = LIZTROOPJETPACK__STATIC;
int32_t TILE_LIZTROOPDSPRITE = LIZTROOPDSPRITE__STATIC;
int32_t TILE_LIZTROOPONTOILET = LIZTROOPONTOILET__STATIC;
int32_t TILE_LIZTROOPJUSTSIT = LIZTROOPJUSTSIT__STATIC;
int32_t TILE_LIZTROOPDUCKING = LIZTROOPDUCKING__STATIC;
int32_t TILE_HEADJIB1 = HEADJIB1__STATIC;
int32_t TILE_ARMJIB1 = ARMJIB1__STATIC;
int32_t TILE_LEGJIB1 = LEGJIB1__STATIC;
int32_t TILE_CANNONBALL = CANNONBALL__STATIC;
int32_t TILE_OCTABRAIN = OCTABRAIN__STATIC;
int32_t TILE_OCTABRAINSTAYPUT = OCTABRAINSTAYPUT__STATIC;
int32_t TILE_OCTATOP = OCTATOP__STATIC;
int32_t TILE_OCTADEADSPRITE = OCTADEADSPRITE__STATIC;
int32_t TILE_INNERJAW = INNERJAW__STATIC;
int32_t TILE_DRONE = DRONE__STATIC;
int32_t TILE_EXPLOSION2 = EXPLOSION2__STATIC;
int32_t TILE_COMMANDER = COMMANDER__STATIC;
int32_t TILE_COMMANDERSTAYPUT = COMMANDERSTAYPUT__STATIC;
int32_t TILE_RECON = RECON__STATIC;
int32_t TILE_TANK = TANK__STATIC;
int32_t TILE_PIGCOP = PIGCOP__STATIC;
int32_t TILE_PIGCOPSTAYPUT = PIGCOPSTAYPUT__STATIC;
int32_t TILE_PIGCOPDIVE = PIGCOPDIVE__STATIC;
int32_t TILE_PIGCOPDEADSPRITE = PIGCOPDEADSPRITE__STATIC;
int32_t TILE_PIGTOP = PIGTOP__STATIC;
int32_t TILE_LIZMAN = LIZMAN__STATIC;
int32_t TILE_LIZMANSTAYPUT = LIZMANSTAYPUT__STATIC;
int32_t TILE_LIZMANSPITTING = LIZMANSPITTING__STATIC;
int32_t TILE_LIZMANFEEDING = LIZMANFEEDING__STATIC;
int32_t TILE_LIZMANJUMP = LIZMANJUMP__STATIC;
int32_t TILE_LIZMANDEADSPRITE = LIZMANDEADSPRITE__STATIC;
int32_t TILE_FECES = FECES__STATIC;
int32_t TILE_LIZMANHEAD1 = LIZMANHEAD1__STATIC;
int32_t TILE_LIZMANARM1 = LIZMANARM1__STATIC;
int32_t TILE_LIZMANLEG1 = LIZMANLEG1__STATIC;
int32_t TILE_EXPLOSION2BOT = EXPLOSION2BOT__STATIC;
int32_t TILE_USERWEAPON = USERWEAPON__STATIC;
int32_t TILE_HEADERBAR = HEADERBAR__STATIC;
int32_t TILE_JIBS1 = JIBS1__STATIC;
int32_t TILE_JIBS2 = JIBS2__STATIC;
int32_t TILE_JIBS3 = JIBS3__STATIC;
int32_t TILE_JIBS4 = JIBS4__STATIC;
int32_t TILE_JIBS5 = JIBS5__STATIC;
int32_t TILE_BURNING = BURNING__STATIC;
int32_t TILE_FIRE = FIRE__STATIC;
int32_t TILE_JIBS6 = JIBS6__STATIC;
int32_t TILE_BLOODSPLAT1 = BLOODSPLAT1__STATIC;
int32_t TILE_BLOODSPLAT3 = BLOODSPLAT3__STATIC;
int32_t TILE_BLOODSPLAT2 = BLOODSPLAT2__STATIC;
int32_t TILE_BLOODSPLAT4 = BLOODSPLAT4__STATIC;
int32_t TILE_OOZ = OOZ__STATIC;
int32_t TILE_OOZ2 = OOZ2__STATIC;
int32_t TILE_WALLBLOOD1 = WALLBLOOD1__STATIC;
int32_t TILE_WALLBLOOD2 = WALLBLOOD2__STATIC;
int32_t TILE_WALLBLOOD3 = WALLBLOOD3__STATIC;
int32_t TILE_WALLBLOOD4 = WALLBLOOD4__STATIC;
int32_t TILE_WALLBLOOD5 = WALLBLOOD5__STATIC;
int32_t TILE_WALLBLOOD6 = WALLBLOOD6__STATIC;
int32_t TILE_WALLBLOOD7 = WALLBLOOD7__STATIC;
int32_t TILE_WALLBLOOD8 = WALLBLOOD8__STATIC;
int32_t TILE_BURNING2 = BURNING2__STATIC;
int32_t TILE_FIRE2 = FIRE2__STATIC;
int32_t TILE_CRACKKNUCKLES = CRACKKNUCKLES__STATIC;
int32_t TILE_SMALLSMOKE = SMALLSMOKE__STATIC;
int32_t TILE_SMALLSMOKEMAKER = SMALLSMOKEMAKER__STATIC;
int32_t TILE_FLOORFLAME = FLOORFLAME__STATIC;
int32_t TILE_ROTATEGUN = ROTATEGUN__STATIC;
int32_t TILE_GREENSLIME = GREENSLIME__STATIC;
int32_t TILE_WATERDRIPSPLASH = WATERDRIPSPLASH__STATIC;
int32_t TILE_SCRAP6 = SCRAP6__STATIC;
int32_t TILE_SCRAP1 = SCRAP1__STATIC;
int32_t TILE_SCRAP2 = SCRAP2__STATIC;
int32_t TILE_SCRAP3 = SCRAP3__STATIC;
int32_t TILE_SCRAP4 = SCRAP4__STATIC;
int32_t TILE_SCRAP5 = SCRAP5__STATIC;
int32_t TILE_ORGANTIC = ORGANTIC__STATIC;
int32_t TILE_BETAVERSION = BETAVERSION__STATIC;
int32_t TILE_PLAYERISHERE = PLAYERISHERE__STATIC;
int32_t TILE_PLAYERWASHERE = PLAYERWASHERE__STATIC;
int32_t TILE_SELECTDIR = SELECTDIR__STATIC;
int32_t TILE_F1HELP = F1HELP__STATIC;
int32_t TILE_NOTCHON = NOTCHON__STATIC;
int32_t TILE_NOTCHOFF = NOTCHOFF__STATIC;
int32_t TILE_GROWSPARK = GROWSPARK__STATIC;
int32_t TILE_DUKEICON = DUKEICON__STATIC;
int32_t TILE_BADGUYICON = BADGUYICON__STATIC;
int32_t TILE_FOODICON = FOODICON__STATIC;
int32_t TILE_GETICON = GETICON__STATIC;
int32_t TILE_MENUSCREEN = MENUSCREEN__STATIC;
int32_t TILE_MENUBAR = MENUBAR__STATIC;
int32_t TILE_KILLSICON = KILLSICON__STATIC;
int32_t TILE_FIRSTAID_ICON = FIRSTAID_ICON__STATIC;
int32_t TILE_HEAT_ICON = HEAT_ICON__STATIC;
int32_t TILE_BOTTOMSTATUSBAR = BOTTOMSTATUSBAR__STATIC;
int32_t TILE_BOOT_ICON = BOOT_ICON__STATIC;
int32_t TILE_FRAGBAR = FRAGBAR__STATIC;
int32_t TILE_JETPACK_ICON = JETPACK_ICON__STATIC;
int32_t TILE_AIRTANK_ICON = AIRTANK_ICON__STATIC;
int32_t TILE_STEROIDS_ICON = STEROIDS_ICON__STATIC;
int32_t TILE_HOLODUKE_ICON = HOLODUKE_ICON__STATIC;
int32_t TILE_ACCESS_ICON = ACCESS_ICON__STATIC;
int32_t TILE_DIGITALNUM = DIGITALNUM__STATIC;
int32_t TILE_DUKECAR = DUKECAR__STATIC;
int32_t TILE_CAMCORNER = CAMCORNER__STATIC;
int32_t TILE_CAMLIGHT = CAMLIGHT__STATIC;
int32_t TILE_LOGO = LOGO__STATIC;
int32_t TILE_TITLE = TITLE__STATIC;
int32_t TILE_NUKEWARNINGICON = NUKEWARNINGICON__STATIC;
int32_t TILE_MOUSECURSOR = MOUSECURSOR__STATIC;
int32_t TILE_SLIDEBAR = SLIDEBAR__STATIC;
int32_t TILE_DREALMS = DREALMS__STATIC;
int32_t TILE_BETASCREEN = BETASCREEN__STATIC;
int32_t TILE_WINDOWBORDER1 = WINDOWBORDER1__STATIC;
int32_t TILE_TEXTBOX = TEXTBOX__STATIC;
int32_t TILE_WINDOWBORDER2 = WINDOWBORDER2__STATIC;
int32_t TILE_DUKENUKEM = DUKENUKEM__STATIC;
int32_t TILE_THREEDEE = THREEDEE__STATIC;
int32_t TILE_INGAMEDUKETHREEDEE = INGAMEDUKETHREEDEE__STATIC;
int32_t TILE_TENSCREEN = TENSCREEN__STATIC;
int32_t TILE_PLUTOPAKSPRITE = PLUTOPAKSPRITE__STATIC;
int32_t TILE_DEVISTATOR = DEVISTATOR__STATIC;
int32_t TILE_KNEE = KNEE__STATIC;
int32_t TILE_CROSSHAIR = CROSSHAIR__STATIC;
int32_t TILE_FIRSTGUN = FIRSTGUN__STATIC;
int32_t TILE_FIRSTGUNRELOAD = FIRSTGUNRELOAD__STATIC;
int32_t TILE_FALLINGCLIP = FALLINGCLIP__STATIC;
int32_t TILE_CLIPINHAND = CLIPINHAND__STATIC;
int32_t TILE_HAND = HAND__STATIC;
int32_t TILE_SHELL = SHELL__STATIC;
int32_t TILE_SHOTGUNSHELL = SHOTGUNSHELL__STATIC;
int32_t TILE_CHAINGUN = CHAINGUN__STATIC;
int32_t TILE_RPGGUN = RPGGUN__STATIC;
int32_t TILE_RPGMUZZLEFLASH = RPGMUZZLEFLASH__STATIC;
int32_t TILE_FREEZE = FREEZE__STATIC;
int32_t TILE_CATLITE = CATLITE__STATIC;
int32_t TILE_SHRINKER = SHRINKER__STATIC;
int32_t TILE_HANDHOLDINGLASER = HANDHOLDINGLASER__STATIC;
int32_t TILE_TRIPBOMB = TRIPBOMB__STATIC;
int32_t TILE_LASERLINE = LASERLINE__STATIC;
int32_t TILE_HANDHOLDINGACCESS = HANDHOLDINGACCESS__STATIC;
int32_t TILE_HANDREMOTE = HANDREMOTE__STATIC;
int32_t TILE_HANDTHROW = HANDTHROW__STATIC;
int32_t TILE_TIP = TIP__STATIC;
int32_t TILE_GLAIR = GLAIR__STATIC;
int32_t TILE_SCUBAMASK = SCUBAMASK__STATIC;
int32_t TILE_SPACEMASK = SPACEMASK__STATIC;
int32_t TILE_FORCESPHERE = FORCESPHERE__STATIC;
int32_t TILE_SHOTSPARK1 = SHOTSPARK1__STATIC;
int32_t TILE_RPG = RPG__STATIC;
int32_t TILE_LASERSITE = LASERSITE__STATIC;
int32_t TILE_SHOTGUN = SHOTGUN__STATIC;
int32_t TILE_BOSS1 = BOSS1__STATIC;
int32_t TILE_BOSS1STAYPUT = BOSS1STAYPUT__STATIC;
int32_t TILE_BOSS1SHOOT = BOSS1SHOOT__STATIC;
int32_t TILE_BOSS1LOB = BOSS1LOB__STATIC;
int32_t TILE_BOSSTOP = BOSSTOP__STATIC;
int32_t TILE_BOSS2 = BOSS2__STATIC;
int32_t TILE_BOSS3 = BOSS3__STATIC;
int32_t TILE_SPINNINGNUKEICON = SPINNINGNUKEICON__STATIC;
int32_t TILE_BIGFNTCURSOR = BIGFNTCURSOR__STATIC;
int32_t TILE_SMALLFNTCURSOR = SMALLFNTCURSOR__STATIC;
int32_t TILE_STARTALPHANUM = STARTALPHANUM__STATIC;
int32_t TILE_ENDALPHANUM = ENDALPHANUM__STATIC;
int32_t TILE_BIGALPHANUM = BIGALPHANUM__STATIC;
int32_t TILE_BIGPERIOD = BIGPERIOD__STATIC;
int32_t TILE_BIGCOMMA = BIGCOMMA__STATIC;
// "BIGX" clashes on the Wii?
int32_t TILE_BIGX_ = BIGX__STATIC;
int32_t TILE_BIGQ = BIGQ__STATIC;
int32_t TILE_BIGSEMI = BIGSEMI__STATIC;
int32_t TILE_BIGCOLIN = BIGCOLIN__STATIC;
int32_t TILE_THREEBYFIVE = THREEBYFIVE__STATIC;
int32_t TILE_BIGAPPOS = BIGAPPOS__STATIC;
int32_t TILE_BLANK = BLANK__STATIC;
int32_t TILE_MINIFONT = MINIFONT__STATIC;
int32_t TILE_BUTTON1 = BUTTON1__STATIC;
int32_t TILE_GLASS3 = GLASS3__STATIC;
int32_t TILE_RESPAWNMARKERRED = RESPAWNMARKERRED__STATIC;
int32_t TILE_RESPAWNMARKERYELLOW = RESPAWNMARKERYELLOW__STATIC;
int32_t TILE_RESPAWNMARKERGREEN = RESPAWNMARKERGREEN__STATIC;
int32_t TILE_BONUSSCREEN = BONUSSCREEN__STATIC;
int32_t TILE_VIEWBORDER = VIEWBORDER__STATIC;
int32_t TILE_VICTORY1 = VICTORY1__STATIC;
int32_t TILE_ORDERING = ORDERING__STATIC;
int32_t TILE_TEXTSTORY = TEXTSTORY__STATIC;
int32_t TILE_LOADSCREEN = LOADSCREEN__STATIC;
int32_t TILE_BORNTOBEWILDSCREEN = BORNTOBEWILDSCREEN__STATIC;
int32_t TILE_BLIMP = BLIMP__STATIC;
int32_t TILE_FEM9 = FEM9__STATIC;
int32_t TILE_FOOTPRINT = FOOTPRINT__STATIC;
int32_t TILE_POOP = POOP__STATIC;
int32_t TILE_FRAMEEFFECT1 = FRAMEEFFECT1__STATIC;
int32_t TILE_PANNEL3 = PANNEL3__STATIC;
int32_t TILE_SCREENBREAK14 = SCREENBREAK14__STATIC;
int32_t TILE_SCREENBREAK15 = SCREENBREAK15__STATIC;
int32_t TILE_SCREENBREAK19 = SCREENBREAK19__STATIC;
int32_t TILE_SCREENBREAK16 = SCREENBREAK16__STATIC;
int32_t TILE_SCREENBREAK17 = SCREENBREAK17__STATIC;
int32_t TILE_SCREENBREAK18 = SCREENBREAK18__STATIC;
int32_t TILE_W_TECHWALL11 = W_TECHWALL11__STATIC;
int32_t TILE_W_TECHWALL12 = W_TECHWALL12__STATIC;
int32_t TILE_W_TECHWALL13 = W_TECHWALL13__STATIC;
int32_t TILE_W_TECHWALL14 = W_TECHWALL14__STATIC;
int32_t TILE_W_TECHWALL5 = W_TECHWALL5__STATIC;
int32_t TILE_W_TECHWALL6 = W_TECHWALL6__STATIC;
int32_t TILE_W_TECHWALL7 = W_TECHWALL7__STATIC;
int32_t TILE_W_TECHWALL8 = W_TECHWALL8__STATIC;
int32_t TILE_W_TECHWALL9 = W_TECHWALL9__STATIC;
int32_t TILE_BPANNEL3 = BPANNEL3__STATIC;
int32_t TILE_W_HITTECHWALL16 = W_HITTECHWALL16__STATIC;
int32_t TILE_W_HITTECHWALL10 = W_HITTECHWALL10__STATIC;
int32_t TILE_W_HITTECHWALL15 = W_HITTECHWALL15__STATIC;
int32_t TILE_W_MILKSHELF = W_MILKSHELF__STATIC;
int32_t TILE_W_MILKSHELFBROKE = W_MILKSHELFBROKE__STATIC;
int32_t TILE_PURPLELAVA = PURPLELAVA__STATIC;
int32_t TILE_LAVABUBBLE = LAVABUBBLE__STATIC;
int32_t TILE_DUKECUTOUT = DUKECUTOUT__STATIC;
int32_t TILE_TARGET = TARGET__STATIC;
int32_t TILE_GUNPOWDERBARREL = GUNPOWDERBARREL__STATIC;
int32_t TILE_DUCK = DUCK__STATIC;
int32_t TILE_HATRACK = HATRACK__STATIC;
int32_t TILE_DESKLAMP = DESKLAMP__STATIC;
int32_t TILE_COFFEEMACHINE = COFFEEMACHINE__STATIC;
int32_t TILE_CUPS = CUPS__STATIC;
int32_t TILE_GAVALS = GAVALS__STATIC;
int32_t TILE_GAVALS2 = GAVALS2__STATIC;
int32_t TILE_POLICELIGHTPOLE = POLICELIGHTPOLE__STATIC;
int32_t TILE_FLOORBASKET = FLOORBASKET__STATIC;
int32_t TILE_PUKE = PUKE__STATIC;
int32_t TILE_DOORTILE23 = DOORTILE23__STATIC;
int32_t TILE_TOPSECRET = TOPSECRET__STATIC;
int32_t TILE_SPEAKER = SPEAKER__STATIC;
int32_t TILE_TEDDYBEAR = TEDDYBEAR__STATIC;
int32_t TILE_ROBOTDOG = ROBOTDOG__STATIC;
int32_t TILE_ROBOTPIRATE = ROBOTPIRATE__STATIC;
int32_t TILE_ROBOTMOUSE = ROBOTMOUSE__STATIC;
int32_t TILE_MAIL = MAIL__STATIC;
int32_t TILE_MAILBAG = MAILBAG__STATIC;
int32_t TILE_HOTMEAT = HOTMEAT__STATIC;
int32_t TILE_COFFEEMUG = COFFEEMUG__STATIC;
int32_t TILE_DONUTS2 = DONUTS2__STATIC;
int32_t TILE_TRIPODCAMERA = TRIPODCAMERA__STATIC;
int32_t TILE_METER = METER__STATIC;
int32_t TILE_DESKPHONE = DESKPHONE__STATIC;
int32_t TILE_GUMBALLMACHINE = GUMBALLMACHINE__STATIC;
int32_t TILE_GUMBALLMACHINEBROKE = GUMBALLMACHINEBROKE__STATIC;
int32_t TILE_PAPER = PAPER__STATIC;
int32_t TILE_MACE = MACE__STATIC;
int32_t TILE_GENERICPOLE2 = GENERICPOLE2__STATIC;
int32_t TILE_XXXSTACY = XXXSTACY__STATIC;
int32_t TILE_WETFLOOR = WETFLOOR__STATIC;
int32_t TILE_BROOM = BROOM__STATIC;
int32_t TILE_MOP = MOP__STATIC;
int32_t TILE_LETTER = LETTER__STATIC;
int32_t TILE_PIRATE1A = PIRATE1A__STATIC;
int32_t TILE_PIRATE4A = PIRATE4A__STATIC;
int32_t TILE_PIRATE2A = PIRATE2A__STATIC;
int32_t TILE_PIRATE5A = PIRATE5A__STATIC;
int32_t TILE_PIRATE3A = PIRATE3A__STATIC;
int32_t TILE_PIRATE6A = PIRATE6A__STATIC;
int32_t TILE_PIRATEHALF = PIRATEHALF__STATIC;
int32_t TILE_CHESTOFGOLD = CHESTOFGOLD__STATIC;
int32_t TILE_SIDEBOLT1 = SIDEBOLT1__STATIC;
int32_t TILE_FOODOBJECT1 = FOODOBJECT1__STATIC;
int32_t TILE_FOODOBJECT2 = FOODOBJECT2__STATIC;
int32_t TILE_FOODOBJECT3 = FOODOBJECT3__STATIC;
int32_t TILE_FOODOBJECT4 = FOODOBJECT4__STATIC;
int32_t TILE_FOODOBJECT5 = FOODOBJECT5__STATIC;
int32_t TILE_FOODOBJECT6 = FOODOBJECT6__STATIC;
int32_t TILE_FOODOBJECT7 = FOODOBJECT7__STATIC;
int32_t TILE_FOODOBJECT8 = FOODOBJECT8__STATIC;
int32_t TILE_FOODOBJECT9 = FOODOBJECT9__STATIC;
int32_t TILE_FOODOBJECT10 = FOODOBJECT10__STATIC;
int32_t TILE_FOODOBJECT11 = FOODOBJECT11__STATIC;
int32_t TILE_FOODOBJECT12 = FOODOBJECT12__STATIC;
int32_t TILE_FOODOBJECT13 = FOODOBJECT13__STATIC;
int32_t TILE_FOODOBJECT14 = FOODOBJECT14__STATIC;
int32_t TILE_FOODOBJECT15 = FOODOBJECT15__STATIC;
int32_t TILE_FOODOBJECT16 = FOODOBJECT16__STATIC;
int32_t TILE_FOODOBJECT17 = FOODOBJECT17__STATIC;
int32_t TILE_FOODOBJECT18 = FOODOBJECT18__STATIC;
int32_t TILE_FOODOBJECT19 = FOODOBJECT19__STATIC;
int32_t TILE_FOODOBJECT20 = FOODOBJECT20__STATIC;
int32_t TILE_HEADLAMP = HEADLAMP__STATIC;
int32_t TILE_TAMPON = TAMPON__STATIC;
int32_t TILE_SKINNEDCHICKEN = SKINNEDCHICKEN__STATIC;
int32_t TILE_FEATHEREDCHICKEN = FEATHEREDCHICKEN__STATIC;
int32_t TILE_ROBOTDOG2 = ROBOTDOG2__STATIC;
int32_t TILE_JOLLYMEAL = JOLLYMEAL__STATIC;
int32_t TILE_DUKEBURGER = DUKEBURGER__STATIC;
int32_t TILE_SHOPPINGCART = SHOPPINGCART__STATIC;
int32_t TILE_CANWITHSOMETHING2 = CANWITHSOMETHING2__STATIC;
int32_t TILE_CANWITHSOMETHING3 = CANWITHSOMETHING3__STATIC;
int32_t TILE_CANWITHSOMETHING4 = CANWITHSOMETHING4__STATIC;
int32_t TILE_SNAKEP = SNAKEP__STATIC;
int32_t TILE_DOLPHIN1 = DOLPHIN1__STATIC;
int32_t TILE_DOLPHIN2 = DOLPHIN2__STATIC;
int32_t TILE_NEWBEAST = NEWBEAST__STATIC;
int32_t TILE_NEWBEASTSTAYPUT = NEWBEASTSTAYPUT__STATIC;
int32_t TILE_NEWBEASTJUMP = NEWBEASTJUMP__STATIC;
int32_t TILE_NEWBEASTHANG = NEWBEASTHANG__STATIC;
int32_t TILE_NEWBEASTHANGDEAD = NEWBEASTHANGDEAD__STATIC;
int32_t TILE_BOSS4 = BOSS4__STATIC;
int32_t TILE_BOSS4STAYPUT = BOSS4STAYPUT__STATIC;
int32_t TILE_FEM10 = FEM10__STATIC;
int32_t TILE_TOUGHGAL = TOUGHGAL__STATIC;
int32_t TILE_MAN = MAN__STATIC;
int32_t TILE_MAN2 = MAN2__STATIC;
int32_t TILE_WOMAN = WOMAN__STATIC;
int32_t TILE_PLEASEWAIT = PLEASEWAIT__STATIC;
int32_t TILE_NATURALLIGHTNING = NATURALLIGHTNING__STATIC;
int32_t TILE_WEATHERWARN = WEATHERWARN__STATIC;
int32_t TILE_DUKETAG = DUKETAG__STATIC;
int32_t TILE_SIGN1 = SIGN1__STATIC;
int32_t TILE_SIGN2 = SIGN2__STATIC;
int32_t TILE_JURYGUY = JURYGUY__STATIC;

int32_t TILE_RRTILE11 = 0;
int32_t TILE_RPG2SPRITE = 0;
int32_t TILE_RRTILE18 = 0;
int32_t TILE_RRTILE19 = 0;
int32_t TILE_RRTILE34 = 0;
int32_t TILE_RRTILE35 = 0;
int32_t TILE_DESTRUCTO = 0;
int32_t TILE_RRTILE38 = 0;
int32_t TILE_RRTILE43 = 0;
int32_t TILE_GUTMETER = 0;
int32_t TILE_RRTILE63 = 0;
int32_t TILE_RRTILE64 = 0;
int32_t TILE_RRTILE65 = 0;
int32_t TILE_RRTILE66 = 0;
int32_t TILE_RRTILE67 = 0;
int32_t TILE_RRTILE68 = 0;
int32_t TILE_SOUNDFX = 0;
int32_t TILE_MOTOAMMO = 0;
int32_t TILE_UFOBEAM = 0;
int32_t TILE_RRTILE280 = 0;
int32_t TILE_RRTILE281 = 0;
int32_t TILE_RRTILE282 = 0;
int32_t TILE_RRTILE283 = 0;
int32_t TILE_RRTILE285 = 0;
int32_t TILE_RRTILE286 = 0;
int32_t TILE_RRTILE287 = 0;
int32_t TILE_RRTILE288 = 0;
int32_t TILE_RRTILE289 = 0;
int32_t TILE_RRTILE290 = 0;
int32_t TILE_RRTILE291 = 0;
int32_t TILE_RRTILE292 = 0;
int32_t TILE_RRTILE293 = 0;
int32_t TILE_RRTILE295 = 0;
int32_t TILE_RRTILE296 = 0;
int32_t TILE_RRTILE297 = 0;
int32_t TILE_CDPLAYER = 0;
int32_t TILE_RRTILE380 = 0;
int32_t TILE_RRTILE403 = 0;
int32_t TILE_RRTILE409 = 0;
int32_t TILE_GUTMETER_LIGHT1 = 0;
int32_t TILE_GUTMETER_LIGHT2 = 0;
int32_t TILE_GUTMETER_LIGHT3 = 0;
int32_t TILE_GUTMETER_LIGHT4 = 0;
int32_t TILE_AMMO_ICON = 0;
int32_t TILE_RRTILE1076 = 0;
int32_t TILE_MUD = 0;
int32_t TILE_EXPLOSION3 = 0;
int32_t TILE_RRTILE1636 = 0;
int32_t TILE_WEAPONBAR = 0;
int32_t TILE_RRTILE1752 = 0;
int32_t TILE_RPG2 = 0;
int32_t TILE_RRTILE1790 = 0;
int32_t TILE_RRTILE1792 = 0;
int32_t TILE_RRTILE1801 = 0;
int32_t TILE_RRTILE1805 = 0;
int32_t TILE_RRTILE1807 = 0;
int32_t TILE_RRTILE1808 = 0;
int32_t TILE_RRTILE1812 = 0;
int32_t TILE_RRTILE1814 = 0;
int32_t TILE_RRTILE1817 = 0;
int32_t TILE_RRTILE1821 = 0;
int32_t TILE_RRTILE1824 = 0;
int32_t TILE_RRTILE1826 = 0;
int32_t TILE_RRTILE1850 = 0;
int32_t TILE_RRTILE1851 = 0;
int32_t TILE_RRTILE1856 = 0;
int32_t TILE_RRTILE1877 = 0;
int32_t TILE_RRTILE1878 = 0;
int32_t TILE_RRTILE1938 = 0;
int32_t TILE_RRTILE1939 = 0;
int32_t TILE_RRTILE1942 = 0;
int32_t TILE_RRTILE1944 = 0;
int32_t TILE_RRTILE1945 = 0;
int32_t TILE_RRTILE1947 = 0;
int32_t TILE_RRTILE1951 = 0;
int32_t TILE_RRTILE1952 = 0;
int32_t TILE_RRTILE1953 = 0;
int32_t TILE_RRTILE1961 = 0;
int32_t TILE_RRTILE1964 = 0;
int32_t TILE_RRTILE1973 = 0;
int32_t TILE_RRTILE1985 = 0;
int32_t TILE_RRTILE1986 = 0;
int32_t TILE_RRTILE1987 = 0;
int32_t TILE_RRTILE1988 = 0;
int32_t TILE_RRTILE1990 = 0;
int32_t TILE_RRTILE1995 = 0;
int32_t TILE_RRTILE1996 = 0;
int32_t TILE_RRTILE2004 = 0;
int32_t TILE_RRTILE2005 = 0;
int32_t TILE_POPCORN = 0;
int32_t TILE_RRTILE2022 = 0;
int32_t TILE_LANEPICS = 0;
int32_t TILE_RRTILE2025 = 0;
int32_t TILE_RRTILE2026 = 0;
int32_t TILE_RRTILE2027 = 0;
int32_t TILE_RRTILE2028 = 0;
int32_t TILE_RRTILE2034 = 0;
int32_t TILE_RRTILE2050 = 0;
int32_t TILE_RRTILE2052 = 0;
int32_t TILE_RRTILE2053 = 0;
int32_t TILE_RRTILE2056 = 0;
int32_t TILE_RRTILE2060 = 0;
int32_t TILE_RRTILE2072 = 0;
int32_t TILE_RRTILE2074 = 0;
int32_t TILE_RRTILE2075 = 0;
int32_t TILE_RRTILE2083 = 0;
int32_t TILE_RRTILE2097 = 0;
int32_t TILE_RRTILE2121 = 0;
int32_t TILE_RRTILE2122 = 0;
int32_t TILE_RRTILE2123 = 0;
int32_t TILE_RRTILE2124 = 0;
int32_t TILE_RRTILE2125 = 0;
int32_t TILE_RRTILE2126 = 0;
int32_t TILE_RRTILE2137 = 0;
int32_t TILE_RRTILE2132 = 0;
int32_t TILE_RRTILE2136 = 0;
int32_t TILE_RRTILE2139 = 0;
int32_t TILE_RRTILE2150 = 0;
int32_t TILE_RRTILE2151 = 0;
int32_t TILE_RRTILE2152 = 0;
int32_t TILE_RRTILE2156 = 0;
int32_t TILE_RRTILE2157 = 0;
int32_t TILE_RRTILE2158 = 0;
int32_t TILE_RRTILE2159 = 0;
int32_t TILE_RRTILE2160 = 0;
int32_t TILE_RRTILE2161 = 0;
int32_t TILE_RRTILE2175 = 0;
int32_t TILE_RRTILE2176 = 0;
int32_t TILE_RRTILE2178 = 0;
int32_t TILE_RRTILE2186 = 0;
int32_t TILE_RRTILE2214 = 0;
int32_t TILE_RRTILE2319 = 0;
int32_t TILE_RRTILE2321 = 0;
int32_t TILE_RRTILE2326 = 0;
int32_t TILE_RRTILE2329 = 0;
int32_t TILE_RRTILE2357 = 0;
int32_t TILE_RRTILE2382 = 0;
int32_t TILE_RRTILE2430 = 0;
int32_t TILE_RRTILE2431 = 0;
int32_t TILE_RRTILE2432 = 0;
int32_t TILE_RRTILE2437 = 0;
int32_t TILE_RRTILE2443 = 0;
int32_t TILE_RRTILE2445 = 0;
int32_t TILE_RRTILE2446 = 0;
int32_t TILE_RRTILE2450 = 0;
int32_t TILE_RRTILE2451 = 0;
int32_t TILE_RRTILE2455 = 0;
int32_t TILE_RRTILE2460 = 0;
int32_t TILE_RRTILE2465 = 0;
int32_t TILE_RRTILE2560 = 0;
int32_t TILE_RRTILE2562 = 0;
int32_t TILE_RRTILE2564 = 0;
int32_t TILE_RRTILE2573 = 0;
int32_t TILE_RRTILE2574 = 0;
int32_t TILE_RRTILE2577 = 0;
int32_t TILE_RRTILE2578 = 0;
int32_t TILE_RRTILE2581 = 0;
int32_t TILE_RRTILE2583 = 0;
int32_t TILE_RRTILE2604 = 0;
int32_t TILE_RRTILE2610 = 0;
int32_t TILE_RRTILE2613 = 0;
int32_t TILE_RRTILE2621 = 0;
int32_t TILE_RRTILE2622 = 0;
int32_t TILE_RRTILE2636 = 0;
int32_t TILE_RRTILE2637 = 0;
int32_t TILE_RRTILE2654 = 0;
int32_t TILE_RRTILE2656 = 0;
int32_t TILE_RRTILE2676 = 0;
int32_t TILE_RRTILE2689 = 0;
int32_t TILE_RRTILE2697 = 0;
int32_t TILE_RRTILE2702 = 0;
int32_t TILE_RRTILE2707 = 0;
int32_t TILE_RRTILE2732 = 0;
int32_t TILE_RRTILE2030 = 0;
int32_t TILE_RRTILE2831 = 0;
int32_t TILE_RRTILE2832 = 0;
int32_t TILE_RRTILE2842 = 0;
int32_t TILE_RRTILE2859 = 0;
int32_t TILE_RRTILE2876 = 0;
int32_t TILE_RRTILE2878 = 0;
int32_t TILE_RRTILE2879 = 0;
int32_t TILE_RRTILE2893 = 0;
int32_t TILE_RRTILE2894 = 0;
int32_t TILE_RRTILE2898 = 0;
int32_t TILE_RRTILE2899 = 0;
int32_t TILE_RRTILE2915 = 0;
int32_t TILE_RRTILE2940 = 0;
int32_t TILE_RRTILE2944 = 0;
int32_t TILE_RRTILE2945 = 0;
int32_t TILE_RRTILE2946 = 0;
int32_t TILE_RRTILE2947 = 0;
int32_t TILE_RRTILE2948 = 0;
int32_t TILE_RRTILE2949 = 0;
int32_t TILE_RRTILE2961 = 0;
int32_t TILE_RRTILE2970 = 0;
int32_t TILE_RRTILE2977 = 0;
int32_t TILE_RRTILE2978 = 0;
int32_t TILE_RRTILE2990 = 0;
int32_t TILE_RRTILE3073 = 0;
int32_t TILE_RRTILE3083 = 0;
int32_t TILE_RRTILE3100 = 0;
int32_t TILE_RRTILE3114 = 0;
int32_t TILE_RRTILE3115 = 0;
int32_t TILE_RRTILE3116 = 0;
int32_t TILE_RRTILE3117 = 0;
int32_t TILE_RRTILE3120 = 0;
int32_t TILE_RRTILE3121 = 0;
int32_t TILE_RRTILE3122 = 0;
int32_t TILE_RRTILE3123 = 0;
int32_t TILE_RRTILE3124 = 0;
int32_t TILE_RRTILE3132 = 0;
int32_t TILE_RRTILE3139 = 0;
int32_t TILE_RRTILE3144 = 0;
int32_t TILE_RRTILE3152 = 0;
int32_t TILE_RRTILE3153 = 0;
int32_t TILE_RRTILE3155 = 0;
int32_t TILE_RRTILE3171 = 0;
int32_t TILE_RRTILE3172 = 0;
int32_t TILE_RRTILE3190 = 0;
int32_t TILE_RRTILE3191 = 0;
int32_t TILE_RRTILE3192 = 0;
int32_t TILE_RRTILE3195 = 0;
int32_t TILE_RRTILE3200 = 0;
int32_t TILE_RRTILE3201 = 0;
int32_t TILE_RRTILE3202 = 0;
int32_t TILE_RRTILE3203 = 0;
int32_t TILE_RRTILE3204 = 0;
int32_t TILE_RRTILE3205 = 0;
int32_t TILE_RRTILE3206 = 0;
int32_t TILE_RRTILE3207 = 0;
int32_t TILE_RRTILE3208 = 0;
int32_t TILE_RRTILE3209 = 0;
int32_t TILE_RRTILE3216 = 0;
int32_t TILE_RRTILE3218 = 0;
int32_t TILE_RRTILE3219 = 0;
int32_t TILE_RRTILE3232 = 0;
int32_t TILE_SHOTGUNSHELLS = 0;
int32_t TILE_CIRCLESTUCK = 0;
int32_t TILE_RRTILE3410 = 0;
int32_t TILE_LUMBERBLADE = 0;
int32_t TILE_BOWLINGBALLH = 0;
int32_t TILE_BOWLINGBALL = 0;
int32_t TILE_BOWLINGBALLSPRITE = 0;
int32_t TILE_POWDERH = 0;
int32_t TILE_RRTILE3440 = 0;
int32_t TILE_RRTILE3462 = 0;
int32_t TILE_OWHIP = 0;
int32_t TILE_UWHIP = 0;
int32_t TILE_RPGGUN2 = 0;
int32_t TILE_RRTILE3497 = 0;
int32_t TILE_RRTILE3498 = 0;
int32_t TILE_RRTILE3499 = 0;
int32_t TILE_RRTILE3500 = 0;
int32_t TILE_SLINGBLADE = 0;
int32_t TILE_RRTILE3584 = 0;
int32_t TILE_RRTILE3586 = 0;
int32_t TILE_RRTILE3587 = 0;
int32_t TILE_RRTILE3600 = 0;
int32_t TILE_RRTILE3631 = 0;
int32_t TILE_RRTILE3635 = 0;
int32_t TILE_RRTILE3637 = 0;
int32_t TILE_RRTILE3643 = 0;
int32_t TILE_RRTILE3647 = 0;
int32_t TILE_RRTILE3652 = 0;
int32_t TILE_RRTILE3653 = 0;
int32_t TILE_RRTILE3668 = 0;
int32_t TILE_RRTILE3671 = 0;
int32_t TILE_RRTILE3673 = 0;
int32_t TILE_RRTILE3677 = 0;
int32_t TILE_RRTILE3684 = 0;
int32_t TILE_RRTILE3708 = 0;
int32_t TILE_RRTILE3714 = 0;
int32_t TILE_RRTILE3716 = 0;
int32_t TILE_RRTILE3720 = 0;
int32_t TILE_RRTILE3723 = 0;
int32_t TILE_RRTILE3725 = 0;
int32_t TILE_RRTILE3737 = 0;
int32_t TILE_RRTILE3754 = 0;
int32_t TILE_RRTILE3762 = 0;
int32_t TILE_RRTILE3763 = 0;
int32_t TILE_RRTILE3764 = 0;
int32_t TILE_RRTILE3765 = 0;
int32_t TILE_RRTILE3767 = 0;
int32_t TILE_RRTILE3773 = 0;
int32_t TILE_RRTILE3774 = 0;
int32_t TILE_RRTILE3793 = 0;
int32_t TILE_RRTILE3795 = 0;
int32_t TILE_RRTILE3804 = 0;
int32_t TILE_RRTILE3814 = 0;
int32_t TILE_RRTILE3815 = 0;
int32_t TILE_RRTILE3819 = 0;
int32_t TILE_RRTILE3827 = 0;
int32_t TILE_RRTILE3837 = 0;
int32_t TILE_RRTILE5014 = 0;
int32_t TILE_RRTILE5016 = 0;
int32_t TILE_RRTILE5017 = 0;
int32_t TILE_RRTILE5018 = 0;
int32_t TILE_RRTILE5019 = 0;
int32_t TILE_RRTILE5020 = 0;
int32_t TILE_RRTILE5021 = 0;
int32_t TILE_RRTILE5022 = 0;
int32_t TILE_RRTILE5023 = 0;
int32_t TILE_RRTILE5024 = 0;
int32_t TILE_RRTILE5025 = 0;
int32_t TILE_RRTILE5026 = 0;
int32_t TILE_RRTILE5027 = 0;
int32_t TILE_RRTILE5029 = 0;
int32_t TILE_RRTILE5030 = 0;
int32_t TILE_RRTILE5031 = 0;
int32_t TILE_RRTILE5032 = 0;
int32_t TILE_RRTILE5033 = 0;
int32_t TILE_RRTILE5034 = 0;
int32_t TILE_RRTILE5035 = 0;
int32_t TILE_RRTILE5036 = 0;
int32_t TILE_RRTILE5037 = 0;
int32_t TILE_RRTILE5038 = 0;
int32_t TILE_RRTILE5039 = 0;
int32_t TILE_RRTILE5040 = 0;
int32_t TILE_RRTILE5041 = 0;
int32_t TILE_RRTILE5043 = 0;
int32_t TILE_RRTILE5044 = 0;
int32_t TILE_RRTILE5045 = 0;
int32_t TILE_RRTILE5046 = 0;
int32_t TILE_RRTILE5047 = 0;
int32_t TILE_RRTILE5048 = 0;
int32_t TILE_RRTILE5049 = 0;
int32_t TILE_RRTILE5050 = 0;
int32_t TILE_RRTILE5051 = 0;
int32_t TILE_RRTILE5052 = 0;
int32_t TILE_RRTILE5053 = 0;
int32_t TILE_RRTILE5054 = 0;
int32_t TILE_RRTILE5055 = 0;
int32_t TILE_RRTILE5056 = 0;
int32_t TILE_RRTILE5057 = 0;
int32_t TILE_RRTILE5058 = 0;
int32_t TILE_RRTILE5059 = 0;
int32_t TILE_RRTILE5061 = 0;
int32_t TILE_RRTILE5062 = 0;
int32_t TILE_RRTILE5063 = 0;
int32_t TILE_RRTILE5064 = 0;
int32_t TILE_RRTILE5065 = 0;
int32_t TILE_RRTILE5066 = 0;
int32_t TILE_RRTILE5067 = 0;
int32_t TILE_RRTILE5068 = 0;
int32_t TILE_RRTILE5069 = 0;
int32_t TILE_RRTILE5070 = 0;
int32_t TILE_RRTILE5071 = 0;
int32_t TILE_RRTILE5072 = 0;
int32_t TILE_RRTILE5073 = 0;
int32_t TILE_RRTILE5074 = 0;
int32_t TILE_RRTILE5075 = 0;
int32_t TILE_RRTILE5076 = 0;
int32_t TILE_RRTILE5077 = 0;
int32_t TILE_RRTILE5078 = 0;
int32_t TILE_RRTILE5079 = 0;
int32_t TILE_RRTILE5080 = 0;
int32_t TILE_RRTILE5081 = 0;
int32_t TILE_RRTILE5082 = 0;
int32_t TILE_RRTILE5083 = 0;
int32_t TILE_RRTILE5084 = 0;
int32_t TILE_RRTILE5085 = 0;
int32_t TILE_RRTILE5086 = 0;
int32_t TILE_RRTILE5087 = 0;
int32_t TILE_RRTILE5088 = 0;
int32_t TILE_RRTILE5090 = 0;
int32_t TILE_RRTILE6144 = 0;
int32_t TILE_RRTILE7110 = 0;
int32_t TILE_RRTILE7111 = 0;
int32_t TILE_RRTILE7112 = 0;
int32_t TILE_RRTILE7113 = 0;
int32_t TILE_MOTOGUN = 0;
int32_t TILE_RRTILE7169 = 0;
int32_t TILE_MOTOHIT = 0;
int32_t TILE_BOATHIT = 0;
int32_t TILE_RRTILE7184 = 0;
int32_t TILE_RRTILE7190 = 0;
int32_t TILE_RRTILE7191 = 0;
int32_t TILE_RRTILE7213 = 0;
int32_t TILE_RRTILE7219 = 0;
int32_t TILE_EMPTYBIKE = 0;
int32_t TILE_EMPTYBOAT = 0;
int32_t TILE_RRTILE7424 = 0;
int32_t TILE_RRTILE7430 = 0;
int32_t TILE_RRTILE7433 = 0;
int32_t TILE_RRTILE7441 = 0;
int32_t TILE_RRTILE7547 = 0;
int32_t TILE_RRTILE7467 = 0;
int32_t TILE_RRTILE7469 = 0;
int32_t TILE_RRTILE7470 = 0;
int32_t TILE_RRTILE7475 = 0;
int32_t TILE_RRTILE7478 = 0;
int32_t TILE_RRTILE7505 = 0;
int32_t TILE_RRTILE7506 = 0;
int32_t TILE_RRTILE7534 = 0;
int32_t TILE_RRTILE7540 = 0;
int32_t TILE_RRTILE7533 = 0;
int32_t TILE_RRTILE7545 = 0;
int32_t TILE_RRTILE7552 = 0;
int32_t TILE_RRTILE7553 = 0;
int32_t TILE_RRTILE7554 = 0;
int32_t TILE_RRTILE7555 = 0;
int32_t TILE_RRTILE7557 = 0;
int32_t TILE_RRTILE7558 = 0;
int32_t TILE_RRTILE7559 = 0;
int32_t TILE_RRTILE7561 = 0;
int32_t TILE_RRTILE7566 = 0;
int32_t TILE_RRTILE7568 = 0;
int32_t TILE_RRTILE7574 = 0;
int32_t TILE_RRTILE7575 = 0;
int32_t TILE_RRTILE7576 = 0;
int32_t TILE_RRTILE7578 = 0;
int32_t TILE_RRTILE7579 = 0;
int32_t TILE_RRTILE7580 = 0;
int32_t TILE_RRTILE7595 = 0;
int32_t TILE_RRTILE7629 = 0;
int32_t TILE_RRTILE7636 = 0;
int32_t TILE_RRTILE7638 = 0;
int32_t TILE_RRTILE7640 = 0;
int32_t TILE_RRTILE7644 = 0;
int32_t TILE_RRTILE7646 = 0;
int32_t TILE_RRTILE7648 = 0;
int32_t TILE_RRTILE7650 = 0;
int32_t TILE_RRTILE7653 = 0;
int32_t TILE_RRTILE7655 = 0;
int32_t TILE_RRTILE7657 = 0;
int32_t TILE_RRTILE7659 = 0;
int32_t TILE_RRTILE7691 = 0;
int32_t TILE_RRTILE7694 = 0;
int32_t TILE_RRTILE7696 = 0;
int32_t TILE_RRTILE7697 = 0;
int32_t TILE_RRTILE7700 = 0;
int32_t TILE_RRTILE7702 = 0;
int32_t TILE_RRTILE7704 = 0;
int32_t TILE_RRTILE7705 = 0;
int32_t TILE_RRTILE7711 = 0;
int32_t TILE_RRTILE7716 = 0;
int32_t TILE_RRTILE7756 = 0;
int32_t TILE_RRTILE7768 = 0;
int32_t TILE_RRTILE7806 = 0;
int32_t TILE_RRTILE7820 = 0;
int32_t TILE_RRTILE7859 = 0;
int32_t TILE_RRTILE7870 = 0;
int32_t TILE_RRTILE7873 = 0;
int32_t TILE_RRTILE7875 = 0;
int32_t TILE_RRTILE7876 = 0;
int32_t TILE_RRTILE7879 = 0;
int32_t TILE_RRTILE7881 = 0;
int32_t TILE_RRTILE7883 = 0;
int32_t TILE_RRTILE7885 = 0;
int32_t TILE_RRTILE7886 = 0;
int32_t TILE_RRTILE7887 = 0;
int32_t TILE_RRTILE7888 = 0;
int32_t TILE_RRTILE7889 = 0;
int32_t TILE_RRTILE7890 = 0;
int32_t TILE_RRTILE7900 = 0;
int32_t TILE_RRTILE7901 = 0;
int32_t TILE_RRTILE7906 = 0;
int32_t TILE_RRTILE7912 = 0;
int32_t TILE_RRTILE7913 = 0;
int32_t TILE_RRTILE7936 = 0;
int32_t TILE_RRTILE8047 = 0;
int32_t TILE_MULTISWITCH2 = 0;
int32_t TILE_RRTILE8059 = 0;
int32_t TILE_RRTILE8060 = 0;
int32_t TILE_RRTILE8063 = 0;
int32_t TILE_RRTILE8067 = 0;
int32_t TILE_RRTILE8076 = 0;
int32_t TILE_RRTILE8094 = 0;
int32_t TILE_RRTILE8096 = 0;
int32_t TILE_RRTILE8099 = 0;
int32_t TILE_RRTILE8106 = 0;
int32_t TILE_RRTILE8162 = 0;
int32_t TILE_RRTILE8163 = 0;
int32_t TILE_RRTILE8164 = 0;
int32_t TILE_RRTILE8165 = 0;
int32_t TILE_RRTILE8166 = 0;
int32_t TILE_RRTILE8167 = 0;
int32_t TILE_RRTILE8168 = 0;
int32_t TILE_RRTILE8192 = 0;
int32_t TILE_RRTILE8193 = 0;
int32_t TILE_RRTILE8215 = 0;
int32_t TILE_RRTILE8216 = 0;
int32_t TILE_RRTILE8217 = 0;
int32_t TILE_RRTILE8218 = 0;
int32_t TILE_RRTILE8220 = 0;
int32_t TILE_RRTILE8221 = 0;
int32_t TILE_RRTILE8222 = 0;
int32_t TILE_RRTILE8223 = 0;
int32_t TILE_RRTILE8224 = 0;
int32_t TILE_RRTILE8227 = 0;
int32_t TILE_RRTILE8312 = 0;
int32_t TILE_RRTILE8370 = 0;
int32_t TILE_RRTILE8371 = 0;
int32_t TILE_RRTILE8372 = 0;
int32_t TILE_RRTILE8373 = 0;
int32_t TILE_RRTILE8379 = 0;
int32_t TILE_RRTILE8380 = 0;
int32_t TILE_RRTILE8385 = 0;
int32_t TILE_RRTILE8386 = 0;
int32_t TILE_RRTILE8387 = 0;
int32_t TILE_RRTILE8388 = 0;
int32_t TILE_RRTILE8389 = 0;
int32_t TILE_RRTILE8390 = 0;
int32_t TILE_RRTILE8391 = 0;
int32_t TILE_RRTILE8392 = 0;
int32_t TILE_RRTILE8394 = 0;
int32_t TILE_RRTILE8395 = 0;
int32_t TILE_RRTILE8396 = 0;
int32_t TILE_RRTILE8397 = 0;
int32_t TILE_RRTILE8398 = 0;
int32_t TILE_RRTILE8399 = 0;
int32_t TILE_RRTILE8423 = 0;
int32_t TILE_RRTILE8448 = 0;
int32_t TILE_RRTILE8450 = 0;
int32_t TILE_BOATAMMO = 0;
int32_t TILE_RRTILE8461 = 0;
int32_t TILE_RRTILE8462 = 0;
int32_t TILE_RRTILE8464 = 0;
int32_t TILE_RRTILE8475 = 0;
int32_t TILE_RRTILE8487 = 0;
int32_t TILE_RRTILE8488 = 0;
int32_t TILE_RRTILE8489 = 0;
int32_t TILE_RRTILE8490 = 0;
int32_t TILE_RRTILE8496 = 0;
int32_t TILE_RRTILE8497 = 0;
int32_t TILE_RRTILE8498 = 0;
int32_t TILE_RRTILE8499 = 0;
int32_t TILE_RRTILE8503 = 0;
int32_t TILE_RRTILE8525 = 0;
int32_t TILE_RRTILE8537 = 0;
int32_t TILE_RRTILE8565 = 0;
int32_t TILE_RRTILE8567 = 0;
int32_t TILE_RRTILE8568 = 0;
int32_t TILE_RRTILE8569 = 0;
int32_t TILE_RRTILE8570 = 0;
int32_t TILE_RRTILE8571 = 0;
int32_t TILE_RRTILE8579 = 0;
int32_t TILE_RRTILE8588 = 0;
int32_t TILE_RRTILE8589 = 0;
int32_t TILE_RRTILE8590 = 0;
int32_t TILE_RRTILE8591 = 0;
int32_t TILE_RRTILE8592 = 0;
int32_t TILE_RRTILE8593 = 0;
int32_t TILE_RRTILE8594 = 0;
int32_t TILE_RRTILE8595 = 0;
int32_t TILE_RRTILE8596 = 0;
int32_t TILE_RRTILE8598 = 0;
int32_t TILE_RRTILE8605 = 0;
int32_t TILE_RRTILE8608 = 0;
int32_t TILE_RRTILE8609 = 0;
int32_t TILE_RRTILE8611 = 0;
int32_t TILE_RRTILE8617 = 0;
int32_t TILE_RRTILE8618 = 0;
int32_t TILE_RRTILE8620 = 0;
int32_t TILE_RRTILE8621 = 0;
int32_t TILE_RRTILE8622 = 0;
int32_t TILE_RRTILE8623 = 0;
int32_t TILE_RRTILE8624 = 0;
int32_t TILE_RRTILE8640 = 0;
int32_t TILE_RRTILE8651 = 0;
int32_t TILE_RRTILE8660 = 0;
int32_t TILE_RRTILE8677 = 0;
int32_t TILE_RRTILE8679 = 0;
int32_t TILE_RRTILE8680 = 0;
int32_t TILE_RRTILE8681 = 0;
int32_t TILE_RRTILE8682 = 0;
int32_t TILE_RRTILE8683 = 0;
int32_t TILE_RRTILE8704 = 0;
int32_t TILE_BOULDER = 0;
int32_t TILE_BOULDER1 = 0;
int32_t TILE_TORNADO = 0;
int32_t TILE_CHEERBOMB = 0;
int32_t TILE_CHEERBLADE = 0;
int32_t TILE_DOGATTACK = 0;
int32_t TILE_BILLYWALK = 0;
int32_t TILE_BILLYDIE = 0;
int32_t TILE_BILLYCOCK = 0;
int32_t TILE_BILLYRAY = 0;
int32_t TILE_BILLYRAYSTAYPUT = 0;
int32_t TILE_BILLYBUT = 0;
int32_t TILE_BILLYSCRATCH = 0;
int32_t TILE_BILLYSNIFF = 0;
int32_t TILE_BILLYWOUND = 0;
int32_t TILE_BILLYGORE = 0;
int32_t TILE_BILLYJIBA = 0;
int32_t TILE_BILLYJIBB = 0;
int32_t TILE_BRAYSNIPER = 0;
int32_t TILE_DOGRUN = 0;
int32_t TILE_DOGDIE = 0;
int32_t TILE_DOGDEAD = 0;
int32_t TILE_DOGBARK = 0;
int32_t TILE_LTH = 0;
int32_t TILE_LTHSTRAFE = 0;
int32_t TILE_HULKHANG = 0;
int32_t TILE_HULKHANGDEAD = 0;
int32_t TILE_HULKJUMP = 0;
int32_t TILE_LTHLOAD = 0;
int32_t TILE_LTHDIE = 0;
int32_t TILE_BUBBASCRATCH = 0;
int32_t TILE_BUBBANOSE = 0;
int32_t TILE_BUBBAPISS = 0;
int32_t TILE_BUBBASTAND = 0;
int32_t TILE_BUBBAOUCH = 0;
int32_t TILE_BUBBADIE = 0;
int32_t TILE_BUBBADEAD = 0;
int32_t TILE_HULK = 0;
int32_t TILE_HULKSTAYPUT = 0;
int32_t TILE_HULKA = 0;
int32_t TILE_HULKB = 0;
int32_t TILE_HULKC = 0;
int32_t TILE_HULKJIBA = 0;
int32_t TILE_HULKJIBB = 0;
int32_t TILE_HULKJIBC = 0;
int32_t TILE_SBSWIPE = 0;
int32_t TILE_SBPAIN = 0;
int32_t TILE_SBDIE = 0;
int32_t TILE_HEN = 0;
int32_t TILE_HENSTAYPUT = 0;
int32_t TILE_HENSTAND = 0;
int32_t TILE_PIG = 0;
int32_t TILE_PIGSTAYPUT = 0;
int32_t TILE_PIGEAT = 0;
int32_t TILE_SBMOVE = 0;
int32_t TILE_SBSPIT = 0;
int32_t TILE_SBDIP = 0;
int32_t TILE_MINION = 0;
int32_t TILE_MINIONSTAYPUT = 0;
int32_t TILE_UFO1 = 0;
int32_t TILE_UFO2 = 0;
int32_t TILE_UFO3 = 0;
int32_t TILE_UFO4 = 0;
int32_t TILE_UFO5 = 0;
int32_t TILE_MINJIBA = 0;
int32_t TILE_MINJIBB = 0;
int32_t TILE_MINJIBC = 0;
int32_t TILE_COW = 0;
int32_t TILE_COOT = 0;
int32_t TILE_COOTSTAYPUT = 0;
int32_t TILE_COOTSHOOT = 0;
int32_t TILE_COOTDIE = 0;
int32_t TILE_COOTDUCK = 0;
int32_t TILE_COOTPAIN = 0;
int32_t TILE_COOTTRANS = 0;
int32_t TILE_COOTGETUP = 0;
int32_t TILE_COOTJIBA = 0;
int32_t TILE_COOTJIBB = 0;
int32_t TILE_COOTJIBC = 0;
int32_t TILE_VIXEN = 0;
int32_t TILE_VIXENPAIN = 0;
int32_t TILE_VIXENDIE = 0;
int32_t TILE_VIXENSHOOT = 0;
int32_t TILE_VIXENWDN = 0;
int32_t TILE_VIXENWUP = 0;
int32_t TILE_VIXENKICK = 0;
int32_t TILE_VIXENTELE = 0;
int32_t TILE_VIXENTEAT = 0;
int32_t TILE_BIKEJIBA = 0;
int32_t TILE_BIKEJIBB = 0;
int32_t TILE_BIKEJIBC = 0;
int32_t TILE_BIKERB = 0;
int32_t TILE_BIKERBV2 = 0;
int32_t TILE_BIKER = 0;
int32_t TILE_BIKERJIBA = 0;
int32_t TILE_BIKERJIBB = 0;
int32_t TILE_BIKERJIBC = 0;
int32_t TILE_BIKERJIBD = 0;
int32_t TILE_MAKEOUT = 0;
int32_t TILE_CHEERB = 0;
int32_t TILE_CHEER = 0;
int32_t TILE_CHEERSTAYPUT = 0;
int32_t TILE_CHEERJIBA = 0;
int32_t TILE_CHEERJIBB = 0;
int32_t TILE_CHEERJIBC = 0;
int32_t TILE_CHEERJIBD = 0;
int32_t TILE_FBOATJIBA = 0;
int32_t TILE_FBOATJIBB = 0;
int32_t TILE_COOTPLAY = 0;
int32_t TILE_BILLYPLAY = 0;
int32_t TILE_MINIONBOAT = 0;
int32_t TILE_HULKBOAT = 0;
int32_t TILE_CHEERBOAT = 0;
int32_t TILE_RRTILE7274 = 0;
int32_t TILE_RABBIT = 0;
int32_t TILE_RABBITJIBA = 0;
int32_t TILE_RABBITJIBB = 0;
int32_t TILE_RABBITJIBC = 0;
int32_t TILE_ROCK = 0;
int32_t TILE_ROCK2 = 0;
int32_t TILE_MAMACLOUD = 0;
int32_t TILE_MAMA = 0;
int32_t TILE_MAMAJIBA = 0;
int32_t TILE_MAMAJIBB = 0;

#if 0
static hashtable_t h_names = {512, NULL};

void G_ProcessDynamicTileMapping(const char *szLabel, int32_t lValue)
{
    int32_t i;

    if ((unsigned)lValue >= MAXTILES || !szLabel)
        return;

    i = hash_find(&h_names,szLabel);
    if (i>=0)
    {
        struct dynitem *di = &g_dynTileList[i];
#ifdef DEBUGGINGAIDS
        if (g_scriptDebug && di->staticval != lValue)
            Printf("REMAP %s (%d) --> %d\n", di->str, di->staticval, lValue);
#endif
        *di->dynvalptr = lValue;
    }
}

void inithashnames(void)
{
    int32_t i;

    hash_init(&h_names);

    for (i=0; g_dynTileList[i].staticval >= 0; i++)
        hash_add(&h_names, g_dynTileList[i].str, i, 0);
}

void freehashnames(void)
{
    hash_free(&h_names);
}
#endif


static struct dynitem g_dynWeaponList[] =
{
    { "KNEE_WEAPON", DVPTR(KNEE_WEAPON), KNEE_WEAPON__STATIC, KNEE_WEAPON__STATIC },
    { "PISTOL_WEAPON", DVPTR(PISTOL_WEAPON), PISTOL_WEAPON__STATIC, PISTOL_WEAPON__STATIC },
    { "SHOTGUN_WEAPON", DVPTR(SHOTGUN_WEAPON), SHOTGUN_WEAPON__STATIC, SHOTGUN_WEAPON__STATIC },
    { "CHAINGUN_WEAPON", DVPTR(CHAINGUN_WEAPON), CHAINGUN_WEAPON__STATIC, CHAINGUN_WEAPON__STATIC },
    { "RPG_WEAPON", DVPTR(RPG_WEAPON), RPG_WEAPON__STATIC, HANDBOMB_WEAPON__STATIC },
    { "HANDBOMB_WEAPON", DVPTR(HANDBOMB_WEAPON), HANDBOMB_WEAPON__STATIC, RPG_WEAPON__STATIC },
    { "SHRINKER_WEAPON", DVPTR(SHRINKER_WEAPON), SHRINKER_WEAPON__STATIC, SHRINKER_WEAPON__STATIC },
    { "DEVISTATOR_WEAPON", DVPTR(DEVISTATOR_WEAPON), DEVISTATOR_WEAPON__STATIC, FREEZE_WEAPON__STATIC },
    { "TRIPBOMB_WEAPON", DVPTR(TRIPBOMB_WEAPON), TRIPBOMB_WEAPON__STATIC, TRIPBOMB_WEAPON__STATIC },
    { "FREEZE_WEAPON", DVPTR(FREEZE_WEAPON), FREEZE_WEAPON__STATIC, DEVISTATOR_WEAPON__STATIC },
    { "HANDREMOTE_WEAPON", DVPTR(HANDREMOTE_WEAPON), HANDREMOTE_WEAPON__STATIC, HANDREMOTE_WEAPON__STATIC },
    { "GROW_WEAPON", DVPTR(GROW_WEAPON), GROW_WEAPON__STATIC, GROW_WEAPON__STATIC },
    { "BOWLINGBALL_WEAPON", DVPTR(BOWLINGBALL_WEAPON), BOWLINGBALL_WEAPON__STATIC, BOWLINGBALL_WEAPON__STATIC },
    { "MOTORCYCLE_WEAPON", DVPTR(MOTORCYCLE_WEAPON), MOTORCYCLE_WEAPON__STATIC, MOTORCYCLE_WEAPON__STATIC },
    { "BOAT_WEAPON", DVPTR(BOAT_WEAPON), BOAT_WEAPON__STATIC, BOAT_WEAPON__STATIC },
    { "SLINGBLADE_WEAPON", DVPTR(SLINGBLADE_WEAPON), SLINGBLADE_WEAPON__STATIC, SLINGBLADE_WEAPON__STATIC },
    { "CHICKEN_WEAPON", DVPTR(CHICKEN_WEAPON), CHICKEN_WEAPON__STATIC, CHICKEN_WEAPON__STATIC },
    { NULL, NULL, -1, -1 },
};

int32_t KNEE_WEAPON = KNEE_WEAPON__STATIC;
int32_t PISTOL_WEAPON = PISTOL_WEAPON__STATIC;
int32_t SHOTGUN_WEAPON = SHOTGUN_WEAPON__STATIC;
int32_t CHAINGUN_WEAPON = CHAINGUN_WEAPON__STATIC;
int32_t RPG_WEAPON = RPG_WEAPON__STATIC;
int32_t HANDBOMB_WEAPON = HANDBOMB_WEAPON__STATIC;
int32_t SHRINKER_WEAPON = SHRINKER_WEAPON__STATIC;
int32_t DEVISTATOR_WEAPON = DEVISTATOR_WEAPON__STATIC;
int32_t TRIPBOMB_WEAPON = TRIPBOMB_WEAPON__STATIC;
int32_t FREEZE_WEAPON = FREEZE_WEAPON__STATIC;
int32_t HANDREMOTE_WEAPON = HANDREMOTE_WEAPON__STATIC;
int32_t GROW_WEAPON = GROW_WEAPON__STATIC;
int32_t BOWLINGBALL_WEAPON = BOWLINGBALL_WEAPON__STATIC;
int32_t MOTORCYCLE_WEAPON = MOTORCYCLE_WEAPON__STATIC;
int32_t BOAT_WEAPON = BOAT_WEAPON__STATIC;
int32_t SLINGBLADE_WEAPON = SLINGBLADE_WEAPON__STATIC;
int32_t CHICKEN_WEAPON = CHICKEN_WEAPON__STATIC;

// This is run after all CON define's have been processed to set up the
// dynamic->static tile mapping.
void G_InitDynamicTiles(void)
{
    int32_t i;

    Bmemset(DynamicTileMap, 0, sizeof(DynamicTileMap));

    if (RR)
    {
        for (i = 0; g_dynTileList[i].staticval >= 0; i++) {
            *(g_dynTileList[i].dynvalptr) = -g_dynTileList[i].staticval_rr;
            if (RRRA && *(g_dynTileList[i].dynvalptr) == -UFO1__STATICRR) *(g_dynTileList[i].dynvalptr) = -UFO1__STATICRRRA;
            DynamicTileMap[*(g_dynTileList[i].dynvalptr)] = g_dynTileList[i].staticval_rr;
			NameToTileIndex.Insert(g_dynTileList[i].str, *(g_dynTileList[i].dynvalptr));
        }
        for (i = 0; g_dynWeaponList[i].staticval >= 0; i++)
            *(g_dynWeaponList[i].dynvalptr) = g_dynWeaponList[i].staticval_rr;

        PHEIGHT = PHEIGHT_RR;
    }

    for (i=0; g_dynTileList[i].staticval >= 0; i++)
        if (g_dynTileList[i].staticval > 0)
		{
            DynamicTileMap[*(g_dynTileList[i].dynvalptr)] = g_dynTileList[i].staticval;
			NameToTileIndex.Insert(g_dynTileList[i].str, *(g_dynTileList[i].dynvalptr));
		}

    for (i=0; g_dynWeaponList[i].staticval >= 0; i++)
        DynamicWeaponMap[*(g_dynWeaponList[i].dynvalptr)] = g_dynWeaponList[i].staticval;

    DynamicTileMap[0] = 0;

    g_blimpSpawnItems[0] = TILE_RPGSPRITE;
    g_blimpSpawnItems[1] = TILE_CHAINGUNSPRITE;
    g_blimpSpawnItems[2] = TILE_DEVISTATORAMMO;
    g_blimpSpawnItems[3] = TILE_RPGAMMO;
    g_blimpSpawnItems[4] = TILE_RPGAMMO;
    g_blimpSpawnItems[5] = TILE_JETPACK;
    g_blimpSpawnItems[6] = TILE_SHIELD;
    g_blimpSpawnItems[7] = TILE_FIRSTAID;
    g_blimpSpawnItems[8] = TILE_STEROIDS;
    g_blimpSpawnItems[9] = TILE_RPGAMMO;
    g_blimpSpawnItems[10] = TILE_RPGAMMO;
    g_blimpSpawnItems[11] = TILE_RPGSPRITE;
    g_blimpSpawnItems[12] = TILE_RPGAMMO;
    g_blimpSpawnItems[13] = TILE_FREEZESPRITE;
    g_blimpSpawnItems[14] = TILE_FREEZEAMMO;

    if (RR)
    {
        WeaponPickupSprites[0] = TILE_KNEE;
        WeaponPickupSprites[1] = TILE_FIRSTGUNSPRITE;
        WeaponPickupSprites[2] = TILE_SHOTGUNSPRITE;
        WeaponPickupSprites[3] = TILE_CHAINGUNSPRITE;
        WeaponPickupSprites[4] = TILE_RPGSPRITE;
        WeaponPickupSprites[5] = TILE_HEAVYHBOMB;
        WeaponPickupSprites[6] = TILE_SHRINKERSPRITE;
        WeaponPickupSprites[7] = TILE_DEVISTATORSPRITE;
        WeaponPickupSprites[8] = TILE_TRIPBOMBSPRITE;
        WeaponPickupSprites[9] = TILE_BOWLINGBALLSPRITE;
        WeaponPickupSprites[10] = TILE_FREEZEBLAST;
        WeaponPickupSprites[11] = TILE_HEAVYHBOMB;
    }
    else
    {
        WeaponPickupSprites[0] = TILE_KNEE;
        WeaponPickupSprites[1] = TILE_FIRSTGUNSPRITE;
        WeaponPickupSprites[2] = TILE_SHOTGUNSPRITE;
        WeaponPickupSprites[3] = TILE_CHAINGUNSPRITE;
        WeaponPickupSprites[4] = TILE_RPGSPRITE;
        WeaponPickupSprites[5] = TILE_HEAVYHBOMB;
        WeaponPickupSprites[6] = TILE_SHRINKERSPRITE;
        WeaponPickupSprites[7] = TILE_DEVISTATORSPRITE;
        WeaponPickupSprites[8] = TILE_TRIPBOMBSPRITE;
        WeaponPickupSprites[9] = TILE_FREEZESPRITE;
        WeaponPickupSprites[10] = TILE_HEAVYHBOMB;
        WeaponPickupSprites[11] = TILE_SHRINKERSPRITE;
    }

    // ouch... the big background image takes up a fuckload of memory and takes a second to load!
#ifdef EDUKE32_GLES
    TILE_MENUSCREEN = TILE_LOADSCREEN = TILE_BETASCREEN;
#endif
}
END_DUKE_NS
